*This do-file cleans the Household roster data and prepares variables for analysis
clear all 
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Clean hhm
use "${gsdData}/1-CleanInput/hhm.dta", clear
*define lyn value label for later
*Give value labels Yes/No 
label define lyn 0 "No" 1 "Yes"
*merge with number of members per household
merge m:1 migr_idp region ea hh using "${gsdData}/1-CleanInput/hh.dta", assert(match) keep(match master) keepusing(hhsize hhh_id weight) nogen 
*create household head dummy
gen ishead=hhh_id==hhmid
sort migr_idp region ea hh ishead
bys migr_idp region ea hh: assert ishead[_N]==1
order ishead, after(hhmid)
label var ishead "Household head"
label val ishead lyn
*Generate and label age group variable
*make sure age is never missing
recode B_1_1_hhm_age (0/5 = 1 "Under 6 Years") (6/14 = 2 "6 - 14 Years") (15/30 = 3 "15 - 30 Years") (31/65 = 4 "31 - 65 Years") (66/150 = 5 "Above 65 Years"), generate(age_g)
label var age_g "Age Category (4 groups)"
recode B_1_1_hhm_age (0/4 = 1 "Under 5 Years") (5/9 = 2 "5 - 9 Years") (10/14 = 3 "10 - 14 Years") (15/19 = 4 "15 - 19 Years") (20/24 = 5 "20 - 24 Years") (25/29 = 6 "25 - 29 Years") (30/34 = 7 "30 - 34 Years") (35/39 = 8 "35 - 39 Years") (40/44 = 9 "40 - 44 Years") (45/49 = 10 "45 - 49 Years") (50/100 = 11 "Above 49 Years"), generate(age_g_alt)
label var age_g_alt "Age Category (5 yrs increments, end above 49)"
recode B_1_1_hhm_age (0/4.9 = 1 "Under 5 Years") (5/9.9 = 2 "5 - 9 Years") (10/14.9 = 3 "10 - 14 Years") (15/19.9 = 4 "15 - 19 Years") (20/24.9 = 5 "20 - 24 Years") (25/29.9 = 6 "25 - 29 Years") (30/34.9 = 7 "30 - 34 Years") (35/39.9 = 8 "35 - 39 Years") (40/44.9 = 9 "40 - 44 Years") (45/49 = 10 "45 - 49 Years") (50/54 = 11 "50 - 54 Years") (55/59 = 12 "55 - 59 Years") (60/65 = 13 "60 - 64 Years") (65/69 = 14 "65 - 69 Years") (70/74 = 15 "70 - 74 Years") (75/79 = 16 "75 - 79 Years") (80/120 = 17 "Above 80 Years"), generate(age_cat_g)
label var age_cat_g "Age Category (5 yrs increments, end above 80)"
*Generate and label youth age group variable
gen youth = inrange(B_1_1_hhm_age, 15, 35)
label var youth "Youth Age (15-35)"
label val youth lyn
recode B_1_1_hhm_age (15/20 = 1 "Between 15 and 20 Years") (21/25 = 2 "Between 21 and 25 Years") (26/30 = 3 "Between 26 and 30 Years") (31/35 = 4 "Between 31 and 35 Years") if youth == 1, generate(youthage_g)
label var youthage_g "Youth Age Group (5 yrs increment, 15-35)"
*Generate and label working age variable
recode B_1_1_hhm_age (15/64 = 1 "Working age") (0/14 = 0 "Not of working age") (65/120 = 0 "Not of working age"), gen(working_age)
label var working_age "Working Age (15-64)"
label val working_age lyn
*Generate school age grouping variables
*Generate and label school age indicator
recode B_1_1_hhm_age ( 6/120 = 1 "School age") (0/5 = 0 "Not of school age"), gen(school_age)
label var school_age "School age (6+)"
*Generate and label primary school age indicator
recode B_1_1_hhm_age (6/13 = 1 "Primary school age") (0/5 14/120 = 0 "Not of primary school age") , gen(school_age_primary)
label var school_age_primary "Primary School Age (6-13)"
*Generate and label secondary school age indicator
recode B_1_1_hhm_age (14/18 = 1 "Secondary school age") (0/13 19/120 = 0 "Not of secondary school age") , gen(school_age_secondary)
label var school_age_secondary "Of Secondary School Age (14-18)"
*Generate and label school age indicator
recode B_1_1_hhm_age (6/18 = 1 "Primary or secondary school age") (0/5 19/120 = 0 "Not of primary or secondary school age") , gen(school_age_prim_sec)
label var school_age_prim_sec "Of Primary or Secondary School Age"
*Generate and label post-secondary school age indicator
recode B_1_1_hhm_age (19/120 = 1 "Post-secondary school age") (0/18 = 0 "Not of post-secondary school age") , gen(school_age_adult)
label var school_age_adult "Of Post-Secondary School Age"

*Generate literacy and education status variables
*Generate literacy variable (literacy defined as ability to read AND write) and add variable label
gen literacy = (B_4_1_hhm_read==1 & B_4_2_hhm_write==1) 
replace literacy=. if (missing(B_4_1_hhm_read) | missing(B_4_2_hhm_write))
label var literacy "Literacy (can read and write)" 
label val literacy lyn

*Generate education group variable:
recode B_4_10_hhm_edu_level (0/8 = 2 "Primary & Intermediate") (9/12 = 3 "Secondary") (13/17 = 4 "University") (17 18 = 5 " Technical and Vocational Education" ) (19/21 24 25 26 1000 = 6 "Others"), generate(edu_level_g)
*Consolidating the different country education groups:
label var edu_level_g "Highest level of education attended (categorized)"
replace edu_level_g=1 if B_4_7_hhm_edu_ever==0
label define edu_level_g 1 "No education", modify
label values edu_level_g edu_level_g
recode B_4_10_hhm_edu_level (0=1 "No education") (1/8 = 2 "Primary & Intermediate") (9/16 = 3 "Secondary") (22/23 = 4 "University") (17 18 = 5 " Technical and Vocational Education" ) (24/25 = 6 "Religious") (19/21 26 1000 = 7 "Others"), generate(edu_level_g_c)
label var edu_level_g_c "Highest level of education completed (categorized)"
replace edu_level_g_c=1 if B_4_7_hhm_edu_ever==0
label define edu_level_g_c 1 "No education", modify
label values edu_level_g_c edu_level_g_c
*Generate current attendance variables:
recode B_4_10_hhm_edu_level (0/7 = 1 "Primary") (8/11 = 2 "Secondary") (12/19 1000 = .) if B_4_3_hhm_edu_current == 1, generate(edu_level_current)
label var edu_level_current "Current level of education attended (categorized)"
*Generate education group variables for Jobs Compact:
recode B_4_10_hhm_edu_level (0/7 = 1 "Less than grade 8 education") (8/18 = 2 "Grade 8 or higher education") (19 1000 = 6 "Others"), generate(edu_level_g_jc) label(edu_level_g_jc)
label var edu_level_g_jc "Highest level of education attended (categorized) for Job Compact"
label values edu_level_g_jc edu_level_g_jc
replace edu_level_g_jc=0 if B_4_7_hhm_edu_ever==0
label define edu_level_g_jc 0 "No education", modify
*Enrollment status
gen enrolled = .
replace enrolled = -1 if missing(B_1_1_hhm_age)
replace enrolled = 0 if B_1_1_hhm_age <= 5
replace enrolled = 1 if B_4_3_hhm_edu_current == 1
replace enrolled = 2 if (B_4_6_hhm_edu_pre == 1 | B_4_7_hhm_edu_ever == 1) & B_4_3_hhm_edu_current == 0
replace enrolled = 3 if B_4_7_hhm_edu_ever == 0 & B_4_3_hhm_edu_current == 0 & B_4_6_hhm_edu_pre == 0
label define enrolled -1 "Age unknown" 0 "Not of education age" 1 "Currently enrolled" 2 "Previously enrolled" 3 "Never enrolled"
label values enrolled enrolled
label variable enrolled "Enrollment status" 
*Generate net and gross enrollment variables:
gen net_primary_enrolled = 1 if (edu_level_current == 1 & school_age_primary == 1)
replace net_primary_enrolled = 0 if (school_age_primary == 1 & edu_level_current !=1)
gen net_secondary_enrolled = 1 if (edu_level_current == 2 & school_age_secondary == 1)
replace net_secondary_enrolled = 0 if (school_age_secondary == 1 & edu_level_current !=2)

*Employment/Short reference period
*Generate variable indicating recently active in the labor mkt in past week, 
*defined as either "did something in the last seven days" OR "did not but will definitely return to work"
egen empl_active_7d=rowtotal(B_5_2_emp_7d_paid B_5_3_emp_7d_busi B_5_4_emp_7d_help B_5_5_emp_7d_farm B_5_6_emp_7d_appr)
gen active_7d = .
replace active_7d = 1 if (empl_active_7d >0 & !missing(empl_active_7d)) | B_5_7_emp_7d_temp == 1
replace active_7d = 0 if empl_active_7d == 0 &  B_5_7_emp_7d_temp == 0
label var active_7d "Currently working or about to return to work (7 days)"
lab val active_7d lyn
*Labor force participation
*include all working age people
gen status=0 if inrange(B_1_1_hhm_age,15,64)
*mark observations missing age
replace status=99 if missing(B_1_1_hhm_age)
*mark observations outside working age
replace status=3 if working_age==0
*mark observations with missing employment information 
replace status=98 if status ==0 & missing( B_5_2_emp_7d_paid) & missing(B_5_3_emp_7d_busi) & missing(B_5_4_emp_7d_help) & missing(B_5_5_emp_7d_farm) & missing(B_5_6_emp_7d_appr) & working_age==1
*mark the employed (active or going back to a job AND of working age
replace status = ((empl_active_7d>0 & !missing(empl_active_7d)) | B_5_7_emp_7d_temp == 1) if working_age==1
*mark the unemployed: Those that are not currently employed, are looking for job and are available to work.
replace status= 2 if status==0 & (empl_active_7d==0 & B_5_7_emp_7d_temp==0) & B_6_1_hhm_job_search==1  & inlist(B_6_3_hhm_available,1,2,3)
*label
label define status 0 "Inactive" 1 "Employed" 2 "Unemployed"  3 "Outside Working Age" 98 "Working-age, no information on activity" 99 "Age N/A"
label values status status
label variable status "Labor force status, 7 days reference period"
*generate a labor force participation variable
gen lfparticip=0 if status==0
*count employed as active
replace lfparticip=1 if status==1
*count unemployed as active
replace lfparticip=1 if status==2
*make sure that LFP is missing if status is outside working age or missing age or employement information
assert missing(lfparticip) if status==3 | status==98 | status==99
*label
label def lfparticipl 0 "Outside the labor force / inactive" 1 "In the labor force / active"
label val lfparticip lfparticipl
label var lfparticip "Labor force participation, 7 days reference period"
*generate education status for inactive population
gen inactivechar_7d = 0 if lfparticip == 0
replace inactivechar_7d =1 if enrolled == 1 & lfparticip == 0
label var inactivechar_7d "Status of those not participating in the labor force"
label def inactivechar_7d 1 "Enrolled"  0 "Not enrolled"
label val inactivechar_7d inactivechar_7d
*generate labor status with enrolled in education option
gen laborchar_7d=1 if status==1
replace laborchar_7d=2 if status==1 & B_4_3_hhm_edu_current == 1 
replace laborchar_7d=3 if status==2
label var laborchar_7d "Status of those participating in the labor force"
label def labor_7d  1 "Employed"  2 "Employment and Enrolled" 3 "Unemployed" 
label val laborchar_7d labor_7d
*Check that the emplpoyment status is missing if not in the labor force
assert missing(laborchar_7d) if lfparticip==0
*check that those in the labor force are employed/emp and enrolled/unemployed
assert lfparticip==1 if (laborchar_7d==1 | laborchar_7d==2 |laborchar_7d==3)
*generate unemployment rate
recode laborchar_7d (1 2=0 "Employed") (3=1 "Unemployed") , gen(u_rate)
label var u_rate "Unemployment rate, 7 days reference period"

*Reasons for not participating in the labor force in the last 7 days:
recode B_6_2_hhm_job_s_no (0 = 1 "Insecurity") (1/2 = 2 "Sick/Disabled") (3 = 3 "Studying") (4/5 = 4 "Too young/too old") (6 10 = 5 "Family Reasons") (7 8 = 6 "Waiting for employment opportunities") ( 9 = 7 "Does not want to work") ( 11/12 = 8 "Non-existent/poor employmnet opporutnities"), gen(reason_inactive)                  

*Cleaning employment before displacement for Refugees:
replace B_8_2_emp_prev = B_5_12_emp_ever_detail if missing(B_8_2_emp_prev)

* Sector Breakdown
tab B_7_4_emp_7d_prim_isic, m
recode B_7_4_emp_7d_prim_isic (1 = 1 "Agriculture") (2 3 4 6 = 2 "Manufacturing") (5 7/14 16/21 = 3 "Services") ( 15 = 4 "Public sector / defence") (1000 = 1000 "Other") , gen(emp_sector_broad)
label var emp_sector_broad "Employment sector, broad"
tab emp_sector_broad, m
label define emp_sector_broad  .a "Don't know" .c "Refused to respond" , modify
recode B_7_4_emp_7d_prim_isic (1 = 1 "Agriculture") (2 3 4 6 = 2 "Manufacturing") (5 7/14 17/21 = 3 "Services") (16 = 4 "Education") (1000 = 1000 "Other") ( 15 = 5 "Public sector / defence"), gen(emp_sector_5)
label var emp_sector_5 "Employment sector"
label define emp_sector_5  .a "Don't know" .c "Refused to respond" , modify
tab emp_sector_5, m
*Sector breakdown before displacement
tab B_8_7_emp_7d_prim_prev, m
recode B_8_7_emp_7d_prim_prev (1 = 1 "Agriculture") (2 3 4 6 = 2 "Manufacturing") (5 7/14 16/21 = 3 "Services") ( 15 = 4 "Public sector / defence") (1000 = 1000 "Other") , gen(emp_sector_broad_prev)
label var emp_sector_broad_prev "Employment sector, broad: before Dec13"
tab emp_sector_broad_prev, m
label define emp_sector_broad_prev  .a "Don't know" .c "Refused to respond" , modify
recode B_8_7_emp_7d_prim_prev (1 = 1 "Agriculture") (2 3 4 6 = 2 "Manufacturing") (5 7/14 17/21 = 3 "Services") (16 = 4 "Education") (1000 = 1000 "Other") ( 15 = 5 "Public sector / defence"), gen(emp_sector_5_prev)
label var emp_sector_5_prev "Employment sector: before Dec13"
label define emp_sector_5_prev  .a "Don't know" .c "Refused to respond" , modify
tab emp_sector_5_prev, m

*Identify dependents (include disabled in dependent indicator)
*Calculating dependent share according to Victoria's definition.
gen dependent = 0
*replace dependent = 0 if working_age == 1 & B_61_hhm_job_search_no != 2
replace dependent = 1 if inlist(age_g,1,2)
*replace dependent = 1 if B_61_hhm_job_search_no == 2
*replace as missing those whose information on employment is missing
*replace dependent=. if status==98
label var dependent "Household member is a dependent (0-14)"
label val dependent lyn
*clean up and save
*Drop unnecessary vars
drop age_g_alt 

save "${gsdData}/1-CleanOutput/hhm.dta", replace
merge m:1 migr_idp region ea hh using "${gsdData}/1-CleanInput/hh.dta"

*Generate household level statistics
use "${gsdData}/1-CleanOutput/hhm.dta", clear
*Generate household head statistics
*Confirm that every HH has exactly 1 head
bysort migr_idp region ea hh: egen hhh_indicator = total(ishead)
assert hhh_indicator == 1
drop hhh_indicator
*Generate hhh gender and spread to all hh members
recode B_2_1_hhm_gender (1 = 0 "Male Head") (2 = 1 "Female Head") if ishead == 1, gen(hhh_gender)
label var hhh_gender "Gender of household head"
*Generate hhh age
gen hhh_age = B_1_1_hhm_age if ishead == 1
label variable hhh_age "Age of Household Head"
*Generate hhh highest level of education
gen hhh_edu_level_g= edu_level_g if ishead == 1
label var hhh_edu_level_g "Level of Education of Household Head"
label value hhh_edu_level_g edu_level_g
*generate household head literacy
gen hhh_literacy=literacy==1 if ishead == 1
label var hhh_literacy "Literacy of household head"
label val hhh_literacy lyn
*Compute number of HH members report their age
gen age_nm = !missing(B_1_1_hhm_age)
bysort migr_idp region ea hh: egen nhhm_age = total(age_nm), missing
drop age_nm
*Compute number of HH members who are (1) of working age and (2) have a non-missing employment status
gen labor_wa_nm = (!missing(status) & working_age==1)
bysort migr_idp region ea hh: egen nhhm_labor_wa = total(labor_wa_nm), missing
drop labor_wa_nm
*Compute number of HH members who (1) have a non-missing employment status
gen labor_all_nm = !inlist(status,98,99)
bysort migr_idp region ea hh: egen nhhm_labor_all = total(labor_all_nm), missing
drop labor_all_nm
*Sum employed per household
bysort migr_idp region ea hh: egen empl_sum = total(u_rate), missing
*Generate proportion employed to total number of members of working age with non-missing labor status
bysort migr_idp region ea hh: gen empl_share_wa = empl_sum / nhhm_labor_wa 
label var empl_share_wa "Ratio of employed to HH members of working age"
*Generate proportion employed to total number of members with non-missing labor status
bysort migr_idp region ea hh: gen empl_share_ls = empl_sum / nhhm_labor_all 
label var empl_share_ls "Ratio of employed to all HH members with identifiable labor status"
*Generate proportion employed to all members of household
bysort migr_idp region ea hh: gen empl_share_all = empl_sum / hhsize 
label var empl_share_all "Ratio of employed to all HH members"
*Compute total number of dependents per household
bysort migr_idp region ea hh: egen ndependents = total(dependent), missing	
*Create variable that identifies disabled among those of working age
gen disabled = 0 if working_age == 1
replace disabled = 1 if B_6_2_hhm_job_s_no == 2
*Identify HH members who are not dependents
*Idenfitying HH members who are not dependents based on Victoria's definition:
gen dependent_not = 0
replace dependent_not = 1 if inlist(age_g,3,4)
*replace dependent_not = 1 if dependent == 0
*Compute HH members who have a non-missing dependency status
bysort migr_idp region ea hh: egen nindependents = total(dependent_not), missing
*Compute proportion dependents per household
bysort migr_idp region ea hh: gen depend_share = ndependents / nindependents 
label var depend_share "Share of dependents in household"
*drop unecessary variables
drop empl_sum nhhm_age nhhm_labor_wa nhhm_labor_all ndependents disabled dependent_not nindependents
*Compute school attendance shares
foreach l in primary secondary adult prim_sec {
	*Count number of HH members that belong to each school age category
	bysort migr_idp region ea hh: egen school_age_`l'_sum = total(school_age_`l'), missing
	*Generate variable indicating if each HH member attends school for the relevant school age category
	gen attend_`l' = .
	replace attend_`l' = 0 if B_4_3_hhm_edu_current==0 & school_age_`l'==1
	replace attend_`l' = 1 if B_4_3_hhm_edu_current==1 & school_age_`l'==1
	*Count number of HH members that attend school in each school age category
	bysort migr_idp region ea hh: egen attend_`l'_sum = total(attend_`l'), missing
	*Compute attendance share for each school age category
	bysort migr_idp region ea hh: gen attend_`l'_share = attend_`l'_sum / school_age_`l'_sum 
	*Label age share variables
	label var attend_`l'_share "School attendance rate of `l' school aged"
	*Drop unnecessary variables
	drop school_age_`l'_sum  attend_`l'_sum
}
drop attend_primary attend_secondary attend_adult attend_prim_sec
bysort migr_idp region ea hh: egen joined = max(B_1_4_hhm_pre)
label var joined "New Household Member Joined"

*Collapse data
local collapselist "hhh_age hhh_gender hhh_edu_level_g hhh_literacy depend_share attend_primary_share attend_secondary_share attend_adult_share attend_prim_sec_share B_2_8_hhm_mar_status joined" //ADD TRIBE VARIABLE LATER
*Save labels
foreach var of local collapselist {
	*Save variable labels
	local l`var' : variable label `var'
	if `"`l`var''"' == "" {
		local l`var' "`var'"
	}
	*Save value labels
	local vl`var': value label `var'
	if `"`vl`var''"' == "" {
		local vl`var' "` '"
	}
}
*Collapse data
collapse (max) `collapselist', by(migr_idp region ea hh weight)
*Reapply labels
foreach var of local collapselist  {
	*Reapply variable labels
	label variable `var' "`l`var''"
	*Reapply value labels
	label value `var' `vl`var''
}
save "${gsdData}/1-CleanTemp/hh_hhm.dta", replace
