*This do file cleans food consumption data

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

use "${gsdData}\1-CleanInput\food.dta", clear
*prepare data for cleaning
*merge with sampling weights to calculate medians
merge m:1 migr_idp region ea hh using "${gsdData}/1-CleanInput/hh.dta" , keep(match) keepusing(hhsize mod_hh) nogen
*rename variables of interest 
rename (D_4_cons D_1_13_cons_quant D_1_13_cons_unit D_1_14_cons_high D_1_14_cons_low D_1_15_purc_quant D_1_15_purc_unit D_1_16_purc_high D_1_16_purc_low D_1_17_pric_total D_1_17_pric_total_curr) (cons cons_q cons_u cons_high cons_low purc_q purc_u purc_high purc_low price price_curr)
*keep if (cons==1)
*Generate conversion factors:

merge m:1 itemcode purc_u using "${gsdDataRaw}/conversions.dta", keepusing(purc_conv_factor)
drop if _merge==2
drop _merge
merge m:1 itemcode cons_u using "${gsdDataRaw}/conversions.dta", keepusing(cons_conv_factor)
drop if _merge==2
drop _merge
gen cons_conv2kg = cons_conv_factor 
replace cons_conv2kg = 0.001 if cons_u == 2
gen purc_conv2kg = purc_conv_factor
replace purc_conv2kg = 1 if purc_u == 1 | purc_u == 3
replace purc_conv2kg = 0.001 if purc_u == 2
*replace cons_conv2kg = 0.25 if cons_u == 3
*replace cons_conv2kg = 0.045 if cons_u == 5 & item == 1106401
*Nyala is a cigarette brand
*replace cons_conv2kg = 0.001 if cons_u == 5 & item == 2201101
*Generate vars that report kg quantities consumed and produced
gen cons_q_kg = cons_q * cons_conv2kg
label var cons_q_kg	"Quantity consumed in kg"

*replace purc_conv2kg = 0.25 if purc_u == 3
*replace purc_u = 5 if item == 1106401 & !missing(purc_q)
*replace purc_u = 5 if item == 2201101  & !missing(purc_q)
label values purc_u rf_cons_unit
*replace purc_conv2kg = 0.045 if purc_u == 5 & item == 1106401
*Nyala is a cigarette brand
*replace purc_conv2kg = 0.001 if purc_u == 5 & item == 2201101 
gen purc_q_kg = purc_q * purc_conv2kg
label var purc_q_kg "Quantity purchased in kg"
*gen item id for easily seeing codes in data
gen itemid =item
* Unit correction:
* Check distribution of quantities across units to see if units are systematically misreported or if it is simply outliers
tabstat purc_q , by(purc_u) s(N min p5 p25 p50 mean p75 p95 max)
tabstat cons_q , by(cons_u) s(N min p5 p25 p50 mean p75 p95 max)
*qui tabout purc_u using "${gsdTemp}/Check_Purchase.xls", sum oneway cells(min purc_q p5 purc_q p25 purc_q p50 purc_q mean purc_q p75 purc_q p95 purc_q max purc_q) h1(Raw Distribution - Purchase Quantities) f(2) replace
*qui tabout cons_u using "${gsdTemp}/Check_Consumption.xls", sum oneway cells(min cons_q p5 cons_q p25 cons_q p50 cons_q mean cons_q p75 cons_q p95 cons_q max cons_q) h1(Raw Distribution - Consumption Quantities) f(2) replace
*Cleaning rule 1: tag units where a record has the same figure in quantity consumed and purchased but different units
gen tag_same_q_diff_u=1 if (cons_q==purc_q) & (cons_u!=purc_u) & cons==1 & !missing(cons_q) & !missing(purc_q)
replace tag_same_q_diff_u=0 if cons==1 & tag_same_q_diff_u!=1
*The correct unit is the one that takes the variable (consumption or purchase) closer to the weighted median value in the distribution of that variable for the same item
*calculate the median quantity consumed/purchased
local ls = "cons purc"
foreach s of local ls {
	bysort itemid: egen x`s'_kg_med=median(`s'_q_kg) if tag_same_q_diff_u!=1 & `s'_q_kg!=0 
	bysort itemid: egen `s'_kg_med=max(x`s'_kg_med)
	drop x`s'_kg_med
	*make sure medians are never equal to zero
	assert `s'_kg_med!=0 
}
*obtain the absolute difference between the quantity and the median for the respective item
gen diff_cons_kg=abs(cons_q_kg - cons_kg_med) if tag_same_q_diff_u==1
gen diff_purc_kg=abs(purc_q_kg - purc_kg_med) if tag_same_q_diff_u==1
*introduce the replacements
replace cons_u=purc_u 					if diff_purc_kg<diff_cons_kg & tag_same_q_diff_u==1
replace purc_u=cons_u 					if diff_purc_kg>diff_cons_kg & tag_same_q_diff_u==1
replace cons_conv2kg=purc_conv2kg 		if diff_purc_kg<diff_cons_kg & tag_same_q_diff_u==1
replace purc_conv2kg=cons_conv2kg   	if diff_purc_kg>diff_cons_kg & tag_same_q_diff_u==1
replace cons_q_kg=purc_q_kg 			if diff_purc_kg<diff_cons_kg & tag_same_q_diff_u==1
replace purc_q_kg=cons_q_kg 			if diff_purc_kg>diff_cons_kg & tag_same_q_diff_u==1
* Check if all conversion factors that need to be constant are constant, For unit, number the conversion factor is different based on item.
tabstat purc_conv2kg, by(purc_u) stat(min q max)
tabstat cons_conv2kg, by(cons_u) stat(min q max)
*check impact of cleaning rule
tabstat cons_q , by(cons_u) s(N min p5 p25 p50 mean p75 p95 max)
tabstat purc_q , by(purc_u) s(N min p5 p25 p50 mean p75 p95 max)
*qui tabout purc_u using "${gsdTemp}/Check_Purchase.xls", sum oneway cells(min purc_q p5 purc_q p25 purc_q p50 purc_q mean purc_q p75 purc_q p95 purc_q max purc_q) h1(Distribution1 - Purchase Quantities) f(2) append
*qui tabout cons_u using "${gsdTemp}/Check_Consumption.xls", sum oneway cells(min cons_q p5 cons_q p25 cons_q p50 cons_q mean cons_q p75 cons_q p95 cons_q max cons_q) h1(Distribution1 - Consumption Quantities) f(2) append

*Cleaning rule 2: clean items probably reported in the wrong units
gen tag_cons_wrong_u = 0 if cons==1
gen tag_purc_wrong_u = 0 if cons==1
* Create loop over units of consumption and purchase, tag and then replace
local ls = "cons purc"
foreach s of local ls {
	* Gram: If grams <=10, multiply by 1000 because the enumerator probably meant 
	* kilogram 
	replace tag_`s'_wrong_u = 1 			if  (`s'_q<=10 & `s'_u==2  &  cons==1 & !missing(cons))
	replace `s'_q 			= `s'_q*1000	if  (`s'_q<=10 & `s'_u==2  &  cons==1 & !missing(cons))
	* Kilogram: If kilogram >= 100, divide by 1,000 because the enumerator 
	* probably meant grams
	replace tag_`s'_wrong_u = 1 			if (`s'_q>=100 & `s'_u==1 & cons==1 & cons!=.)
	replace `s'_q 			= `s'_q/1000 	if (`s'_q>=100 & `s'_u==1 & cons==1 & cons!=.)	
}
*check impact of corrections
tabstat cons_q , by(cons_u) s(N min p5 p25 p50 mean p75 p95 p99 max)
tabstat purc_q if purc_q!=0, by(purc_u) s(N min p5 p25 p50 mean p75 p95 p99 max) 
*qui tabout purc_u using "${gsdTemp}/Check_Purchase.xls", sum oneway cells(min purc_q p5 purc_q p25 purc_q p50 purc_q mean purc_q p75 purc_q p95 purc_q max purc_q) h1(Distribution2 - Purchase Quantities) f(2) append
*qui tabout cons_u using "${gsdTemp}/Check_Consumption.xls", sum oneway cells(min cons_q p5 cons_q p25 cons_q p50 cons_q mean cons_q p75 cons_q p95 cons_q max cons_q) h1(Distribution2 - Consumption Quantities) f(2) append
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
label val tag_* ltag
tab tag_same_q_diff_u
qui qui tabout tag_same_q_diff_u using "${gsdOutput}/cleaning_rules-food.xls" , replace c(freq col) h1(Tagged because same quantities different units)
tab tag_cons_wrong_u
qui qui tabout tag_cons_wrong_u using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col) h1(Tagged because wrong consumption units)
tab tag_purc_wrong_u
qui qui tabout tag_purc_wrong_u using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col) h1(Tagged because wrong purchase units)
*drop tags and variables used for cleaning this section
drop tag_* *_med diff_*
*Regenerate vars that report kg quantities consumed and produced after corrections
drop cons_q_kg
gen cons_q_kg = cons_q * cons_conv2kg
label var cons_q_kg	"Quantity consumed in kg"
drop purc_q_kg 
gen purc_q_kg = purc_q * purc_conv2kg
label var purc_q_kg "Quantity purchased in kg"
*check whether conversions into kg make sense
tabstat cons_q_kg , by(cons_u) s(N min p5 p25 p50 mean p75 p95 p99 max)
*qui tabout cons_u using "${gsdTemp}/Check_Consumption_kg.xls", sum oneway cells(min cons_q_kg p5 cons_q_kg p25 cons_q_kg p50 cons_q_kg mean cons_q_kg p75 cons_q_kg p95 cons_q_kg max cons_q_kg) h1(Distribution - Consumption Quantities) f(2) replace
tabstat purc_q_kg if purc_q!=0, by(purc_u) s(N min p5 p25 p50 mean p75 p95 p99 max) 
*qui tabout purc_u using "${gsdTemp}/Check_Purchase_kg.xls" if purc_q!=0 , sum oneway cells(min purc_q p5 purc_q p25 purc_q p50 purc_q mean purc_q p75 purc_q p95 purc_q max purc_q) h1(Distribution - Purchase Quantities) f(2) replace
tabstat cons_q_kg , by(itemid) s(N min p5 p25 p50 mean p75 p95 p99 max)
*qui tabout item using "${gsdTemp}/Check_Consumption_Item.xls", sum oneway cells(N cons_q_kg min cons_q_kg p5 cons_q_kg p25 cons_q_kg p50 cons_q_kg mean cons_q_kg p75 cons_q_kg p95 cons_q_kg max cons_q_kg) h1(Distribution - Consumption Quantities) f(2) replace
tabstat purc_q_kg if purc_q!=0, by(itemid) s(N min p5 p25 p50 mean p75 p95 p99 max) 
*qui tabout item using "${gsdTemp}/Check_Purchase_Item.xls" if purc_q!=0 , sum oneway cells(N purc_q_kg min purc_q_kg p5 purc_q_kg p25 purc_q_kg p50 purc_q_kg mean purc_q_kg p75 purc_q_kg p95 purc_q_kg max purc_q_kg) h1(Distribution - Purchase Quantities) f(2) replace
*1-tag observations according to cleaning rules

* Cleaning Rule 3: 
* (i) tag values that were consumed but have missing quantities. 
gen tag_cons_but_no_cons_q=1 if cons==1 & missing(cons_q)
replace tag_cons_but_no_cons_q=0 if cons==1 & tag_cons_but_no_cons_q!=1
* (ii) tag values that were consumed and have missing purchase. 
gen tag_cons_but_no_purc_q=1 if cons==1  & missing(purc_q)
replace tag_cons_but_no_purc_q=0 if cons==1 & tag_cons_but_no_purc_q!=1
* (iii) tag values that were consumed but have zero consumption quantities
gen tag_cons_but_zero_cons=1 if cons==1 & cons_q==0
replace tag_cons_but_zero_cons=0 if cons==1 & tag_cons_but_zero_cons!=1
save "${gsdTemp}/foodcleaningtemp_1.dta", replace
* Cleaning Rule 4 (i): 
use "${gsdData}/1-CleanInput/food_quant.dta", clear
merge 1:m itemid using "${gsdTemp}/foodcleaningtemp_1.dta", assert(master match) keep(match) nogen
*collapse c_pc_min c_pc_max v_min v_max, by(item itemid)
*export excel item itemid c_pc_min c_pc_max v_min v_max using "${gsdTemp}/food_constraints_appendix.xls", replace firstrow(variables)
local ls = "cons purc"
foreach s of local ls{
	gen tag_`s'_below_soft_q = 1 if `s'_q_kg*1000 < c_min 
	replace tag_`s'_below_soft_q=0 if tag_`s'_below_soft_q !=1 & cons==1
	gen tag_`s'_above_soft_q = 1 if  `s'_q_kg*1000 > c_max & 	!missing(`s'_q_kg) & c_max != 0
	replace tag_`s'_above_soft_q=0 if tag_`s'_above_soft_q!= 1 & cons == 1
}
*Cleaning Rule 4(ii):
foreach s of local ls{
	gen tag_`s'_below_soft_pc_q = 1 if `s'_q_kg/hhsize*1000 < c_min 
	replace tag_`s'_below_soft_pc_q=0 if tag_`s'_below_soft_pc_q !=1 & cons==1
	gen tag_`s'_above_soft_pc_q = 1 if  `s'_q_kg/hhsize*1000 > c_max & !missing(`s'_q_kg) & c_max != 0
	replace tag_`s'_above_soft_pc_q=0 if tag_`s'_above_soft_pc_q!= 1 & cons == 1
}
* Cleaning Rule 5: 
* (i) tag values with same figure in quant. consumed, purchased and price
gen tag_same_cons_purc_price=1 if cons==1 & !missing(cons_q) & cons_q == purc_q & purc_q == price 
replace tag_same_cons_purc_price=0 if cons==1 & tag_same_cons_purc_price!=1
* (ii) tag values with same figure for quantity purchased and price 
gen tag_same_purc_price=1 if cons==1 & !missing(purc_q) & purc_q == price & cons_q != purc_q
replace tag_same_purc_price=0 if cons==1 & tag_same_purc_price!=1
* (iii) tag values with same figure for quantity consumed and price 
gen tag_same_cons_price=1 if cons==1 & !missing(cons_q) & cons_q == price & cons_q != purc_q
replace tag_same_cons_price=0 if cons==1 & tag_same_cons_price!=1
*Cleaning Rule 6: 
*Calculating median consumption per capita in kg for each item and then observing the data outside 3 median absolute deviations
local ls = "cons purc"
foreach s of local ls{
	bysort itemid: gen `s'_q_kg_pc = `s'_q_kg/hhsize
	bysort itemid: egen `s'_q_kg_pc_med = median(`s'_q_kg_pc)
	bysort itemid: egen `s'_q_kg_pc_mad = mad(`s'_q_kg_pc)
	bysort itemid: gen `s'_q_kg_pc_z_r = (`s'_q_kg_pc - `s'_q_kg_pc_med)/`s'_q_kg_pc_mad
	gen tag_`s'_q_kg_pc_top3mad = 1 if `s'_q_kg_pc_z_r > 3 & !missing(`s'_q_kg_pc_z)
	replace tag_`s'_q_kg_pc_top3mad = 0 if tag_`s'_q_kg_pc_top3mad != 1 & cons == 1
	gen tag_`s'_q_kg_pc_bottom3mad = 1 if `s'_q_kg_pc_z_r < -3 & !missing(`s'_q_kg_pc_z)
	replace tag_`s'_q_kg_pc_bottom3mad = 0 if tag_`s'_q_kg_pc_bottom3mad != 1 & cons == 1
}
*Cleaning Rule 7: 
*Calculating per capita normal distributions for each item and then observing the data outside 3 standard deviations. 
local ls = "cons purc"
foreach s of local ls{
	bysort itemid: egen `s'_q_kg_pc_mean = mean(`s'_q_kg_pc) if (tag_`s'_below_soft_pc_q == 0 & tag_`s'_above_soft_pc_q == 0) & (tag_`s'_below_soft_q == 0 & tag_`s'_above_soft_q == 0)
	bysort itemid: egen `s'_q_kg_pc_sd = sd(`s'_q_kg_pc) if (tag_`s'_below_soft_pc_q == 0 & tag_`s'_above_soft_pc_q == 0) & (tag_`s'_below_soft_q == 0 & tag_`s'_above_soft_q == 0)
	bysort itemid: gen `s'_q_kg_pc_z = (`s'_q_kg_pc - `s'_q_kg_pc_mean)/`s'_q_kg_pc_sd
	gen tag_`s'_q_kg_pc_top3sd = 1 if `s'_q_kg_pc_z > 3 & !missing(`s'_q_kg_pc_z) & cons == 1
	replace tag_`s'_q_kg_pc_top3sd = 0 if tag_`s'_q_kg_pc_top3sd != 1 & cons == 1
	gen tag_`s'_q_kg_pc_bottom3sd = 1 if `s'_q_kg_pc_z < -3 & !missing(`s'_q_kg_pc_z) & cons == 1 
	replace tag_`s'_q_kg_pc_bottom3sd = 0 if tag_`s'_q_kg_pc_bottom3sd != 1 & cons == 1
}

*Cleaning Rule 7(ii):
*Calculating mean kg consumption per capita over all items for a household and then observing the data outside 3 standard deviations.
local ls = "cons purc"
foreach s of local ls{
	bysort region ea migr_idp hh: egen `s'_q_kg_pc_total = total(`s'_q_kg_pc) 
	egen `s'_q_kg_pc_total_mean = mean(`s'_q_kg_pc_total) if (tag_`s'_below_soft_pc_q == 0 & tag_`s'_above_soft_pc_q == 0) & (tag_`s'_below_soft_q == 0 & tag_`s'_above_soft_q == 0)
	egen `s'_q_kg_pc_total_sd = sd(`s'_q_kg_pc_total) if (tag_`s'_below_soft_pc_q == 0 & tag_`s'_above_soft_pc_q == 0) & (tag_`s'_below_soft_q == 0 & tag_`s'_above_soft_q == 0)
	gen `s'_q_kg_pc_total_z = (`s'_q_kg_pc_total - `s'_q_kg_pc_total_mean)/`s'_q_kg_pc_total_sd
	gen tag_`s'_q_kg_pc_total_top3sd = 1 if `s'_q_kg_pc_total_z > 3 & !missing(`s'_q_kg_pc_total_z) & cons == 1 
	replace tag_`s'_q_kg_pc_total_top3sd = 0 if tag_`s'_q_kg_pc_total_top3sd != 1 & cons == 1
	gen tag_`s'_q_kg_pc_total_bottom3sd = 1 if `s'_q_kg_pc_total_z < -3 & !missing(`s'_q_kg_pc_total_z) & cons == 1 
	replace tag_`s'_q_kg_pc_total_bottom3sd = 0 if tag_`s'_q_kg_pc_total_bottom3sd != 1 & cons == 1
}
*Observe where both are tagged:
foreach s of local ls{
	gen tag_`s'_q_kg_pc_check_top = 1 if tag_`s'_q_kg_pc_top3sd == 1 & tag_`s'_q_kg_pc_total_top3sd == 1
	replace  tag_`s'_q_kg_pc_check_top = 0 if missing(tag_`s'_q_kg_pc_check_top) & cons == 1
	gen tag_`s'_q_kg_pc_check_bottom = 1 if tag_`s'_q_kg_pc_bottom3sd == 1 & tag_`s'_q_kg_pc_total_bottom3sd == 1
	replace  tag_`s'_q_kg_pc_check_bottom = 0 if missing(tag_`s'_q_kg_pc_check_bottom) & cons == 1 
}
*Cleaning Rule 8:
*Tag bottom and top percent prices in overall quantity consumed per capita distributions 
local bottom = 0.01
local top = 0.99
local ls = "cons purc"
foreach s of local ls{
	*gen `s'_q_kg_pc=`s'_q_kg/hhsize
	* Calculate distribution
	cumul  `s'_q_kg_pc, gen(`s'_q_kg_pc_distribution) equal 
	* (i) tag prices at the bottom of the distribution
	gen tag_`s'_q_pc_bottom=0 if (`s'_q_kg_pc_distribution>=`bottom' ) & (cons==1) & !missing(`s'_q_kg) 
	replace tag_`s'_q_pc_bottom=1 if (`s'_q_kg_pc_distribution<`bottom') & cons==1 & !missing(`s'_q_kg)
	*tag prices at the top of the distribution
	gen tag_`s'_q_pc_top=0	if (`s'_q_kg_pc_distribution<=`top' ) & (cons==1) & !missing(`s'_q_kg)
	replace tag_`s'_q_pc_top=1	if (`s'_q_kg_pc_distribution>`top') & cons==1 & !missing(`s'_q_kg)
}
*Cleaning Rule 
*drop cons_q_kg_pc purc_q_kg_pc
*tag consumption values that must be replaced according to quantity cleaning rules: 3 (i),and (iii), 4, 5 (i) and 6.
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
gen replace_cons=0 if cons==1
label val replace_cons ltag 
label var replace_cons "Consumption value to be replaced with median"
local varlist "tag_cons_but_no_cons_q tag_cons_but_zero_cons tag_cons_below_soft_pc_q tag_cons_above_soft_pc_q tag_same_cons_price tag_cons_q_kg_pc_check_top tag_cons_q_kg_pc_check_bottom" 
foreach t of local varlist {
	replace replace_cons = 1 if (`t'==1)
	label val `t' ltag
	tab `t'
	qui tabout `t' using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col)
}
tab replace_cons
qui tabout replace_cons using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col)
*tag purchase values that must be replaced according to quantity cleaning rules: 3 (ii), 4, and 5 (i) and (ii).
gen replace_purc=0 if cons==1
label val replace_purc ltag 
label var replace_purc "Purchase value to be replaced with median"
local varlist "tag_cons_but_no_purc_q tag_same_purc_price" 
foreach t of local varlist {
	replace replace_purc = 1 if (`t'==1)
	label val `t' ltag
	tab `t'
	quietly qui tabout `t' using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col)
}
tab replace_purc
qui tabout replace_purc using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col)
*2-Calculate medians for quantities consumed and quantities purchased on three levels: (i) EA (ii) region (iii) IDP or not
*  (iv) national level; count the # of obs available at each level to see how representative the medians are at the respective level
local varlist "cons purc"
foreach v of local varlist {
	bysort itemid region ea: egen x`v'_q_kg_pc_ea_med = median(`v'_q_kg_pc) if replace_`v'==0 & `v'_q_kg_pc!=0
	bysort itemid region ea: egen `v'_q_kg_pc_ea_med = max(x`v'_q_kg_pc_ea_med)
	drop x`v'_q_kg_pc_ea_med
	bysort itemid region ea: egen x`v'_q_kg_pc_ea_c = count(`v'_q_kg_pc) if replace_`v'==0 & `v'_q_kg_pc!=0
	bysort itemid region ea: egen `v'_q_kg_pc_ea_c = max(x`v'_q_kg_pc_ea_c)
	drop x`v'_q_kg_pc_ea_c
	bysort itemid region: egen x`v'_q_kg_pc_reg_med = median(`v'_q_kg_pc) if replace_`v' == 0 & `v'_q_kg_pc != 0
	bysort itemid region: egen `v'_q_kg_pc_reg_med = max(x`v'_q_kg_pc_reg_med)
	drop x`v'_q_kg_pc_reg_med
	bysort itemid region: egen x`v'_q_kg_pc_reg_c = count(`v'_q_kg) if replace_`v'==0 & `v'_q_kg_pc!=0
	bysort itemid region: egen `v'_q_kg_pc_reg_c = max(x`v'_q_kg_pc_reg_c)
	drop x`v'_q_kg_pc_reg_c
	bysort itemid region migr_idp: egen x`v'_q_kg_pc_idp_med = median(`v'_q_kg_pc) if replace_`v'==0 & `v'_q_kg_pc!=0
	bysort itemid region migr_idp: egen `v'_q_kg_pc_idp_med = max(x`v'_q_kg_pc_idp_med)
	drop x`v'_q_kg_pc_idp_med
	bysort itemid region migr_idp: egen x`v'_q_kg_pc_idp_c = count(`v'_q_kg_pc) if replace_`v'==0 & `v'_q_kg_pc!=0
	bysort itemid region migr_idp: egen `v'_q_kg_pc_idp_c = max(x`v'_q_kg_pc_idp_c)
	drop x`v'_q_kg_pc_idp_c	
	bysort itemid: egen x`v'_q_kg_pc_itemid_med = median(`v'_q_kg_pc) if replace_`v'==0 & `v'_q_kg_pc!=0
	bysort itemid: egen `v'_q_kg_pc_itemid_med = max(x`v'_q_kg_pc_itemid_med)
	drop x`v'_q_kg_pc_itemid_med
	bysort itemid: egen x`v'_q_kg_pc_itemid_c = count(`v'_q_kg) if replace_`v'==0 & `v'_q_kg_pc!=0
	bysort itemid: egen `v'_q_kg_pc_itemid_c = max(x`v'_q_kg_pc_itemid_c)
	drop x`v'_q_kg_pc_itemid_c		
}
*make sure that medians are not equal to zero
assert cons_q_kg_pc_ea_med!=0
assert purc_q_kg_pc_ea_med!=0
assert cons_q_kg_pc_reg_med!=0
assert purc_q_kg_pc_reg_med!=0
assert cons_q_kg_pc_idp_med!=0
assert purc_q_kg_pc_idp_med!=0
assert cons_q_kg_pc_itemid_med!=0
assert purc_q_kg_pc_itemid_med!=0
*make sure medians at least at the item level are not missing; check for which items do we have no quantities
tab itemid if missing(cons_q_kg_pc_itemid_med) & cons==1
*We have 8 items for which we have no consumption quantities : 1102202,1108105,1109107,1121107,1121120,1121130,1202206,2202302
*assert !missing(cons_q_kg_pc_itemid_med) if cons==1 & !inlist(itemid,1101154,1102202,1108105,1109107,1121107,1121120,1121130,1202206,2202302)
*we dont have any purchase quantities for a range of items: 1101105 1101112 1101113 1101124 1101125 1101127 1101128 1101129 1102202 1103102 116201 1108105 1109205 1121115 1110104 1121115 1121130 1121132 1202206 2101110 2202302 
tab itemid if missing(purc_q_kg_pc_itemid_med) & cons==1
*assert !missing(purc_q_kg_pc_itemid_med) if cons==1 & !inlist(itemid,1101105,1101112,1101124,1101125,1101127,1101128,1101129,1102202,1106202,1107102,1108105,1109107,1121107,1121120,1121130,1121132,1202206,2101110,2202302)
*inspect medians and counts. The tabstat shows that most replacements are at the itemid level.
tabstat *_med *_c , s(N min p5 q p95 max) columns(stat) varwidth(16)
*3-replace tagged outliers with medians
* Use median quantities from smallest geo level where min # of 5/10 obs are available
*check how many items will be affected
tab replace_cons
*perform corrections
replace  cons_q_kg_pc = cons_q_kg_pc_itemid_med if (replace_cons==1) & !missing(cons_q_kg_pc_itemid_med)
replace  cons_q_kg_pc = cons_q_kg_pc_idp_med if (replace_cons==1 & cons_q_kg_pc_idp_c>=10 & !missing(cons_q_kg_pc_idp_c))
replace cons_q_kg_pc = cons_q_kg_pc_reg_med if (replace_cons==1 & cons_q_kg_pc_reg_c >=10 & !missing(cons_q_kg_pc_reg_c))
replace  cons_q_kg_pc = cons_q_kg_pc_ea_med if (replace_cons==1 & cons_q_kg_pc_ea_c>=5 & !missing(cons_q_kg_pc_ea_c))
*check how many items will be affected
tab replace_purc
*perform corrections
replace  purc_q_kg_pc = purc_q_kg_pc_itemid_med if (replace_purc==1) & !missing(purc_q_kg_pc_itemid_med)  									
replace  purc_q_kg_pc = purc_q_kg_pc_idp_med if (replace_purc==1 &  purc_q_kg_pc_idp_c>=10 & !missing(purc_q_kg_pc_idp_c))
replace purc_q_kg_pc = purc_q_kg_pc_reg_med if (replace_purc==1 & purc_q_kg_pc_reg_c >=10 & !missing(purc_q_kg_pc_reg_c))
replace  purc_q_kg_pc = purc_q_kg_pc_ea_med if (replace_purc==1 &  purc_q_kg_pc_ea_c>=5 & !missing(purc_q_kg_pc_ea_c))
*Obtain cleaned cons_q_kg and purc_q_kg
local varlist "cons purc"
foreach v of local varlist {
	replace `v'_q_kg = `v'_q_kg_pc*hhsize if replace_`v' == 1
}
*rename three tags for later use for cleaning prices; change prefix so that they are not dropped in following line
rename (tag_same_cons_purc_price tag_same_purc_price tag_same_cons_price) (keep_tag_same_cons_purc_price keep_tag_same_purc_price keep_tag_same_cons_price)
*drop tags and variables used for cleaning this section
drop tag_* *_med *_c replace_*
*re-rename tags to keep
rename (keep_tag_same_cons_purc_price keep_tag_same_purc_price keep_tag_same_cons_price) (tag_same_cons_purc_price tag_same_purc_price tag_same_cons_price) 
*4-Check impact of cleaning 
*check that quantity consumed is never equal to zero
assert cons_q_kg!=0
*check impact of corrections
tabstat cons_q_kg_pc , s(N min p5 p25 p50 mean p75 p95 p99 max)
tabstat purc_q_kg_pc , s(N min p5 p25 p50 mean p75 p95 p99 max)
*by itemid per capita:
tabstat cons_q_kg_pc , by(itemid) s(N min p5 p25 p50 mean p75 p95 p99 max)
*qui tabout item using "${gsdTemp}/Check_Consumption_Item_pc_f.xls", sum oneway cells(N cons_q_kg_pc min cons_q_kg_pc p5 cons_q_kg_pc p25 cons_q_kg_pc p50 cons_q_kg_pc mean cons_q_kg_pc p75 cons_q_kg_pc p95 cons_q_kg_pc max cons_q_kg_pc) h1(Distribution - Consumption Quantities) f(2) replace
tabstat purc_q_kg_pc , by(itemid) s(N min p5 p25 p50 mean p75 p95 p99 max)
*qui tabout item using "${gsdTemp}/Check_Purchase_Item_pc_f.xls", sum oneway cells(N purc_q_kg_pc min purc_q_kg_pc p5 purc_q_kg_pc p25 purc_q_kg_pc p50 purc_q_kg_pc mean purc_q_kg_pc p75 purc_q_kg_pc p95 purc_q_kg_pc max purc_q_kg_pc) h1(Distribution - Purchase Quantities) f(2) replace
/*by itemid per capita
gen cons_q_kg_pc=cons_q_kg/hhsize
gen purc_q_kg_pc=purc_q_kg/hhsize
tabstat cons_q_kg_pc , by(itemid) s(N min p5 p25 p50 mean p75 p95 p99 max) format(%8.2g)
qui tabout item using "${gsdTemp}/Check_Consumption_pc_Item_f.xls", sum oneway cells(min cons_q_kg_pc p5 cons_q_kg_pc p25 cons_q_kg_pc p50 cons_q_kg_pc mean cons_q_kg_pc p75 cons_q_kg_pc p95 cons_q_kg_pc max cons_q_kg_pc) h1(Distribution - Consumption Quantities) f(2) replace
tabstat purc_q_kg_pc , by(itemid) s(N min p5 p25 p50 mean p75 p95 p99 max) format(%8.2g)
qui tabout item using "${gsdTemp}/Check_Purchase_Item_f.xls", sum oneway cells(min purc_q_kg_pc p5 purc_q_kg_pc p25 purc_q_kg_pc p50 purc_q_kg_pc mean purc_q_kg_pc p75 purc_q_kg_pc p95 purc_q_kg_pc max purc_q_kg_pc) h1(Distribution - Purchase Quantities) f(2) replace
*/
*relabel quantities
label var cons_q_kg_pc	"Quantity consumed in kg per capita"
label var purc_q_kg_pc "Quantity purchased in kg per capita"
replace cons_q_kg = cons_q_kg_pc * hhsize
replace purc_q_kg = purc_q_kg_pc * hhsize
save "${gsdTemp}/foodcleaningtemp_2.dta", replace

* Cleaning: Prices 
use "${gsdTemp}/foodcleaningtemp_2.dta", clear
*1-Prepare prices
*Convert currencies
tab price_curr
gen price_usd = price if price_curr == 2
replace price=price/360 if price_curr==2
replace price=.z if price==0 & inrange(itemid,1,8) & D_1_18_pric_zero==1 
* Calculate per kilo price
gen  price_per_kg = price/purc_q_kg if cons==1
label var price_per_kg "Price paid per kg in current Naira"
*2-Tag observations according to cleaning rules
*Cleaning rule 6: replace missing prices
* (i) tag values that were purchased but have missing prices; 
gen tag_purc_but_no_price=1 if cons==1 & missing(price) & !missing(purc_q) & purc_q!=0
replace tag_purc_but_no_price=0 if cons==1 & tag_purc_but_no_price!=1
* (ii) tag items where quantity purchased is zero or missing to replace the missing prices
gen tag_purc_zero_missing = 1 if cons==1 &  (purc_q_kg==0 | purc_q_kg==.) 
replace tag_purc_zero_missing=0 if cons==1 & tag_purc_zero_missing!=1
* (iii) tag items that were consumed but do not have a price
gen tag_cons_but_no_price = 0 if cons==1
replace tag_cons_but_no_price = 1 if cons==1 & missing(price)
* (iv) tag items that were consumed but have zero price
gen tag_cons_zero_price = 0 if cons==1
replace tag_cons_zero_price = 1 if cons==1 & price==0
* Cleaning Rule 7: 
* Tag bottom and top percent prices in overall price distributions 
local bottom = 0.05
local top = 0.95
* Calculate distribution
cumul price_per_kg, gen(price_per_kg_distribution) equal 
* (i) tag prices at the bottom of the distribution
gen tag_price_bottom=0 if (price_per_kg_distribution>=`bottom') & (cons==1) & !missing(price_per_kg)
replace tag_price_bottom=1 if (price_per_kg_distribution<`bottom') & cons==1 & !missing(price_per_kg)
*tag prices at the top of the distribution
gen tag_price_top=0	if (price_per_kg_distribution<=`top') & (cons==1) & !missing(price_per_kg)
replace tag_price_top=1	if (price_per_kg_distribution>`top') & cons==1 & !missing(price_per_kg)
*Cleaning Rule 8:
*Tag prices per kg that are above or below 3 standard deviations of the mean:
bysort itemid: egen price_per_kg_mean = mean(price_per_kg)
bysort itemid: egen price_per_kg_sd = sd(price_per_kg)
gen tag_price_above_3sd = 1 if price_per_kg > price_per_kg_mean + 3*price_per_kg_sd & !missing(price_per_kg)
replace tag_price_above_3sd = 0 if missing(tag_price_above_3sd) & cons == 1
gen tag_price_below_3sd = 1 if price_per_kg < price_per_kg_mean - 3*price_per_kg_sd & !missing(price_per_kg)
replace tag_price_below_3sd = 0 if missing(tag_price_below_3sd) & cons == 1
tab tag_price_above_3sd
tab tag_price_below_3sd
tabstat price_per_kg if (tag_purc_but_no_price == tag_purc_zero_missing == tag_cons_but_no_price == tag_cons_zero_price == tag_same_cons_purc_price == tag_same_purc_price == tag_same_cons_price == tag_price_above_3sd == tag_price_below_3sd == 0) , by(itemid) stat(N sd min p5 q p95 p99 max) col(stat)
*Cleaning remaining prices:
* (ii) check how many values are affected by cleaning rules
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
*tag purchase values that must be replaced according to quantity cleaning rules: 6 (i),(ii),(iii) and (iv) .
gen replace_price=0 if cons==1
label var replace_price "Price value to be replaced with median"
local varlist "tag_purc_but_no_price tag_purc_zero_missing tag_cons_but_no_price tag_cons_zero_price tag_same_cons_purc_price tag_same_purc_price tag_same_cons_price tag_price_above_3sd tag_price_below_3sd tag_price_bottom tag_price_top"
foreach t of local varlist {
	replace replace_price = 1 if (`t'==1)
	label val `t' ltag
	tab `t' 
	quietly qui tabout `t' using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col)
}
label val replace_price ltag
tab replace_price 
qui tabout replace_price using "${gsdOutput}/cleaning_rules-food.xls" , append c(freq col)
tabstat price_per_kg if replace_price == 0 , by(itemid) stat(N sd min p5 q p95 p99 max) col(stat)


*3-Calculate medians for per kilo prices on three levels: (i) EA (ii) camp (iii) strata, i.e. 
* StrataID level, (iii) item level; count # of obs available at each level 
* to see how representative the medians are at the respective level
*calculate medians and counts
bysort itemid region ea: egen xprice_per_kg_ea_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid region ea: egen price_per_kg_ea_med = max(xprice_per_kg_ea_med)
drop xprice_per_kg_ea_med
bysort itemid region ea: egen xprice_per_kg_ea_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid region ea: egen price_per_kg_ea_c = max(xprice_per_kg_ea_c)
drop xprice_per_kg_ea_c
bysort itemid region: egen xprice_per_kg_reg_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid region: egen price_per_kg_reg_med = max(xprice_per_kg_reg_med)
drop xprice_per_kg_reg_med
bysort itemid region: egen xprice_per_kg_reg_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid region: egen price_per_kg_reg_c = max(xprice_per_kg_reg_c)
drop xprice_per_kg_reg_c 
bysort itemid region migr_idp: egen xprice_per_kg_idp_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid region migr_idp: egen price_per_kg_idp_med = max(xprice_per_kg_idp_med)
drop xprice_per_kg_idp_med
bysort itemid region migr_idp: egen xprice_per_kg_idp_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid region migr_idp: egen price_per_kg_idp_c = max(xprice_per_kg_idp_c)
drop xprice_per_kg_idp_c
bysort itemid: egen xprice_per_kg_itemid_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid: egen price_per_kg_itemid_med = max(xprice_per_kg_itemid_med)
drop xprice_per_kg_itemid_med
bysort itemid: egen xprice_per_kg_itemid_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort itemid: egen price_per_kg_itemid_c = max(xprice_per_kg_itemid_c)
drop xprice_per_kg_itemid_c
*make sure that medians at the itemlevel are never equal to zero
assert price_per_kg_itemid_med!=0
tab itemid if missing(price_per_kg_itemid_med) & cons==1
*There are a number items for which prices are missing even at the item level, though these items are consumed.
*local itemlist = "1101105 1101112 1101113 1101116 1101124 1101125 1101127 1101128 101129 1101135 1101141 1101153 1101154 1102123 1102202 1106103 1106201 1106202  1107102 1108105 1108109 1109107 1111103 1121101 1121107 1121109 1121116 1121120 1121130 1109205 121130 1121132 1121133 1201106 1202206 2101110 2201101 2202302"
*foreach i of local itemlist {
	*su price_per_kg [aw=weight] if itemid==`i' & price_per_kg!=0  & replace_price == 0, detail
	*replace price_per_kg_itemid_med = r(p50) if itemid==`i' & missing(price_per_kg_itemid_med)
*}
*tab item if missing(price_per_kg_itemid_med) & cons==1
*assert !missing(price_per_kg_itemid_med) if cons==1 & !inlist(itemid,2201101,1101105,1101112,1101116,1101124,1101125,1101127,1101128,1101129,1101135,1101141,1101153,1101154,1102123,1102202,1104301,1106103,1106201,1106202,1107102,1108105,1108109,1109107,1111103,1121101,1121107,1121109,1121116,1121120,1121130,1121132,1121133,1201106,1202206,2101110,2201101,2202302)
*inspect medians and counts: 
tabstat *_med *_c , s(N min p5 q p95 max)
*4-Replace tagged outliers with medians
gen price_per_kg_cleaned = price_per_kg if cons==1 & replace_price == 0
label var price_per_kg_cleaned "Price paid per kg in current Naira after cleaning"
*check how many items will be affected
tab replace_price
*perform corrections
replace  price_per_kg_cleaned =  price_per_kg_itemid_med if cons==1 & replace_price==1 & !missing(price_per_kg_itemid_med)
replace  price_per_kg_cleaned =  price_per_kg_idp_med if cons==1 & replace_price==1 &  price_per_kg_idp_c>=10 & !missing(price_per_kg_idp_c)
replace  price_per_kg_cleaned =  price_per_kg_reg_med if cons==1 & replace_price==1 &  price_per_kg_reg_c>=5 & !missing(price_per_kg_reg_c)
replace  price_per_kg_cleaned =  price_per_kg_ea_med if cons==1 & replace_price==1 &  price_per_kg_ea_c>=5 & !missing(price_per_kg_ea_c)
*5-Check impact of cleaning
tabstat price_per_kg price_per_kg_cleaned , stat(N sd min p5 q p95 p99 max) col(stat)
tabstat price_per_kg_cleaned , by(itemid) stat(N sd min p5 q p95 p99 max) col(stat)
gen tag_missing_cleaned = 1 if missing(price_per_kg_cleaned) & cons == 1
*replace the prices for missing food items to the closest five digit category:
*generate five digit categories out of 7 digit item codes:
gen cat = 0 if !missing(itemid)
replace cat= 1 if inrange(itemid,10,28)
replace cat= 2 if inrange(itemid,40,48)
replace cat= 3 if inrange(itemid,80,114)
replace cat= 4 if inrange(itemid,60,78)
replace cat= 4 if itemid==601
replace cat= 5 if inrange(itemid,1,8) 
replace cat= 0 if inrange(itemid,29,37)
replace cat= 0 if inrange(itemid,50,56)
replace cat= 0 if inrange(itemid,120,162)
label define categories 1 "Bread" 2 "Pulses" 3 "Meat and Dairy" 4 "Fruits and Vegetables" 5 "Away from home" 0 "Other"
label val cat categories
bysort cat region ea: egen xprice_per_kg_ea_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort cat region ea: egen price_per_kg_ea_cat_med = max(xprice_per_kg_ea_cat_med)
drop xprice_per_kg_ea_cat_med
bysort cat region ea: egen xprice_per_kg_ea_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat region ea: egen price_per_kg_ea_cat_c = max(xprice_per_kg_ea_cat_c)
drop xprice_per_kg_ea_cat_c
bysort cat region: egen xprice_per_kg_reg_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat region: egen price_per_kg_reg_cat_med = max(xprice_per_kg_reg_cat_med)
drop xprice_per_kg_reg_cat_med
bysort cat region: egen xprice_per_kg_reg_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat region: egen price_per_kg_reg_cat_c = max(xprice_per_kg_reg_cat_c)
drop xprice_per_kg_reg_cat_c 
bysort cat region migr_idp: egen xprice_per_kg_idp_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0  
bysort cat region migr_idp: egen price_per_kg_idp_cat_med = max(xprice_per_kg_idp_cat_med)
drop xprice_per_kg_idp_cat_med
bysort cat region migr_idp: egen xprice_per_kg_idp_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat region migr_idp: egen price_per_kg_idp_cat_c = max(xprice_per_kg_idp_cat_c)
drop xprice_per_kg_idp_cat_c
bysort cat: egen xprice_per_kg_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat: egen price_per_kg_cat_med = max(xprice_per_kg_cat_med)
drop xprice_per_kg_cat_med
bysort cat: egen xprice_per_kg_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat: egen price_per_kg_cat_c = max(xprice_per_kg_cat_c)
drop xprice_per_kg_cat_c
tabstat *cat_med *cat_c , s(N min p5 q p95 max)
replace  price_per_kg_cleaned =  price_per_kg_cat_med if cons==1 & replace_price==1 & tag_missing_cleaned == 1 & !missing(price_per_kg_cat_med)
replace  price_per_kg_cleaned =  price_per_kg_idp_cat_med if cons==1 & replace_price==1 &  price_per_kg_idp_cat_c>=10  & tag_missing_cleaned == 1 & !missing(price_per_kg_idp_cat_c) 
replace  price_per_kg_cleaned =  price_per_kg_reg_cat_med if cons==1 & replace_price==1 &  price_per_kg_reg_cat_c>=5 & tag_missing_cleaned == 1 & !missing(price_per_kg_reg_cat_c)  
replace  price_per_kg_cleaned =  price_per_kg_ea_cat_med if cons==1 & replace_price==1 &  price_per_kg_ea_cat_c>=5 & tag_missing_cleaned == 1 &  !missing(price_per_kg_ea_cat_c) 
*There are still a few items without cleaned prices:
*Tag these observations:
drop tag_missing_cleaned *cat*
tab itemid if missing(price_per_kg_cleaned) & cons == 1
gen tag_missing_cleaned = 1 if missing(price_per_kg_cleaned) & cons == 1 
/*
*replace the prices for missing food items to the closest four digit category:
*generate four digit categories out of 7 digit item codes:
gen cat = int(item/1000)
bysort cat StrataID ea: egen xprice_per_kg_ea_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort cat StrataID ea: egen price_per_kg_ea_cat_med = max(xprice_per_kg_ea_cat_med)
drop xprice_per_kg_ea_cat_med
bysort cat StrataID ea: egen xprice_per_kg_ea_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID ea: egen price_per_kg_ea_cat_c = max(xprice_per_kg_ea_cat_c)
drop xprice_per_kg_ea_cat_c
bysort cat StrataID camp_ref camp_hc: egen xprice_per_kg_camp_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID camp_ref camp_hc: egen price_per_kg_camp_cat_med = max(xprice_per_kg_camp_cat_med)
drop xprice_per_kg_camp_cat_med
bysort cat StrataID camp_ref camp_hc: egen xprice_per_kg_camp_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID camp_ref camp_hc: egen price_per_kg_camp_cat_c = max(xprice_per_kg_camp_cat_c)
drop xprice_per_kg_camp_cat_c 
bysort cat StrataID: egen xprice_per_kg_SID_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0  
bysort cat StrataID: egen price_per_kg_SID_cat_med = max(xprice_per_kg_SID_cat_med)
drop xprice_per_kg_SID_cat_med
bysort cat StrataID: egen xprice_per_kg_SID_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID: egen price_per_kg_SID_cat_c = max(xprice_per_kg_SID_cat_c)
drop xprice_per_kg_SID_cat_c
bysort cat: egen xprice_per_kg_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat: egen price_per_kg_cat_med = max(xprice_per_kg_cat_med)
drop xprice_per_kg_cat_med
bysort cat: egen xprice_per_kg_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat: egen price_per_kg_cat_c = max(xprice_per_kg_cat_c)
drop xprice_per_kg_cat_c
tabstat *cat_med *cat_c , s(N min p5 q p95 max)
replace  price_per_kg_cleaned =  price_per_kg_cat_med if cons==1 & replace_price==1 & tag_missing_cleaned == 1 & !missing(price_per_kg_cat_med)
replace  price_per_kg_cleaned =  price_per_kg_SID_cat_med if cons==1 & replace_price==1 &  price_per_kg_SID_cat_c>=10 & tag_missing_cleaned == 1 & !missing(price_per_kg_SID_cat_c) 
replace  price_per_kg_cleaned =  price_per_kg_camp_cat_med if cons==1 & replace_price==1 &  price_per_kg_camp_cat_c>=5 & tag_missing_cleaned == 1 & !missing(price_per_kg_camp_cat_c)  
replace  price_per_kg_cleaned =  price_per_kg_ea_cat_med if cons==1 & replace_price==1 &  price_per_kg_ea_cat_c>=5 & tag_missing_cleaned == 1 &  !missing(price_per_kg_ea_cat_c) 
*/
*make sure prices are never zero 
assert price_per_kg_cleaned!=0
tab itemid if missing(price_per_kg_cleaned) & cons == 1
drop *_med *_c tag_* *_distribution
gen tag_missing_cleaned = 1 if missing(price_per_kg_cleaned) & cons == 1 
*CHECK THESE ITEMS and replace prices if you can
drop tag_missing_cleaned
tab itemid if missing(price_per_kg_cleaned) & cons == 1 & !inrange(itemid,1,8)
gen tag_missing_cleaned = 1 if missing(price_per_kg_cleaned) & cons == 1 & !inrange(itemid,1,8)
/*
*replace the prices for missing food items to the closest four digit category:
*generate 1 digit categories out of 7 digit item codes:
gen cat = int(item/1000000)
bysort cat StrataID ea: egen xprice_per_kg_ea_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0
bysort cat StrataID ea: egen price_per_kg_ea_cat_med = max(xprice_per_kg_ea_cat_med)
drop xprice_per_kg_ea_cat_med
bysort cat StrataID ea: egen xprice_per_kg_ea_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID ea: egen price_per_kg_ea_cat_c = max(xprice_per_kg_ea_cat_c)
drop xprice_per_kg_ea_cat_c
bysort cat StrataID camp_ref camp_hc: egen xprice_per_kg_camp_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID camp_ref camp_hc: egen price_per_kg_camp_cat_med = max(xprice_per_kg_camp_cat_med)
drop xprice_per_kg_camp_cat_med
bysort cat StrataID camp_ref camp_hc: egen xprice_per_kg_camp_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID camp_ref camp_hc: egen price_per_kg_camp_cat_c = max(xprice_per_kg_camp_cat_c)
drop xprice_per_kg_camp_cat_c 
bysort cat StrataID: egen xprice_per_kg_SID_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0  
bysort cat StrataID: egen price_per_kg_SID_cat_med = max(xprice_per_kg_SID_cat_med)
drop xprice_per_kg_SID_cat_med
bysort cat StrataID: egen xprice_per_kg_SID_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat StrataID: egen price_per_kg_SID_cat_c = max(xprice_per_kg_SID_cat_c)
drop xprice_per_kg_SID_cat_c
bysort cat: egen xprice_per_kg_cat_med = median(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat: egen price_per_kg_cat_med = max(xprice_per_kg_cat_med)
drop xprice_per_kg_cat_med
bysort cat: egen xprice_per_kg_cat_c = count(price_per_kg) if replace_price==0 & price_per_kg!=0 
bysort cat: egen price_per_kg_cat_c = max(xprice_per_kg_cat_c)
drop xprice_per_kg_cat_c
tabstat *cat_med *cat_c , s(N min p5 q p95 max)
replace  price_per_kg_cleaned =  price_per_kg_cat_med if cons==1 & replace_price==1 & tag_missing_cleaned == 1 & !missing(price_per_kg_cat_med)
replace  price_per_kg_cleaned =  price_per_kg_SID_cat_med if cons==1 & replace_price==1 &  price_per_kg_SID_cat_c>=10 & tag_missing_cleaned == 1 & !missing(price_per_kg_SID_cat_c) 
replace  price_per_kg_cleaned =  price_per_kg_camp_cat_med if cons==1 & replace_price==1 &  price_per_kg_camp_cat_c>=5 & tag_missing_cleaned == 1 & !missing(price_per_kg_camp_cat_c)  
replace  price_per_kg_cleaned =  price_per_kg_ea_cat_med if cons==1 & replace_price==1 &  price_per_kg_ea_cat_c>=5 & tag_missing_cleaned == 1 &  !missing(price_per_kg_ea_cat_c)
drop tag_missing_cleaned
tab item if missing(price_per_kg_cleaned) & cons == 1
 *make sure prices are never missing for items that are consumed. 
 */
*We should check the prices with the retail price information available from CSA Ethiopia.
*assert !missing(price_per_kg_cleaned) if cons == 1 // uncomment later
*Checking food prices with food prices provided by CSA:
tabstat price_per_kg_cleaned , by(itemid) s(N min p5 q p95 max)
*drop variables used for cleaning
*drop *_med *_c replace_*
save "${gsdTemp}/foodcleaningtemp_3.dta", replace

*Clean up and save
use "${gsdTemp}/foodcleaningtemp_3.dta", clear
*Fill in zeros for non-consumed items
*Merge mod_hh variable
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta", keepusing(mod_hh) keep(match) nogen
*calculate Birr consumption and purchase values for each observation by multiplying the consumed kg quantity with the price per kg
gen cons_value = .
replace cons_value = cons_q_kg*price_per_kg_cleaned 
label var cons_value "Weekly consumption value of {product} based on quantity consumed and price paid in current Naira after cleaning"
*make sure consumption value is not missing for items that are consumed
*assert !missing(cons_value) if cons==1
*differentiate between missing values and zeros
rename mod_opt mod_item 
replace cons_value = 0 if missing(cons_value) & (mod_hh ==  mod_item)
*fill in zeros for asked but non-consumed core items
replace cons_value = 0 if missing(cons_value) & mod_item == 0
*set consumption value to missing where cons is missing
replace cons_value = . if missing(cons)
*Drop households without core consumption
bys region ea migr_idp hh: egen xcons_hh0 = sum(cons_value) if mod_item == 0
bys region ea migr_idp hh: egen cons_hh0 = max(xcons_hh0)
drop if cons_hh0==0 | missing(cons_hh0)
*drop redundant variables
drop xcons_hh0 cons_hh0 mod_hh hhsize weight 
*rename
*rename ( cons_q cons_u purc_q purc_u price price_curr) ( D_5_cons_quant D_5_cons_unit D_6_purc_quant D_6_purc_unit D_7_pric_total D_7_pric_total_curr)
rename (cons_q cons_u purc_q purc_u price price_curr) (D_1_13_cons_quant D_1_13_cons_unit D_1_15_purc_quant D_1_15_purc_unit D_1_17_pric_total D_1_17_pric_total_curr) 

*reorder
order mod_item , after(itemid)
order price_usd price_per_kg price_per_kg_cleaned cons_value , after(D_1_17_pric_total_curr)
order cons_q_kg , after(D_1_13_cons_unit)
order purc_q_kg , after(D_1_15_purc_unit)
save "${gsdData}/1-CleanTemp/food.dta" , replace

* Create tables to report the impact of cleaning
use "${gsdData}/1-CleanTemp/food.dta" , clear
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta" , assert(match using) keepusing(hhsize migr_idp) nogen
replace cons_value = cons_value/hhsize 
replace cons_value=. if cons_value==0
label var price_per_kg_cleaned "Price kg clean"
label var cons_value "Per capita consumption"
label var cons_q_kg "cons q cleaned"
label var purc_q_kg "purc q cleaned"
label var cons_q_kg_pc "cons q pc cleaned"
label var purc_q_kg_pc "purc q pc cleaned"
save "${gsdData}/1-CleanTemp/food_checking_tables.dta", replace

local va  "price_per_kg_cleaned cons_value cons_q_kg purc_q_kg cons_q_kg_pc purc_q_kg_pc" 
*Overall
set trace on
foreach v of local va {
	use  "${gsdData}/1-CleanTemp/food_checking_tables.dta" , clear
	local name : variable label `v'
	collapse (count) N = `v' (mean) mean = `v' (min) min = `v' (p1) p1 = `v' (p5) p5 = `v' (p25) p25 = `v' (p50) median = `v' (p75) p75 = `v' (p95) p95 = `v' (max) max = `v' , by(itemid)
	gsort -N 
	export excel using "${gsdOutput}/Check food cleaning.xlsx", first(var) sheet("Overall `name'") sheetreplace
}

*by IDP
use  "${gsdData}/1-CleanTemp/food_checking_tables.dta", clear
levelsof migr_idp, local(data)
foreach s of local data {
	foreach v of local va {
		use "${gsdData}/1-CleanTemp/food_checking_tables.dta" , clear
		local name : variable label `v'
		keep if migr_idp ==`s'
		collapse (count) N = `v' (mean) mean = `v' (min) min = `v' (p1) p1 = `v' (p5) p5 = `v' (p25) p25 = `v' (p50) median = `v' (p75) p75 = `v' (p95) p95 = `v' (max) max = `v' , by(itemid)
		gsort -N 
		export excel using "${gsdOutput}/Check food cleaning.xlsx", first(var) sheet("`s' `name'") sheetreplace
	}
}
* Calculate hh level aggregates 
*Calculate weekly hh consumption aggregates for each module
forval i=0/4 {
	*Load food.dta data
	use "${gsdData}\1-CleanTemp\food.dta", clear
	*Merge mod_hh variable
	merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta", keepusing(mod_hh) keep(match master) nogen	
	*Collapse on hh level for modules 0-4
	collapse mod_item mod_hh (sum) cons_value if mod_item == `i' , by(region ea migr_idp hh)
	rename cons_value food_opt`i'_hh_wk
	label var food_opt`i'_hh_wk "Total weekly consumption of module `i' in current Naira"
	save "${gsdTemp}/food_opt`i'_hh_wk.dta", replace
}
* Merge into one dataset 
use "${gsdTemp}/food_opt0_hh_wk.dta", clear
forval i=1/4 {
	merge 1:1 region ea migr_idp hh using "${gsdTemp}/food_opt`i'_hh_wk.dta", keepusing(food_opt`i'_hh_wk) keep(match master) nogen
}	
*Replace missing values with zeros where no items were consumed, but do not assume that households did not consume any food at all
forval i=1/4 {
	replace food_opt`i'_hh_wk = 0 if food_opt`i'_hh_wk  == . & mod_hh == `i'
	replace food_opt`i'_hh_wk = . if food_opt0_hh_wk == 0 | missing(food_opt0_hh_wk)
	replace food_opt`i'_hh_wk = . if mod_hh!=`i'
}
*Check for consistency
tabstat food_opt?_hh_wk, stat(n mean)
*Drop redundant variables
drop mod_hh 
save "${gsdData}/1-CleanTemp/hh_food.dta", replace 
