*This do file cleans nonfood consumption data

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
set more off, perm
set sortseed 10051990

use "${gsdData}\1-CleanInput\nfood.dta", clear
*Add variable on household module assignment and weights to calculate medians
merge m:1 migr_idp region ea hh using "${gsdData}\1-CleanInput\hh.dta", keepusing(mod_hh month hhsize migr_idp weight) assert(match master) keep(match master) nogen //add weight later
*rename variables for convenience
rename (E_2_cons E_1_5_pric_total E_1_5_pric_total_curr) (cons price curr)
gen item=itemid
assert E_1_5_pric_total_sp == "." | E_1_5_pric_total_sp == "N/A"
drop E_1_5_pric_total_sp
*Convert prices not in Naira
gen price_usd = price if curr == 2
gen price_naira = price if curr==1 
replace price_naira = price/360 if curr==2
*Analyze how many times constraints were triggered.
tab E_1_5_pric_sspperkg_high
tab E_1_5_pric_sspperkg_low
*Calculating per capita expenditure on non-food items:
gen price_naira_pc = price_naira/hhsize
merge m:1 itemid using "${gsdData}/1-CleanInput/nfood_constraints.dta", assert(match using) keep(match) nogen
*Cleaning: Tagging of outliers
* Cleaning Rules: 
* i) Tag items higher than soft constraints
gen tag_beyond_soft_max= 0 if cons==1
replace tag_beyond_soft_max  = 1 if cons==1 & price_naira_pc >v_max  & !missing(price_naira_pc)
* i) Tag items higher than hard constraints: twice the soft constraints
gen tag_beyond_hard_max= 0 if cons==1
replace tag_beyond_hard_max  = 1 if cons==1 & price_naira_pc>v_max*2  & !missing(price_naira_pc)
* ii) Tag items lower than soft minimum constraints:
gen tag_beyond_hard_min= 0 if cons==1 
replace tag_beyond_hard_min= 1 if cons==1 & price_naira_pc <v_min & !missing(price_naira_pc)
* iii) Tag items with price == 0 
gen tag_zero_price = 0 if cons==1
replace tag_zero_price = 1 if cons==1 & price_naira == 0
* iv) Tag items that were consumed but have missing price: 
gen tag_missing_price = 0 if cons==1
replace tag_missing_price = 1 if cons==1 & missing(price_naira)
*check how manny observations are affected by each cleaning rule
*Analyze the effect of replacing prices above soft constraints
local varlist "tag_beyond_hard_max tag_beyond_hard_min tag_zero_price tag_missing_price"
gen replace_price=0 if cons==1
foreach t of local varlist {
	replace replace_price = 1 if (`t'==1)
}
label var replace_price "Observation to be replaced with median"
label define ltag 0 "Not-tagged" 1 "Tagged"
label val replace_price ltag
quietly tabout replace_price using "${gsdOutput}/Cleaning/cleaning_rules-nonfood.xls" , replace c(freq col)
ds tag_*
foreach v in `r(varlist)' {
	tab `v'
	label val `v' ltag
	quietly tabout `v' using "${gsdOutput}/cleaning_rules-nonfood.xls" , append c(freq col)
}
*For now, replacing all tagged, then check how and if poverty is affected by different cleaning rules:
*Calculate weighted medians at various geographical levels, 
*Weights are not finalized for now, so for now, as it is
bysort itemid region ea: egen xprice_ea_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid region ea: egen price_ea_med = max(xprice_ea_med)
drop xprice_ea_med
bysort itemid region ea: egen xprice_ea_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid region ea: egen price_ea_c = max(xprice_ea_c)
drop xprice_ea_c
bysort itemid region migr_idp : egen xprice_idp_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid region migr_idp : egen price_idp_med = max(xprice_idp_med)
drop xprice_idp_med
bysort itemid region migr_idp: egen xprice_idp_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid region migr_idp: egen price_idp_c = max(xprice_idp_c)
drop xprice_idp_c
bysort itemid region: egen xprice_region_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid region: egen price_region_med = max(xprice_region_med)
drop xprice_region_med
bysort itemid region: egen xprice_region_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid region: egen price_region_c = max(xprice_region_c)
drop xprice_region_c
bysort itemid: egen xprice_itemid_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid: egen price_itemid_med = max(xprice_itemid_med)
drop xprice_itemid_med
bysort itemid: egen xprice_itemid_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort itemid: egen price_itemid_c = max(xprice_itemid_c)
drop xprice_itemid_c
*make sure that the median prices are never equal to zero
assert price_itemid_med!=0
*inspect medians and counts
tabstat *_med *_c , s(N min p5 q p95 max)
tab item if missing(price_itemid_med) &  cons==1 & replace_price == 1
*Tag these items
gen tagged_missing_cleaned = 1 if missing(price_itemid_med) & cons == 1 & replace_price == 1
*2-Replace outliers with median prices as calculated above
*check how many items will be affected
tab replace_price
* Use median prices from smallest geo level where min # of 10 obs are available
gen price_naira_pc_cleaned = price_naira_pc if (cons==1) & replace_price == 0
*replace prices above maximum constraint
replace  price_naira_pc_cleaned =  price_itemid_med if (replace_price==1)  										
replace  price_naira_pc_cleaned =  price_region_med if (replace_price==1 &  price_region_c>=10 & price_region_med!=0 & !missing(price_region_med))
replace  price_naira_pc_cleaned =  price_idp_med if (replace_price==1 &  price_idp_c>=5 & price_idp_med!=0 & !missing(price_idp_med))
replace  price_naira_pc_cleaned =  price_ea_med if (replace_price==1 &  price_ea_c>=5 & price_ea_med!=0 & !missing(price_ea_med))
*3-Check effect of cleaning on price variables:
tabstat price_naira_pc price_naira_pc_cleaned, by(itemid) stat(N mean min p1 p5 q p95 p99 max) col(stat)
*assert prices are not missing if tagged
*assert !missing(price_naira_pc_cleaned) if cons==1
*drop variables used for cleaning in this section
drop *_idp_* *_ea* *_region* *_itemid*
*Replacing prices by the medians of the categories: extract 5 digit categories from 7 digit itemcodes:
gen nfcat = int(itemid/100)
*Generating medians by categories:
bysort nfcat region ea: egen xprice_ea_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region ea: egen price_ea_cat_med = max(xprice_ea_cat_med)
drop xprice_ea_cat_med
bysort nfcat region ea: egen xprice_ea_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region ea: egen price_ea_cat_c = max(xprice_ea_c)
drop xprice_ea_c
bysort nfcat region migr_idp: egen xprice_idp_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region migr_idp: egen price_idp_cat_med = max(xprice_idp_cat_med)
drop xprice_idp_cat_med
bysort nfcat region migr_idp: egen xprice_idp_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region migr_idp: egen price_idp_cat_c = max(xprice_idp_c)
drop xprice_idp_c
bysort nfcat region: egen xprice_region_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region: egen price_region_cat_med = max(xprice_region_cat_med)
drop xprice_region_cat_med
bysort nfcat region: egen xprice_region_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region: egen price_region_cat_c = max(xprice_region_c)
drop xprice_region_c
bysort nfcat: egen xprice_nfcat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat: egen price_nfcat_med = max(xprice_nfcat_med)
drop xprice_nfcat_med
bysort nfcat: egen xprice_nfcat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat: egen price_nfcat_c = max(xprice_nfcat_c)
drop xprice_nfcat_c
*make sure that the median prices are never equal to zero
assert price_nfcat_med!=0
*inspect medians and counts
tabstat *_med *_c , s(N min p5 q p95 max)
tab item if missing(price_nfcat_med) &  cons==1 & tagged_missing_cleaned == 1
assert !missing(price_nfcat_med) if cons==1 & tagged_missing_cleaned == 1
gen tagged_missing_cleaned_2 = 1 if missing(price_nfcat_med) & cons == 1 & tagged_missing_cleaned ==1
*2-Replace missing with median prices of that category as calculated above
* Use median prices from smallest geo level where min # of 10 obs are available
replace  price_naira_pc_cleaned =  price_nfcat_med if (tagged_missing_cleaned == 1)  & missing(price_naira_pc_cleaned) & cons == 1 										
replace  price_naira_pc_cleaned =  price_region_cat_med if (tagged_missing_cleaned == 1 &  price_region_cat_c>=10 & price_region_cat_med!=0 & !missing(price_region_cat_med) & cons == 1)
replace  price_naira_pc_cleaned =  price_idp_cat_med if (tagged_missing_cleaned==1 &  price_idp_cat_c>=5 & price_idp_cat_med!=0 & !missing(price_idp_cat_med) & cons == 1)
replace  price_naira_pc_cleaned =  price_ea_cat_med if (tagged_missing_cleaned==1 &  price_ea_cat_c>=5 & price_ea_cat_med!=0 & !missing(price_ea_cat_med) & cons == 1)
*3-Check effect of cleaning on price variables:
tabstat price_naira_pc price_naira_pc_cleaned, by(itemid) stat(N mean min p1 p5 q p95 p99 max) col(stat)
*qui tabout itemid using "${gsdTemp}/Check_Price_nf.xls", sum oneway cells(mean price_naira mean price_naira_cleaned min price_naira min price_naira_cleaned p5 price_naira p5 price_naira_cleaned p95 price_naira p95 price_naira_cleaned p99 price_naira p99 price_naira_cleaned max price_naira max price_naira_cleaned ) h1(Checking prices after cleaning) replace
assert !missing(price_naira_pc_cleaned) if replace_price==1 & cons==1 
*drop variables used for cleaning in this section
drop *_idp_* *_ea* *_region* *_nfcat* nfcat
drop tagged_missing_cleaned
*Replacing prices by the medians of the categories: extract 4 digit categories from 7 digit itemcodes:
gen nfcat = int(itemid/1000)
*Generating medians by categories:
bysort nfcat region ea: egen xprice_ea_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region ea: egen price_ea_cat_med = max(xprice_ea_cat_med)
drop xprice_ea_cat_med
bysort nfcat region ea: egen xprice_ea_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region ea: egen price_ea_cat_c = max(xprice_ea_c)
drop xprice_ea_c
bysort nfcat region migr_idp: egen xprice_idp_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region migr_idp: egen price_idp_cat_med = max(xprice_idp_cat_med)
drop xprice_idp_cat_med
bysort nfcat region migr_idp: egen xprice_idp_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region migr_idp: egen price_idp_cat_c = max(xprice_idp_c)
drop xprice_idp_c
bysort nfcat region: egen xprice_region_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region: egen price_region_cat_med = max(xprice_region_cat_med)
drop xprice_region_cat_med
bysort nfcat region: egen xprice_region_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat region: egen price_region_cat_c = max(xprice_region_c)
drop xprice_region_c
bysort nfcat: egen xprice_nfcat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat: egen price_nfcat_med = max(xprice_nfcat_med)
drop xprice_nfcat_med
bysort nfcat: egen xprice_nfcat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat: egen price_nfcat_c = max(xprice_nfcat_c)
drop xprice_nfcat_c
*make sure that the median prices are never equal to zero
assert price_nfcat_med!=0
*inspect medians and counts
tabstat *_med *_c , s(N min p5 q p95 max)
tab item if missing(price_nfcat_med) &  cons==1 & tagged_missing_cleaned_2 == 1
assert !missing(price_nfcat_med) if cons==1
gen tagged_missing_cleaned_3 = 1 if missing(price_nfcat_med) & cons == 1 
*2-Replace missing with median prices of that category as calculated above
* Use median prices from smallest geo level where min # of 10 obs are available
replace  price_naira_pc_cleaned =  price_nfcat_med if (tagged_missing_cleaned_2 == 1)  & missing(price_naira_pc_cleaned)										
replace  price_naira_pc_cleaned =  price_region_cat_med if (tagged_missing_cleaned_2 == 1 &  price_region_cat_c>=10 & price_region_cat_med!=0 & !missing(price_region_cat_med))
replace  price_naira_pc_cleaned =  price_idp_cat_med if (tagged_missing_cleaned_2==1 &  price_idp_cat_c>=5 & price_idp_cat_med!=0 & !missing(price_idp_cat_med))
replace  price_naira_pc_cleaned =  price_ea_cat_med if (tagged_missing_cleaned_2==1 &  price_ea_cat_c>=5 & price_ea_cat_med!=0 & !missing(price_ea_cat_med))
*3-Check effect of cleaning on price variables:
tabstat price_naira_pc price_naira_pc_cleaned, by(itemid) stat(N mean min p1 p5 q p95 p99 max) col(stat)
assert !missing(price_naira_pc_cleaned) if replace_price==1 & cons==1 
*drop variables used for cleaning in this section
drop *_idp_* *_ea* *_region* *_nfcat* nfcat
drop tagged_missing_cleaned_2

/*
*Replacing prices by the medians of the categories: extract 3 digit categories from 7 digit itemcodes:
gen nfcat = int(itemid/10000)
*Generating medians by categories:
bysort nfcat StrataID ea: egen xprice_ea_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat StrataID ea: egen price_ea_cat_med = max(xprice_ea_cat_med)
drop xprice_ea_cat_med
bysort nfcat StrataID ea: egen xprice_ea_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat StrataID ea: egen price_ea_cat_c = max(xprice_ea_c)
drop xprice_ea_c
bysort nfcat StrataID camp_ref camp_hc: egen xprice_idp_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat StrataID camp_ref camp_hc: egen price_idp_cat_med = max(xprice_idp_cat_med)
drop xprice_idp_cat_med
bysort nfcat StrataID camp_ref camp_hc: egen xprice_idp_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat StrataID camp_ref camp_hc: egen price_idp_cat_c = max(xprice_idp_c)
drop xprice_idp_c
bysort nfcat StrataID: egen xprice_region_cat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat StrataID: egen price_region_cat_med = max(xprice_region_cat_med)
drop xprice_region_cat_med
bysort nfcat StrataID: egen xprice_region_cat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat StrataID: egen price_region_cat_c = max(xprice_region_c)
drop xprice_region_c
bysort nfcat: egen xprice_nfcat_med = median(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat: egen price_nfcat_med = max(xprice_nfcat_med)
drop xprice_nfcat_med
bysort nfcat: egen xprice_nfcat_c = count(price_naira_pc) if replace_price==0 & price_naira_pc!=0
bysort nfcat: egen price_nfcat_c = max(xprice_nfcat_c)
drop xprice_nfcat_c
*make sure that the median prices are never equal to zero
assert price_nfcat_med!=0
*inspect medians and counts
tabstat *_med *_c , s(N min p5 q p95 max)
tab item if missing(price_nfcat_med) &  cons==1
assert !missing(price_nfcat_med) if cons==1
*2-Replace missing with median prices of that category as calculated above
* Use median prices from smallest geo level where min # of 10 obs are available
replace  price_naira_pc_cleaned =  price_nfcat_med if (tagged_missing_cleaned_3 == 1)  & missing(price_naira_pc_cleaned)										
replace  price_naira_pc_cleaned =  price_region_cat_med if (tagged_missing_cleaned_3 == 1 &  price_region_cat_c>=10 & price_region_cat_med!=0 & !missing(price_region_cat_med))
replace  price_naira_pc_cleaned =  price_idp_cat_med if (tagged_missing_cleaned_3==1 &  price_idp_cat_c>=5 & price_idp_cat_med!=0 & !missing(price_idp_cat_med))
replace  price_naira_pc_cleaned =  price_ea_cat_med if (tagged_missing_cleaned_3==1 &  price_ea_cat_c>=5 & price_ea_cat_med!=0 & !missing(price_ea_cat_med))
*3-Check effect of cleaning on price variables:
tabstat price_naira_pc price_naira_pc_cleaned, by(itemid) stat(N mean min p1 p5 q p95 p99 max) col(stat)
*/
*make sure that prices are never zero
assert price_naira_pc_cleaned!=0
su price_naira_pc_cleaned
label var price_naira_pc_cleaned "Per capita expenditure on item in current Naira after cleaning"
*Transform annual consumptions into monthly consumptions
gen price_naira_pc_monthly_cleaned = price_naira_pc_cleaned/12 if cons==1 & _item_recall==365
replace price_naira_pc_monthly_cleaned = price_naira_pc_cleaned if cons==1 & _item_recall==30
replace price_naira_pc_monthly_cleaned = price_naira_pc_cleaned/6 if cons==1 & _item_recall==180
replace price_naira_pc_monthly_cleaned = price_naira_pc_cleaned*4.33 if cons==1 & _item_recall==7

*Transform monthly consumptions into weekly consumptions
gen cons_value_pc = price_naira_pc_monthly_cleaned*12/365.25*7 if cons==1 
gen cons_value = cons_value_pc * hhsize
gen price_naira_cleaned = price_naira_pc_cleaned * hhsize
label var cons_value "Weekly consumption value in current Naira"
label var price_naira_cleaned "Price in current Naira after cleaning"
*drop variables used for cleaning in this section
drop price_naira *_monthly* tag_* replace_*  *_usd 
save "${gsdTemp}/hh_nfood.dta", replace
*Clean up and save
*drop households without any core food consumption
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_food.dta", assert(match master) keep(master match) keepusing(food_opt0_hh_wk)
*drop if food_opt0_hh_wk==0
drop food_opt0_hh_wk
*Replace missing values with zeros where no items were consumed, 
rename mod_opt mod_item
replace cons_value = 0 if (missing(cons_value) & mod_item == 0 ) | ( missing(cons_value) & mod_item==mod_hh)
*Set cons_value to missing where cons is missing, but make sure that it results in no loss of information
assert missing(price) & missing(price_naira_pc_cleaned)  if missing(cons)
replace cons_value = . if missing(cons)
*make sure that consumption value is missing for the modules not asked to households
assert missing(cons_value) if mod_hh!=mod_item & mod_item!=0
*rename
rename  (price curr) ( E_1_5_pric_total E_1_5_pric_total_curr) 
*drop redundant variables
drop mod_hh month hhsize item weight 
*reorder and save
order price_naira_pc_cleaned, after(E_1_5_pric_total)
order cons_value, after(cons)
drop _merge
save "${gsdData}/1-CleanTemp/nonfood.dta", replace 

* Calculate hh aggregates 
*Calculate weekly hh consumption aggregates for each module
forval i=0/4 {
	*Load nonfood.dta data
	use "${gsdData}/1-CleanTemp/nonfood.dta", clear
	*get mod_hh variable
	merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta",  assert(match using) keep(match master) keepusing(mod_hh) nogen
	*Collapse on hh level for modules 0-4
	collapse mod_item mod_hh (sum) cons_value if mod_item == `i' , by(region ea migr_idp hh)
	rename cons_value nonfood_opt`i'_hh_wk
	save "${gsdTemp}/nonfood_opt`i'_hh_wk.dta", replace
}
*Merge into one dataset 
use "${gsdTemp}/nonfood_opt0_hh_wk.dta", clear
forval i=1/4 {
	merge 1:1 region ea migr_idp hh using "${gsdTemp}/nonfood_opt`i'_hh_wk.dta", keepusing(nonfood_opt`i'_hh_wk) keep(match master) assert(match master) nogen
}	
forvalues i = 1/4 {
	replace nonfood_opt`i'_hh_wk = . if mod_hh!=`i'
}
*/
*Check for consistency
tabstat nonfood_opt?_hh_wk, stat(n mean)
*drop redundant variables	
*drop  food_opt0_hh_wk mod_hh 
*/
save "${gsdData}/1-CleanTemp/hh_nonfood.dta", replace 

* Create tables to report the impact of cleaning
use "${gsdData}/1-CleanTemp/nonfood.dta" , clear
merge m:1 region ea hh migr_idp using "${gsdData}/1-CleanInput/hh.dta" , assert(match using) keepusing(hhsize) keep(match) nogen
replace cons_value = cons_value/hhsize 
replace cons_value=. if cons_value==0
label var price_naira_pc_cleaned "Price per capita clean"
label var cons_value "HH consumption pc"
save "${gsdTemp}/nonfood_checking_tables.dta", replace
local va  "price_naira_pc_cleaned cons_value" 
*Overall
foreach v of local va {
	use  "${gsdTemp}/nonfood_checking_tables.dta" , clear
	local name : variable label `v'
	collapse (count) N = `v' (mean) mean = `v' (min) min = `v' (p1) p1 = `v' (p5) p5 = `v' (p25) p25 = `v' (p50) median = `v' (p75) p75 = `v' (p95) p95 = `v' (max) max = `v' , by(itemid)
	gsort -N 
	export excel using "${gsdOutput}/Check nonfood cleaning.xlsx", first(var) sheet("Overall `name'") sheetreplace
}
*by idp
use  "${gsdTemp}/nonfood_checking_tables.dta", clear
levelsof migr_idp, local(idp)
foreach s of local Refugee {
	foreach v of local va {
		use "${gsdTemp}/nonfood_checking_tables.dta" , clear
		local name : variable label `v'  
		keep if migr_idp ==`s'
		collapse (count) N = `v' (mean) mean = `v' (min) min = `v' (p1) p1 = `v' (p5) p5 = `v' (p25) p25 = `v' (p50) median = `v' (p75) p75 = `v' (p95) p95 = `v' (max) max = `v' , by(itemid)
		gsort -N 
		export excel using "${gsdOutput}/Check nonfood cleaning.xlsx", first(var) sheet("`s' `name'") sheetreplace
	}
}
 