*This do file cleans assets data
*Steps:
*Clean currencies reported in the data
*Clean year of purchase reported in the data
*Clean quantities of assets owned
*Clean prices reported in the data
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Currencies: identification, labelling, and currency conversion
use "${gsdData}/1-CleanInput/assets.dta", clear
rename (G_1_own_yn G_1_2_owntotal G_1_4_ynew  G_1_5_prnew G_1_5_prnew_curr G_1_5_prnew_sp G_1_9_sellnew G_1_9_sellnew_curr G_1_9_sellnew_sp G_11_own_prev_yn G_1_12_owntotal_prev) (own owntotal year_purc price_purc curr_purc price_purc_curr_sp price_sell curr_sell price_sell_curr_sp own_pre owntotal_pre)
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta", assert(match) keep(match) keepusing(month) nogen
tab curr_purc
*replace curr_purc = 9 if strpos(price_purc_curr_sp,"sudden") | strpos(price_purc_curr_sp,"Sudan") | strpos(price_purc_curr_sp,"Sudden")
*label values curr_purc lcurr
*label values curr_sell lcurr 
*label values G_10_sellall_curr lcurr
*There are wrong year entries in the data:
*replace wrong year entries by missing
*replace year_purc = . if year_purc < 1960

*Identify and replace outliers - Quantities
*use "${gsdTemp}/assets_cleaning1.dta" , clear
*inspect ownership statistics and prices
tabstat owntotal if own==1, by(assets__id) stat(N mean min p5 q p95 max) columns(statistics)
tabstat owntotal_pre if own_pre==1, by(assets__id) stat(N mean min p5 q p95 max) columns(statistics)
*Tag values that need to be cleaned
*rename for looping
rename (own owntotal) (own_now owntotal_now)
*loop over cleaning rules
local ls = "pre now"
foreach s of local ls {
	*tag as outlier quantity ownership of more than 100 of a single asset
	local outlier = 100
	gen tag_outlier_owntotal_`s' = 0 
	replace tag_outlier_owntotal_`s' = 1 if owntotal_`s'>`outlier' & !missing(owntotal_`s') & own_`s'==1
	*tag missing quantities
	gen tag_missing_q_`s' = 0 if own_`s'==1
	replace tag_missing_q_`s' = 1 if missing(owntotal_`s') & own_`s'==1 
	*tag negative or zero quantities
	gen tag_zero_q_`s' = 0 if own_`s'==1
	replace tag_zero_q_`s' = 1 if owntotal_`s'<1 & own_`s'==1 	
}
gen tagged_pre = 0 if own_pre == 1
replace tagged_pre = 1 if tag_outlier_owntotal_pre == 1
replace tagged_pre = 1 if tag_missing_q_pre == 1
replace tagged_pre = 1 if tag_zero_q_pre == 1
gen tagged_now = 0 if own_now == 1
replace tagged_now = 1 if tag_outlier_owntotal_now == 1
replace tagged_now = 1 if tag_missing_q_now == 1
replace tagged_now = 1 if tag_zero_q_now == 1
*calculate medians
local ls = "pre now"
foreach s of local ls {
	bysort assets__id: egen owntotal_`s'_Id_med_x = median(owntotal_`s') if own_`s'==1 & tagged_`s' == 0
	*Propagate to all:
	bysort assets__id: egen owntotal_`s'_Id_med = max(owntotal_`s'_Id_med_x)
	drop owntotal_`s'_Id_med_x
	assert owntotal_`s'_Id_med!=0
	assert !missing(owntotal_`s'_Id_med) if own_`s' == 1
}

*replace quantities
local ls = "pre now"
foreach s of local ls {
	replace owntotal_`s' = owntotal_`s'_Id_med if tag_outlier_owntotal_`s'==1 & own_`s'==1 
	replace owntotal_`s' = owntotal_`s'_Id_med if tag_missing_q_`s'==1 & own_`s'==1 
	replace owntotal_`s' = owntotal_`s'_Id_med if tag_zero_q_`s'==1 & own_`s'==1 
}
rename (own_now owntotal_now) (own owntotal) 
label var owntotal "Number of asset owned today after cleaning"
label var owntotal_pre "Number of asset owned before the conflict after cleaning"
*inspect ownership statistics and prices
tabstat owntotal owntotal_pre, by(assets__id) stat(N mean min p5 q p95 max) columns(statistics)
*checks
assert owntotal!=0 if own==1
assert !missing(owntotal) if own==1
assert owntotal_pre!=0 if own_pre==1
assert !missing(owntotal_pre) if own_pre==1
drop tag* *_med 
save "${gsdTemp}/assets_cleaning1.dta" , replace

*Identify and replace outliers - Prices
use "${gsdTemp}/assets_cleaning1.dta" , clear
*check prices
gen price_purc_naira = price_purc if curr_purc == 1
gen price_sell_naira = price_sell if curr_sell == 1
tabstat price_purc_naira if own==1, by(assets__id) s(N mean min p5 q p95 max) 
tabstat price_sell_naira if own==1, by(assets__id) s(N mean min p5 q p95 max)
*Manually tag prices in naira that are clear outliers or incorrect entries:
gen replace_price_purc = 0 if missing(price_purc_naira)
*replace replace_price_purc = 1 if Id == 22 & price_purc_naira >=30000 & !missing(price_purc_naira)
*Looking at kdensity graphs for each and at the data. *Correcting outliers. No obvious outliers
*Tag prices above and below 3 standard deviations of the mean prices:
*Calculating mean price over all items and then observing the data outside 3 standard deviations.
local ls = "sell"
foreach s of local ls{
	bysort assets__id: egen price_`s'_naira_mean = mean(price_`s'_naira) 
	bysort assets__id: egen price_`s'_naira_sd = sd(price_`s'_naira)
	bysort assets__id: gen price_`s'_naira_z = (price_`s'_naira - price_`s'_naira_mean)/price_`s'_naira_sd
	gen tag_`s'_top3sd = 1 if price_`s'_naira_z > 3 & !missing(price_`s'_naira_z) & own == 1 
	replace tag_`s'_top3sd = 0 if tag_`s'_top3sd != 1 & own == 1
	gen tag_`s'_bottom3sd = 1 if price_`s'_naira_z < -3 & !missing(price_`s'_naira_z) & own == 1 
	replace tag_`s'_bottom3sd = 0 if tag_`s'_bottom3sd != 1 & own == 1
}
gen replace_price_sell = 0
replace replace_price_sell = 1 if tag_sell_top3sd == 1 | tag_sell_bottom3sd == 1
tab replace_price_purc if own==1
tab replace_price_sell if own==1
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
label val replace_* ltag 
label var replace_price_purc "Purchase price to be replaced with median"
label var replace_price_sell "Selling price to be replaced with median"
quietly tabout replace_price_purc using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, replace c(freq col)
quietly tabout replace_price_sell using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
local ls = "purc sell"
foreach t of local ls {
	local rules = "replace_price_`t'"
	foreach r of local rules {
		quietly tabout `r' using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
	}
}
*calculate medians and counts at the item level and at the item-StrataID level, add medians at the item-year level for purchase prices
local ls = "purc sell"
foreach t of local ls {
	*calculate median only for nontagged observations 
	*state
	bysort assets__id region: egen xprice_`t'_naira_region_med = median(price_`t'_naira) if replace_price_`t'==0
	bysort assets__id region: egen price_`t'_naira_region_med = max(xprice_`t'_naira_region_med)	
	bysort assets__id region: egen xprice_`t'_naira_region_c = count(price_`t'_naira) if replace_price_`t'==0
	bysort assets__id region: egen price_`t'_naira_region_c = max(xprice_`t'_naira_region_c)
	*dataset level, i.e. IDP or not
	bysort assets__id migr_idp: egen xprice_`t'_naira_idp_med = median(price_`t'_naira) if price_`t'_naira!=0 & replace_price_`t'==0
	bysort assets__id migr_idp: egen price_`t'_naira_idp_med = max(xprice_`t'_naira_idp_med)
	bysort assets__id migr_idp: egen xprice_`t'_naira_idp_c = count(price_`t'_naira) if price_`t'_naira!=0 & replace_price_`t'==0
	bysort assets__id migr_idp: egen price_`t'_naira_idp_c = max(xprice_`t'_naira_idp_c)
	*asset level
	bysort assets__id: egen xprice_`t'_naira_Id_med = median(price_`t'_naira) if replace_price_`t'==0 & !missing(price_`t'_naira)
	bysort assets__id: egen price_`t'_naira_Id_med = max(xprice_`t'_naira_Id_med)
	bysort assets__id: egen xprice_`t'_naira_Id_c = count(price_`t'_naira) if price_`t'_naira!=0 & replace_price_`t'==0
	bysort assets__id: egen price_`t'_naira_Id_c = max(xprice_`t'_naira_Id_c)
	if "`t'"=="purc" {
	*asset year level
		bysort assets__id year_purc: egen xprice_`t'_naira_year_med = median(price_`t'_naira) if price_`t'_naira!=0 & replace_price_`t'==0
		bysort assets__id year_purc: egen price_`t'_naira_year_med = max(xprice_`t'_naira_year_med)
		bysort assets__id year_purc: egen xprice_`t'_naira_year_c = count(price_`t'_naira) if price_`t'_naira!=0 & replace_price_`t'==0
		bysort assets__id year_purc: egen price_`t'_naira_year_c = max(xprice_`t'_naira_year_c)	
	}
	drop x*
}
*make sure prices at least at Id level are not zero or missing
assert price_purc_naira_Id_med!=0 
assert price_sell_naira_Id_med!=0 
*We do not have prices for weaving equipment and block production equipment.
*assert !missing(price_purc_naira_Id_med) if own==1 
tab assets__id if missing(price_sell_naira_Id_med)
*assert !missing(price_sell_naira_Id_med) if own==1 
*replace purchase prices
gen long price_purc_naira_cleaned=price_purc_naira
replace price_purc_naira_cleaned = price_purc_naira_Id_med if replace_price_purc==1 & own==1
replace price_purc_naira_cleaned = price_purc_naira_region_med if replace_price_purc==1 & own==1 & price_purc_naira_region_c>7 & !missing(price_purc_naira_region_c) &!missing(price_purc_naira_region_med) & price_purc_naira_region_med!=0
replace price_purc_naira_cleaned = price_purc_naira_idp_med if replace_price_purc==1 & own==1 & price_purc_naira_idp_c>5 & !missing(price_purc_naira_idp_c) &!missing(price_purc_naira_idp_med) & price_purc_naira_idp_med!=0
replace price_purc_naira_cleaned = price_purc_naira_year_med if replace_price_purc==1 & own==1 & price_purc_naira_year_c>3 & !missing(price_purc_naira_year_c) & !missing(price_purc_naira_year_med) & price_purc_naira_year_med!=0
label var price_purc_naira_cleaned "Price of asset when purchased in naira after cleaning"
*replace selling prices
tab replace_price_sell
gen long price_sell_naira_cleaned=price_sell_naira
replace price_sell_naira_cleaned = price_sell_naira_Id_med if replace_price_sell==1 & own==1
replace price_sell_naira_cleaned = price_sell_naira_region_med if replace_price_sell==1 & own==1 & price_sell_naira_region_c>7 & !missing(price_sell_naira_region_c)  &!missing(price_sell_naira_region_med) & price_sell_naira_region_med!=0
replace price_sell_naira_cleaned = price_sell_naira_idp_med if replace_price_sell==1 & own==1 & price_sell_naira_idp_c>5 & !missing(price_sell_naira_idp_c) &!missing(price_sell_naira_idp_med) & price_sell_naira_idp_med!=0
label var price_sell_naira_cleaned "Selling price of {asset} today in current naira after cleaning"
*check impact of cleaning
*check prices
tabstat price_purc_naira price_purc_naira_cleaned , by(assets__id) s(N mean min p5 q p95 max) col(stat) 
tabstat price_sell_naira price_sell_naira_cleaned , by(assets__id) s(N mean min p5 q p95 max) col(stat) 
*check that prices are never zero
assert price_purc_naira_cleaned!=0
assert price_sell_naira_cleaned!=0
*check evolution of prices over the years 
table year_purc assets__id, c(median price_purc_naira_cleaned) f(%10.0f) concise m
*drop redundant variables
drop *_med *_c replace_*
save "${gsdTemp}/assets_cleaning2.dta" , replace

*Calculate depreciation rates 
use "${gsdTemp}/assets_cleaning2.dta" , clear
*Calculate vintages. Note that as soon items are purchased, it is considered 
*one year old due to loss in value. I.e. items bought in 2018 are one year old.
gen year = 2018
gen vintage =(year-year_purc)+1
*Calculate vintage medians and replace where missing
bysort assets__id: egen vintage_median=median(vintage)
gen tag_missing_vintage = 0 if own==1 
replace tag_missing_vintage =1 if missing(vintage) & own==1
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
label val tag_missing_vintage ltag
quietly tabout tag_missing_vintage using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
*Set missing vintages to medians
replace vintage = vintage_median if missing(vintage) & own==1
*Label variables
lab var vintage "Years since newest {asset} was purchased, after cleaning"
drop vintage_median 
*calculate depreciation rate
*CAGR   =   (FV / PV)^(1 / Y)  -  1
*Assume constant asset-specific inflation rate of pi= 12.06%
*	97 percent of assets were purchased after 2010, 12.06% is the annual compound growth rate of the CPI rate between the CPI in 2010 and 2018
local pi = 0.1206 
*Estimate formula from Deaton and Zaidi (2002)
*Look to verify what cleaning operations should be performed.
gen drate= 1 - (1/(1+`pi'))*(price_sell_naira_cleaned/price_purc_naira_cleaned)^(1/vintage)
*clean depreciation rate:
tabstat drate, stat(n mean min p5 q p95 max) by(assets__id)
*Convert drate to missing if 
* 1) calculated drate is negative:
gen tag_neg_drate=(drate<0)
label val tag_neg_drate ltag
quietly tabout tag_neg_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
replace drate=. if drate<0
* 2) calculated drate is in top of dist despite small vintages; or 
* 3) calculated drate is in bottom of dist despite large vintages:
cumul drate if !missing(drate), gen (drate_distribution) equal
label define ldum_distr 1 "Bottom 10% (0)"  2 "Top 10% (1)"
gen dum_distr=2 if drate_distribution>=.9 & !missing(drate_distribution)
replace dum_distr=1 if drate_distribution<=.1 & !missing(drate_distribution)
label var dum_distr "Observation in top/bottom of distribution"
label values dum_distr ldum_distr
*replace inconsistent cases in the top of the drate distribution
gen tag_high_drate = 0 if own==1
replace tag_high_drate = 1 if dum_distr==2 & vintage==1
tab tag_high_drate
label val tag_high_drate ltag
quietly tabout tag_high_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
*replace inconsistent cases in the bottom of the drate distribution
gen tag_low_drate= 0 if own==1
replace tag_low_drate=1 if dum_distr==1 & vintage>=3
tab tag_low_drate
label val tag_low_drate ltag
quietly tabout tag_low_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
*calculate median depreciation rates by item where >= 3 observations avail.
bysort assets__id: egen drate_count=count(drate) 
bysort assets__id: egen drate_median=median(drate) if drate_count>=2 
*Set missing depreciation rates to median rates calculated above, check them
gen tag_missing_drate=0 if own==1
replace tag_missing_drate=1 if own==1 & missing(drate)
tab tag_missing_drate
label val tag_missing_drate ltag
quietly tabout tag_missing_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
replace drate = drate_median if missing(drate) & own==1 
replace drate = drate_median if (tag_high_drate==1 | tag_low_drate==1) & own==1
lab var drate "Depreciation rate for each durable item by household, after cleaning"
lab var drate_median "Median depreciation rate for each durable item"
* Summarise the median depreciation rates in a table 
drop drate_median
bysort assets__id: egen drate_median=median(drate) if drate_count>=2
*collapse drate_median, by(assets__id)
*export excel Id drate_median using "${gsdTemp}/drate.xls", replace firstrow(variables)
tabstat drate, stat(n mean min p5 q p95 max) by(assets__id)
*drop variables needed for cleaning
drop tag_* drate_count dum_distr drate_distribution 
table assets__id, c(median drate_median) format (%10.2f)
save "${gsdTemp}/assets_cleaning3.dta" , replace 

*Calculate consumption flow 
use "${gsdTemp}/assets_cleaning3.dta" , clear
*We assume a real interest rate of 5%, based on nominal interest rate of i=pi+5%
*Assume constant asset-specific inflation rate of pi=12.06%
*	97 percent of assets were purchased after 2010, 12.06% is the annual compound growth rate of the CPI rate between the CPI in 2010 and 2018
local pi = 0.1306 //CHANGE THIS LATER!
local r = .05
*Calculate user cost (consumption flows) per item & vintage using depreciation rates
gen cons_flow = (price_sell_naira_cleaned/(1-drate_median+`pi'))*(`r' + drate_median)
label var cons_flow "Consumption flow from ownership of single asset, yearly"
tabstat cons_flow , s(N mean min p5 q p95 max) col(stat) by(assets__id) format(%9.3f)
*generate consumption flow to check (per day in naira)
gen check_flow=cons_flow/356/23
tabstat check_flow , s(N mean min p5 q p95 max) col(stat) by(assets__id) format(%9.3g)
drop check_flow
*Calculate median consumption flow per item & vintage
bysort assets__id vintage: egen cons_flow_median = median(cons_flow)
lab var cons_flow_median "Median consumption flow"
*Now we estimate the final consumption flow of durable goods, taking into account
*ownership of more than one item
gen cons_d_yearly = (price_sell_naira_cleaned/(1-drate_median+`pi'))*(`r' + drate_median) if owntotal==1 & own==1
replace cons_d_yearly = (price_sell_naira_cleaned/(1-drate_median+`pi'))*(`r' + drate_median) + ((owntotal-1)*cons_flow_median) if owntotal>=2 & own==1
label var cons_d_yearly "Consumption flow of durables (yearly) naira" 
*inspect
tabstat cons_d_yearly , s(N mean min p5 q p95 max) col(stat) by(assets__id)
tabstat cons_d_yearly , s(N mean min p5 q p95 max) col(stat)
*Calculate weekly and daily consumption flow 
*Convert from annual to weekly
gen cons_d_weekly=cons_d_yearly/365.25*7
label var cons_d_weekly "Consumption flow of durables (weekly) naira" 
gen cons_d_daily=cons_d_yearly/365.25
label var cons_d_daily "Consumption flow of durables (daily) naira" 
*Calculate per capita consumption flow
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta", keepusing(hhsize) assert(match) keep(match) nogen
gen cons_d_daily_pc=cons_d_daily/hhsize
label var cons_d_daily_pc "Consumption flow of durables (daily) per capita naira" 
drop hhsize month year 

*Clean up and save
rename (own owntotal year_purc price_purc curr_purc price_purc_curr_sp price_sell curr_sell price_sell_curr_sp own_pre owntotal_pre) (G_1_own_yn G_1_2_owntotal G_1_4_ynew  G_1_5_prnew G_1_5_prnew_curr G_1_5_prnew_sp G_1_9_sellnew G_1_9_sellnew_curr G_1_9_sellnew_sp G_1_12_own_prev_yn G_1_13_owntotal_prev) 
*reorder
order price_purc_* , after(G_1_5_prnew)
order price_sell_* , after(G_1_9_sellnew)
order vintage drate* , after(G_1_4_ynew)
order cons_* , before(G_1_10_sellall)

*Construct asset index:
bysort region ea migr_idp hh: egen asset_index_current = total( G_1_2_owntotal* price_sell_naira_cleaned)
save "${gsdData}/1-CleanOutput/assets.dta", replace
*and calculate aggregates
use "${gsdData}/1-CleanOutput/assets.dta" , clear
collapse (sum) assets_hh_wk = cons_d_weekly (mean) asset_index_current, by(region ea migr_idp hh)
label var assets_hh_wk  "Household weekly consumption flow of durable items"
save "${gsdData}/1-CleanTemp/hh_assets.dta", replace
* Create tables to report the impact of cleaning
use "${gsdData}/1-CleanOutput/assets.dta" , clear
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta" , assert(match using) keep(match) keepusing(hhsize) nogen
gen cons = cons_d_weekly/hhsize 
replace cons=. if cons_d_weekly==0
label var price_purc_naira_cleaned "Purchase price clean"
label var price_sell_naira_cleaned "Selling price clean"
label var cons "HH weekly consflow pc"
gen cons_naira = cons/120 
label var cons_naira "weekly consflow pc naira"
label var cons_d_weekly "HH weekly consflow"
save "${gsdData}/1-CleanTemp/assets_checking_tables.dta", replace
local va  "price_purc_naira_cleaned price_sell_naira_cleaned cons_d_weekly cons cons_naira" 
/*
*Overall
foreach v of local va {
	use  "${gsdData}/1-CleanTemp/assets_checking_tables.dta" , clear
	local name : variable label `v'
	collapse (count) N = `v' (mean) mean = `v' (min) min = `v' (p1) p1 = `v' (p5) p5 = `v' (p25) p25 = `v' (p50) median = `v' (p75) p75 = `v' (p95) p95 = `v' (max) max = `v' , by(assets__id)
	gsort -N 
	export excel using "${gsdOutput}/Check assets cleaning.xlsx", first(var) sheet("Overall `name'") sheetreplace 
}
