*This do file cleans assets data
*Steps:
*Clean currencies reported in the data
*Clean year of purchase reported in the data
*Clean quantities of assets owned
*Clean prices reported in the data
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Currencies: identification, labelling, and currency conversion
use "${gsdData}/1-CleanInput/assets.dta", clear
rename (G_1_own_yn G_2_owntotal G_4_ynew  G_5_prnew G_5_prnew_curr G_5_prnew_sp G_9_sellnew G_9_sellnew_curr G_9_sellnew_sp G_11_own_prev_yn G_12_owntotal_prev) (own owntotal year_purc price_purc curr_purc price_purc_curr_sp price_sell curr_sell price_sell_curr_sp own_pre owntotal_pre)
merge m:1 StrataID ea hh using "${gsdData}/1-CleanInput/hh.dta", assert(match) keep(match) keepusing(month) nogen
label define lcurr 0 "N/A (price unknown)" .a "Don't Know" 1 "ETB" 2 "SSP" 3 "SOS" 4 "SOS (thousands)" 5 "Somaliland shillings" 6 "Somaliland shillings (1000)" 7 "ERN" 8 "USD"  9 "SDG"
*Note: 	etb = South Sudanese Pound	KSH = Kenyan Shilling
*		USD = US Dollar				UGX = Uganda Shilling
*		SDG = Sudanese Pound
*		SDP = 1st Sudanese Pound ( - 1992)
*recode price uknown as .a
*encode currencies entered manually for purchase prices
tab curr_purc
replace curr_purc = 9 if price_purc_curr_sp == "sudden pound"
label values curr_purc lcurr
label values curr_sell lcurr 
label values G_10_sellall_curr lcurr
*There are wrong year entries in the data:
*replace wrong year entries by missing
replace year_purc = . if year_purc < 1960

*Considering only data reported in ETB. 98.44% of the purchase price was reported in ETB. Similarly, 99.66% of the selling prices are reported in ETB.

*Identify and replace outliers - Quantities
*use "${gsdTemp}/assets_cleaning1.dta" , clear
*inspect ownership statistics and prices
tabstat owntotal if own==1, by(Id) stat(N mean min p5 q p95 max) columns(statistics)
tabstat owntotal_pre if own_pre==1, by(Id) stat(N mean min p5 q p95 max) columns(statistics)
*Tag values that need to be cleaned
*rename for looping
rename (own owntotal) (own_now owntotal_now)
*loop over cleaning rules
local ls = "pre now"
foreach s of local ls {
	*tag as outlier quantity ownership of more than 100 of a single asset
	local outlier = 100
	gen tag_outlier_owntotal_`s' = 0 
	replace tag_outlier_owntotal_`s' = 1 if owntotal_`s'>`outlier' & !missing(owntotal_`s') & own_`s'==1
	*tag missing quantities
	gen tag_missing_q_`s' = 0 if own_`s'==1
	replace tag_missing_q_`s' = 1 if missing(owntotal_`s') & own_`s'==1 
	*tag negative or zero quantities
	gen tag_zero_q_`s' = 0 if own_`s'==1
	replace tag_zero_q_`s' = 1 if owntotal_`s'<1 & own_`s'==1 	
}
*calculate medians
local ls = "pre now"
foreach s of local ls {
	bysort Id: egen owntotal_`s'_Id_med = median(owntotal_`s') if own_`s'==1
	assert owntotal_`s'_Id_med!=0
}
*replace quantities
local ls = "pre now"
foreach s of local ls {
	replace owntotal_`s' = owntotal_`s'_Id_med if tag_outlier_owntotal_`s'==1 & own_`s'==1 
	replace owntotal_`s' = owntotal_`s'_Id_med if tag_missing_q_`s'==1 & own_`s'==1 
	replace owntotal_`s' = owntotal_`s'_Id_med if tag_zero_q_`s'==1 & own_`s'==1 
}
rename (own_now owntotal_now) (own owntotal) 
label var owntotal "Number of asset owned today after cleaning"
label var owntotal_pre "Number of asset owned before the conflict after cleaning"
*inspect ownership statistics and prices
tabstat owntotal owntotal_pre, by(Id) stat(N mean min p5 q p95 max) columns(statistics)
*checks
assert owntotal!=0 if own==1
assert !missing(owntotal) if own==1
assert owntotal_pre!=0 if own_pre==1
assert !missing(owntotal_pre) if own_pre==1
drop tag* *_med 
save "${gsdTemp}/assets_cleaning1.dta" , replace

*Identify and replace outliers - Prices
use "${gsdTemp}/assets_cleaning1.dta" , clear
*check prices
gen price_purc_etb = price_purc if curr_purc == 1
*The purchase prices need to be brough to the current year using non-food CPI.

gen price_sell_etb = price_sell if curr_sell == 1
tabstat price_purc_etb if own==1, by(Id) s(N mean min p5 q p95 max) 
tabstat price_sell_etb if own==1, by(Id) s(N mean min p5 q p95 max)
*Manually tag prices in etb that are clear outliers or incorrect entries:
gen replace_price_purc = 1 if Id == 3 & price_purc_etb > 2000 & !missing(price_purc_etb)
replace replace_price_purc = 1 if Id == 22 & price_purc_etb >=30000 & !missing(price_purc_etb)
replace replace_price_purc = 0 if missing(replace_price_purc)
*Looking at kdensity graphs for each and at the data. *Correcting outliers. No obvious outliers
gen replace_price_sell = 0
tab replace_price_purc if own==1
tab replace_price_sell if own==1
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
label val replace_* ltag 
*/
label var replace_price_purc "Purchase price to be replaced with median"
label var replace_price_sell "Selling price to be replaced with median"
quietly tabout replace_price_purc using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, replace c(freq col)
quietly tabout replace_price_sell using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
local ls = "purc sell"
foreach t of local ls {
	local rules = "replace_price_`t'"
	foreach r of local rules {
		quietly tabout `r' using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
	}
}
*calculate medians and counts at the item level and at the item-StrataID level, add medians at the item-year level for purchase prices
local ls = "purc sell"
foreach t of local ls {
	*calculate median only for nontagged observations 
	*state
	bysort Id StrataID: egen xprice_`t'_etb_StrataID_med = median(price_`t'_etb) if replace_price_`t'==0
	bysort Id StrataID: egen price_`t'_etb_StrataID_med = max(xprice_`t'_etb_StrataID_med)	
	bysort Id StrataID: egen xprice_`t'_etb_StrataID_c = count(price_`t'_etb) if replace_price_`t'==0
	bysort Id StrataID: egen price_`t'_etb_StrataID_c = max(xprice_`t'_etb_StrataID_c)
	*dataset level, i.e. IDP or not
	bysort Id camp_ref camp_hc: egen xprice_`t'_etb_camp_med = median(price_`t'_etb) if price_`t'_etb!=0 & replace_price_`t'==0
	bysort Id camp_ref camp_hc: egen price_`t'_etb_camp_med = max(xprice_`t'_etb_camp_med)
	bysort Id camp_ref camp_hc: egen xprice_`t'_etb_camp_c = count(price_`t'_etb) if price_`t'_etb!=0 & replace_price_`t'==0
	bysort Id camp_ref camp_hc: egen price_`t'_etb_camp_c = max(xprice_`t'_etb_camp_c)
	*asset level
	bysort Id: egen xprice_`t'_etb_Id_med = median(price_`t'_etb) if replace_price_`t'==0 & !missing(price_`t'_etb)
	bysort Id: egen price_`t'_etb_Id_med = max(xprice_`t'_etb_Id_med)
	bysort Id: egen xprice_`t'_etb_Id_c = count(price_`t'_etb) if price_`t'_etb!=0 & replace_price_`t'==0
	bysort Id: egen price_`t'_etb_Id_c = max(xprice_`t'_etb_Id_c)
	if "`t'"=="purc" {
	*asset year level
		bysort Id year_purc: egen xprice_`t'_etb_year_med = median(price_`t'_etb) if price_`t'_etb!=0 & replace_price_`t'==0
		bysort Id year_purc: egen price_`t'_etb_year_med = max(xprice_`t'_etb_year_med)
		bysort Id year_purc: egen xprice_`t'_etb_year_c = count(price_`t'_etb) if price_`t'_etb!=0 & replace_price_`t'==0
		bysort Id year_purc: egen price_`t'_etb_year_c = max(xprice_`t'_etb_year_c)	
	}
	drop x*
}
*make sure prices at least at Id level are not zero
assert price_purc_etb_Id_med!=0 
assert price_sell_etb_Id_med!=0 
*We do not have prices for weaving equipment and block production equipment.
assert !missing(price_purc_etb_Id_med) if own==1 & !inlist(Id,20,25)
assert !missing(price_sell_etb_Id_med) if own==1 & !inlist(Id,20,25)
*replace purchase prices
gen long price_purc_etb_cleaned=price_purc_etb
replace price_purc_etb_cleaned = price_purc_etb_Id_med if replace_price_purc==1 & own==1
replace price_purc_etb_cleaned = price_purc_etb_StrataID_med if replace_price_purc==1 & own==1 & price_purc_etb_StrataID_c>7 & !missing(price_purc_etb_StrataID_c) &!missing(price_purc_etb_StrataID_med) & price_purc_etb_StrataID_med!=0
replace price_purc_etb_cleaned = price_purc_etb_camp_med if replace_price_purc==1 & own==1 & price_purc_etb_camp_c>5 & !missing(price_purc_etb_camp_c) &!missing(price_purc_etb_camp_med) & price_purc_etb_camp_med!=0
replace price_purc_etb_cleaned = price_purc_etb_year_med if replace_price_purc==1 & own==1 & price_purc_etb_year_c>3 & !missing(price_purc_etb_year_c) & !missing(price_purc_etb_year_med) & price_purc_etb_year_med!=0
label var price_purc_etb_cleaned "Price of asset when purchased in current etb after cleaning"
*replace selling prices
tab replace_price_sell
gen long price_sell_etb_cleaned=price_sell_etb
replace price_sell_etb_cleaned = price_sell_etb_Id_med if replace_price_sell==1 & own==1
replace price_sell_etb_cleaned = price_sell_etb_StrataID_med if replace_price_sell==1 & own==1 & price_sell_etb_StrataID_c>7 & !missing(price_sell_etb_StrataID_c)  &!missing(price_sell_etb_StrataID_med) & price_sell_etb_StrataID_med!=0
replace price_sell_etb_cleaned = price_sell_etb_camp_med if replace_price_sell==1 & own==1 & price_sell_etb_camp_c>5 & !missing(price_sell_etb_camp_c) &!missing(price_sell_etb_camp_med) & price_sell_etb_camp_med!=0
label var price_sell_etb_cleaned "Selling price of {asset} today in current etb after cleaning"
*check impact of cleaning
*check prices
tabstat price_purc_etb_cleaned , by(Id) s(N mean min p5 q p95 max) col(stat) 
tabstat price_sell_etb_cleaned , by(Id) s(N mean min p5 q p95 max) col(stat) 
*check that prices are never zero
assert price_purc_etb_cleaned!=0
assert price_sell_etb_cleaned!=0
*check evolution of prices over the years 
table year_purc Id, c(median price_purc_etb_cleaned) f(%10.0f) concise m
*drop redundant variables
drop *_med *_c replace_*
save "${gsdTemp}/assets_cleaning2.dta" , replace

*Calculate depreciation rates 
use "${gsdTemp}/assets_cleaning2.dta" , clear
*Calculate vintages. Note that as soon items are purchased, it is considered 
*one year old due to loss in value. I.e. items bought in 2017 are one year old.
gen year = 2017
gen vintage =(year-year_purc)+1
*Calculate vintage medians and replace where missing
bysort Id: egen vintage_median=median(vintage)
gen tag_missing_vintage = 0 if own==1 
replace tag_missing_vintage =1 if missing(vintage) & own==1
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
label val tag_missing_vintage ltag
quietly tabout tag_missing_vintage using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
*Set missing vintages to medians
replace vintage = vintage_median if missing(vintage) & own==1
*Label variables
lab var vintage "Years since newest {asset} was purchased, after cleaning"
drop vintage_median 
*calculate depreciation rate
*From CSA website: general prices have increased by 1.664*2.749*1.763 from December 2000 to October 2017.
*CAGR   =   (FV / PV)^1 / Y  -  1
*Using this information, we obtain the annual compound growth rate of CPI = (1.664*2.749*1.763)/^(1/17) - 1
*Assume constant asset-specific inflation rate of pi= 13.06%
*	97 percent of assets were purchased after 2000, 13.06% is the annual compound growth rate of the CPI rate between the CPI in 2000 and 2017
local pi = 0.1306
*Estimate formula from Deaton and Zaidi (2002)
*Look to verify what cleaning operations should be performed.
gen drate= 1 - (1/(1+`pi'))*(price_sell_etb_cleaned/price_purc_etb_cleaned)^(1/vintage)
*clean depreciation rate:
tabstat drate, stat(n mean min p5 q p95 max) by(Id)
*Convert drate to missing if 
* 1) calculated drate is negative:
gen tag_neg_drate=(drate<0)
label val tag_neg_drate ltag
quietly tabout tag_neg_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
replace drate=. if drate<0
* 2) calculated drate is in top of dist despite small vintages; or 
* 3) calculated drate is in bottom of dist despite large vintages:
cumul drate if !missing(drate), gen (drate_distribution) equal
label define ldum_distr 1 "Bottom 10% (0)"  2 "Top 10% (1)"
gen dum_distr=2 if drate_distribution>=.9 & !missing(drate_distribution)
replace dum_distr=1 if drate_distribution<=.1 & !missing(drate_distribution)
label var dum_distr "Observation in top/bottom of distribution"
label values dum_distr ldum_distr
*replace inconsistent cases in the top of the drate distribution
gen tag_high_drate = 0 if own==1
replace tag_high_drate = 1 if dum_distr==2 & vintage==1
tab tag_high_drate
label val tag_high_drate ltag
quietly tabout tag_high_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
*replace inconsistent cases in the bottom of the drate distribution
gen tag_low_drate= 0 if own==1
replace tag_low_drate=1 if dum_distr==1 & vintage>=3
tab tag_low_drate
label val tag_low_drate ltag
quietly tabout tag_low_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
*calculate median depreciation rates by item where >= 3 observations avail.
bysort Id: egen drate_count=count(drate) 
bysort Id: egen drate_median=median(drate) if drate_count>=3
*Set missing depreciation rates to median rates calculated above, check them
gen tag_missing_drate=0 if own==1
replace tag_missing_drate=1 if own==1 & missing(drate)
tab tag_missing_drate
label val tag_missing_drate ltag
quietly tabout tag_missing_drate using "${gsdOutput}/cleaning_rules-assets.xls" if own==1, append c(freq col)
replace drate = drate_median if missing(drate) & own==1 
replace drate = drate_median if (tag_high_drate==1 | tag_low_drate==1) & own==1
lab var drate "Depreciation rate for each durable item by household, after cleaning"
lab var drate_median "Median depreciation rate for each durable item"
* Summarise the median depreciation rates in a table 
tabstat drate, stat(n mean min p5 q p95 max) by(Id)
*drop variables needed for cleaning
drop tag_* drate_count dum_distr drate_distribution 
table Id, c(median drate_median) format (%10.2f)
*Very similar depreciation rates: Not sure 
save "${gsdTemp}/assets_cleaning3.dta" , replace 

*Calculate consumption flow 
use "${gsdTemp}/assets_cleaning3.dta" , clear
*We assume a real interest rate of 5%, based on nominal interest rate of i=pi+5%
*Assume constant asset-specific inflation rate of pi=13.06%%
*	97 percent of assets were purchased after 2000, 13.06% is the annual compound growth rate of the CPI rate between the CPI in 2000 and 2017
local pi = 0.1306
local r = .05
*Calculate user cost (consumption flows) per item & vintage using depreciation rates from either waves
gen cons_flow = (price_sell_etb_cleaned/(1-drate_median+`pi'))*(`r' + drate_median)
label var cons_flow "Consumption flow from ownership of single asset, yearly"
tabstat cons_flow , s(N mean min p5 q p95 max) col(stat) by(Id) format(%9.3f)
*generate consumption flow to check (per day in USD)
gen check_flow=cons_flow/356/23
tabstat check_flow , s(N mean min p5 q p95 max) col(stat) by(Id) format(%9.3g)
drop check_flow
*Calculate median consumption flow per item & vintage
bysort Id vintage: egen cons_flow_median = median(cons_flow)
lab var cons_flow_median "Median consumption flow"
*Now we estimate the final consumption flow of durable goods, taking into account
*ownership of more than one item
gen cons_d_yearly = (price_sell_etb_cleaned/(1-drate_median+`pi'))*(`r' + drate_median) if owntotal==1 & own==1
replace cons_d_yearly = (price_sell_etb_cleaned/(1-drate_median+`pi'))*(`r' + drate_median) + ((owntotal-1)*cons_flow_median) if owntotal>=2 & own==1
label var cons_d_yearly "Consumption flow of durables (yearly) etb" 
*inspect
tabstat cons_d_yearly , s(N mean min p5 q p95 max) col(stat) by(Id)
tabstat cons_d_yearly , s(N mean min p5 q p95 max) col(stat)
*Calculate weekly and daily consumption flow 
*Convert from annual to weekly
gen cons_d_weekly=cons_d_yearly/365.25*7
label var cons_d_weekly "Consumption flow of durables (weekly) etb" 
gen cons_d_daily=cons_d_yearly/365.25
label var cons_d_daily "Consumption flow of durables (daily) etb" 
*Calculate per capita consumption flow
merge m:1 StrataID ea hh using "${gsdData}/1-CleanInput/hh.dta", keepusing(hhsize) assert(match) keep(match) nogen
gen cons_d_daily_pc=cons_d_daily/hhsize
label var cons_d_daily_pc "Consumption flow of durables (daily) per capita etb" 
drop hhsize month year 

*Clean up and save
rename (own owntotal year_purc price_purc curr_purc price_purc_curr_sp price_sell curr_sell price_sell_curr_sp own_pre owntotal_pre) (G_1_own_yn G_2_owntotal G_4_ynew  G_5_prnew G_5_prnew_curr G_5_prnew_sp G_9_sellnew G_9_sellnew_curr G_9_sellnew_sp G_12_own_prev_yn G_13_owntotal_prev) 
*reorder
order price_purc_* , after(G_5_prnew)
order price_sell_* , after(G_9_sellnew)
order vintage drate* , after(G_4_ynew)
order cons_* , before(G_10_sellall)
*replace consumption flow as zero for households where food core cons was == 0 or . 
merge m:1 StrataID ea hh using  "${gsdData}/1-CleanTemp/hh_food.dta", keepusing(food_opt0_hh_wk) assert(match master using) keep(match) nogen
ds cons_flow cons_d_*
foreach v in `r(varlist)' {
	replace `v'=0 if (food_opt0_hh_wk == 0 | missing(food_opt0_hh_wk))
}
drop food_opt0_hh_wk 
save "${gsdData}/1-CleanOutput/assets.dta", replace
*and calculate aggregates
use "${gsdData}/1-CleanOutput/assets.dta" , clear
collapse (sum) assets_hh_wk = cons_d_weekly, by(StrataID ea hh)
label var assets_hh_wk  "Household weekly consumption flow of durable items"
save "${gsdData}/1-CleanTemp/hh_assets.dta", replace
*create dataset in wide format with asset ownership
/*use "${gsdData}/1-CleanOutput/assets.dta" , clear
rename G_2_owntotal owntotal
keep StrataID ea hh Id owntotal
reshape wide owntotal , j(Id) i( StrataID ea hh)
label var owntotal1 "Num. cars owned"
label var owntotal2 "Num. trucks owned"
label var owntotal3 "Num. Motorcycle owned"
label var owntotal4 "Num. Rickshaw owned"
label var owntotal5 "Num. Bicycle owned"
label var owntotal6 "Num. Canoe or boat owned"
label var owntotal7 "Num. Plough owned"
label var owntotal8 "Num. Television owned"
label var owntotal9 "Num. Satellite dish owned"
label var owntotal10 "Num. DVD or CD player owned"
label var owntotal11 "Num. Radio or transistor owned"
label var owntotal12 "Num. Mobile phone owned"
label var owntotal13 "Num. Computer or laptop owned"
label var owntotal14 "Num. Refrigerator owned"
label var owntotal16 "Num. Fan owned"
label var owntotal17 "Num. Air cooler or air conditioner owned"
label var owntotal18 "Num. Mattress or bed owned"
label var owntotal19 "Num. Mosquito net owned"
label var owntotal20 "Num. Electric ironer owned"
label var owntotal21 "Num. Hoe, spade or axe owned"
save "${gsdData}/1-CleanTemp/assets_wide.dta", replace
*/
* Create tables to report the impact of cleaning
use "${gsdData}/1-CleanOutput/assets.dta" , clear
merge m:1 StrataID ea hh using "${gsdData}/1-CleanInput/hh.dta" , assert(match using) keep(match) keepusing(hhsize) nogen
gen cons = cons_d_weekly/hhsize 
replace cons=. if cons_d_weekly==0
label var price_purc_etb_cleaned "Purchase price clean"
label var price_sell_etb_cleaned "Selling price clean"
label var cons "HH weekly consflow pc"
gen cons_usd = cons/120 
label var cons_usd "weekly consflow pc USD"
label var cons_d_weekly "HH weekly consflow"
save "${gsdData}/1-CleanTemp/assets_checking_tables.dta", replace
local va  "price_purc_etb_cleaned price_sell_etb_cleaned cons_d_weekly cons cons_usd" 
*Overall
foreach v of local va {
	use  "${gsdData}/1-CleanTemp/assets_checking_tables.dta" , clear
	local name : variable label `v'
	collapse (count) N = `v' (mean) mean = `v' (min) min = `v' (p1) p1 = `v' (p5) p5 = `v' (p25) p25 = `v' (p50) median = `v' (p75) p75 = `v' (p95) p95 = `v' (max) max = `v' , by(Id)
	gsort -N 
	export excel using "${gsdOutput}/Check assets cleaning.xlsx", first(var) sheet("Overall `name'") sheetreplace 
}
