set sortseed 10051990
*this do file calculates the deflator for food and nonfood consumption
local lis = "food"
foreach cat of local lis {
	use "${gsdData}/1-CleanTemp/`cat'.dta", clear
	*ensure that food and non-food have the same format
	if ("`cat'"=="food") {
		ren price_per_kg_cleaned uprice
	}
	else {
		ren price_naira_cleaned uprice
	}
	*merge sampling weights and month
	merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta", assert(master match using) keepusing(weight month mod_hh) keep(match master) nogen
	keep region ea migr_idp hh mod_item mod_hh itemid cons_value uprice month weight 
	ren month tm
	tab region tm 
	replace tm = "8" if tm == "Aug"
	replace tm = "9" if tm == "Sep"
	replace tm = "10" if tm == "Oct"
	replace tm = "11" if tm == "Nov"
	destring tm, replace
	*calculate core and optional module consumption per hh
	bys region ea migr_idp hh mod_item: egen tcons = total(cons_value)
	label var tcons "Total consumption of module"
	*check that consumption does not change within hh & module
	bys region ea migr_idp hh mod_item: egen check=sd(tcons)
	assert check==0
	drop check
	*add zero consumption
	reshape wide cons_value uprice, i(region ea migr_idp hh mod_item) j(itemid)
	foreach v of varlist cons_value* {
	replace `v' = 0 if missing(`v') & inlist(mod_item,0,mod_hh)
	}	
	reshape long cons_value uprice, i(region ea migr_idp hh mod_item) j(itemid)
	drop if missing(cons_value)
	assert inlist(mod_item,0,mod_hh)
	*calculate item shares relative to core or optional module
	gen cons_share = cons_value / tcons
	label var cons_share "Item share of module consumption"
	*check shares sum to 1
	bys region ea migr_idp hh mod_item: egen check=total(cons_share)
	assert inlist(round(check,0.0001),1,0) 
	drop check
	*check shares are missing if module items are not consumed, and is not missing if module items are consumed
	assert missing(cons_share) if tcons==0
	assert !missing(cons_share) if tcons!=0
	*check whether any products do not have prices
	bys itemid: egen count=count(uprice)
	tab itemid if count==0
	*drop products with no prices
	*Go back and check whether we can have prices for the these products. (Observations for 23 products deleted. Please go back and incorporate their prices.)
	drop if count==0
	assert !missing(count)
	assert count!=0
	drop count
	save "${gsdTemp}/`cat'-share.dta", replace

	*calculate weights: aggregate across households (using hh weights)
	use "${gsdTemp}/`cat'-share.dta", clear
	collapse (mean) cons_share tcons [pweight=weight], by(itemid mod_item)
	drop if cons_share==0
	*check that items appear only once
	duplicates tag itemid , gen(t)
	assert t==0
	drop t
	*calculate total denominator for core and all optional modules
	reshape wide tcons, i(itemid cons_share) j(mod_item)
	foreach v of varlist tcons? {
		egen t`v'= max(`v')
		assert `v'==t`v' if !missing(`v')
	}	
	egen ttcons = rowtotal(ttcons?)
	egen tcons = rowmin(tcons?)
	drop tcons? ttcons?
	*save module specific shares
	ren cons_share cons_mshare
	gen cons_tshare = cons_mshare * tcons / ttcons
	label var cons_mshare "Share of module `cat' consumption"
	label var cons_tshare "Share of total `cat' consumption"
	assert cons_mshare>=cons_tshare
	*calibrate weights to sum up to 1 
	*check whether calibration worked
	egen check = total(cons_tshare)
	assert round(check,0.001)==1
	drop check	
	ren (tcons ttcons ) (mdenom tdenom)
	label var tdenom "Total denominator"
	label var mdenom "Module-specific denominator"
	save "${gsdTemp}/`cat'-weights.dta", replace
	
	*prepare median and average prices:
	use "${gsdTemp}/`cat'-share.dta", clear
	bysort itemid: egen uprice_med_all = median(uprice)
	*calculate median prices
	collapse (median) uprice_med = uprice  [pweight=weight], by(region itemid uprice_med_all)
	replace uprice_med = uprice_med_all if missing(uprice_med)
	drop uprice_med_all
	*reference is October 2017 prices for Tigray/Afar region
	local ref = 10
	bysort itemid: egen ref = min(uprice_med)
	*propagate to all records
	save "${gsdTemp}/`cat'-prices.dta", replace
	
	*calculate deflator:
	use "${gsdTemp}/`cat'-prices.dta", clear
	*add consumption weights
	merge m:1 itemid using "${gsdTemp}/`cat'-weights.dta", keepusing(cons_tshare) assert(master match) keep(match) nogen
	*calculate deflator
	gen cons_defl = cons_tshare * uprice_med/ref
	collapse (sum) cons_defl, by(region)
	label var cons_defl	"Laspeyres deflator for `cat' consumption"
	rename cons_defl `cat'_cons_defl
	save "${gsdTemp}/`cat'-deflator.dta", replace
	export excel using "${gsdOutput}/deflator.xlsx", sheetreplace sheet("`cat'") first(varl)
	*graph deflator
	*set graphics off
	*egen Strata = concat(migr_idp), decode p(" ")
	*encode Strata, gen(Strata_n)
	*xtset  tm
	*tsline `cat'_cons_defl , by(Strata)
	*graph export "${gsdOutput}/`cat'-deflator.pdf" , as(pdf) replace
	*set graphics on
}
