*Do-file to create a strata level Laspeyres price deflator based on food item prices.

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	error 1
	display as error "Please run init.do first."
}

*=========================================*	
*Strata - level price deflator (Laspeyres)
*=========================================*	
clear all
set more off

*creating basket of items to deflate
 use "${gsdData}\1-CleanTemp\food.dta", clear
*Price deflator is based on items in core category
keep if mod_item==0
gen hhk = 1
*Filling in every item for every household to give zero weightshare to households that do not consume item
fillin region ea migr_idp hh itemid
bys region ea migr_idp hh: egen keep_hh = max(hhk)
keep if keep_hh==1
save "${gsdTemp}/food_allitemhh.dta" , replace
*gen basket shares

use "${gsdTemp}/food_allitemhh.dta", clear
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanInput/hh.dta" , keep(match) keepusing(weight) nogen
keep region ea migr_idp hh itemid price_per_kg_cleaned cons_q_kg weight
gen double uv = price_per_kg_cleaned if cons_q_kg>0 & !mi(cons_q_kg)
gen double exp = price_per_kg_cleaned*cons_q_kg if cons_q_kg>0 & !mi(cons_q_kg)
bys region ea migr_idp hh: egen double sumx = sum(exp)
gen double weightshare = exp / sumx
replace weightshare = 0 if mi(weightshare)
gen wshare_i = .
gen psAdamawa = .
gen psBauchi = .
gen psBorno = .
gen psGombe = .
gen psTaraba= .
gen psYobe= .
gen pnat = .
qui levelsof itemid  , local(items)
qui levelsof region  , local(strata)
	
foreach s of local strata {
	foreach item of local items {
	qui su uv if itemid == `item' & region=="`s'" [aw=weight] , detail
	qui replace ps`s' = r(p50) if itemid == `item' & region=="`s'"
		}	
}
	foreach item of local items {
		qui su uv if itemid == `item' [aw=weight] , detail
		qui replace pnat = r(p50) if itemid == `item'
		qui su weightshare if itemid == `item' , detail
		qui replace wshare_i = `r(mean)' if itemid ==`item'
	}
	
collapse (mean) wshare_i pnat ps* , by(itemid)
egen total_w = total(wshare_i)
assert round(total_w,0.001)==1
drop total_w
saveold "${gsdTemp}/laspeyres_strata.dta" , replace
use "${gsdTemp}/laspeyres_strata.dta"  , clear
*refrencing national prices
rename (psAdamawa psBauchi psBorno psGombe psTaraba psYobe) (ps1 ps2 ps3 ps4 ps5 ps6)
forvalues s = 1 / 6 {
	gen lnpratio_`s' = ln(ps`s' / pnat)
	gen ln_pindex_`s' = wshare_i*(lnpratio_`s')
	egen lnlaspeyres_`s' = sum(ln_pindex_`s')
	gen laspeyres`s' = exp(lnlaspeyres_`s')
	*check constant laspeyres
	egen x`s' = min(laspeyres`s')
	assert (int(x`s')==int(laspeyres`s'))
}
gen nat=1
collapse (mean) laspeyres* , by(nat)
reshape long laspeyres, i(nat) j(region)
tostring region, replace
replace region="Adamawa" if region=="1"
replace region="Bauchi" if region=="2"
replace region="Borno" if region=="3"
replace region="Gombe" if region=="4"
replace region="Taraba" if region=="5"
replace region="Yobe" if region=="6"

ren laspeyres food_cons_defl
label var food_cons_defl "Strata-level Laspeyres price index (based on core item food prices)"
drop nat
saveold "${gsdData}/1-CleanOutput/food-deflator.dta", replace
erase "${gsdTemp}/laspeyres_strata.dta" 
