*This do-file cleans the Household questionnaire and prepares variables for the analysis
clear all 
set more off
set maxvar 10000
set sortseed 10051990
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
use "${gsdData}/1-CleanInput/hh.dta", clear
numlabel, add

recode C_1_1_housingtype (1= 1 "Tent") (3 4=2 "Tukul/gottiya") (5 6 8 10=4 "Concrete/brick house") (7 9=3 "Mud/wood hut") (11/12 = 5 "Incomplete structure/structure not intended for residence") ( 13 = 5 "No house"), gen(house)
recode C_2_1_housingtype_disp (1= 1 "Tent") (3 4=2 "Tukul/gottiya") (5 6 8 10=4 "Concrete/brick house") (7 9=3 "Mud/wood hut") (11/12 = 5 "Incomplete structure/structure not intended for residence") ( 13 = 5 "No house"), gen(house_disp)
 
*Clean 'other specify variables'
replace C_1_11_water_home=4 if C_1_11_water_home_ot=="borehole"
replace C_1_11_water_home=12 if (C_1_11_water_home_ot=="Truck Pusher" | C_1_11_water_home_ot=="Truck pusher" | C_1_11_water_home_ot=="Truck pushers" | C_1_11_water_home_ot=="water trucks")
replace C_2_13_water_home_disp=4 if C_2_13_water_home_ot_disp=="borehole"
replace C_4_17_social_saf_net= 10 if (C_4_17_social_saf_net_spec=="No body" | C_4_17_social_saf_net_spec=="Nobody" | C_4_17_social_saf_net_spec=="Nobody to approach" | C_4_17_social_saf_net_spec=="None" | C_4_17_social_saf_net_spec=="nobody")
lab define nob 1 "Relatives" 2 "Friends" 3 "Community" 4 "Landlord" 5 "Religious institutions" 6 "State" 7 "NGOs" 8 "Money lenders" 9 "Microfinance/banks" 10 "Nobody" 1000 "Other" 
lab val C_4_17_social_saf_net nob

gen a = substr( C_5_1_lhood_spec,1,3)
replace C_5_1_lhood=4 if (a=="sel" | a=="dai" | a=="lab" | a=="LAB" | a=="Dai" | a=="Lab" )
drop a

gen a = substr( C_5_4_obs_access_aid_spec ,1,3)
replace C_5_4_obs_access_aid=9 if (a=="we " | a=="not" | a=="no " | a=="don" | a=="Not" | a=="No " | a=="Ina" | a=="Don")
drop a
lab define inad 1 "Lack of information" 2 "Lack of secure access" 3 "Inadequate transport infrastructure" 4 "Aid captured by more powerful people" 5 "Connections needed" 6 "Lack of time to collect" 7 "Not eligible" 8 "No obstacle" 9 "Inadequate" 100 "Other"
lab val C_5_4_obs_access_aid inad

replace C_5_8_intremit_mode__7=1 if (C_5_8_intremit_mode_sp=="In person" | C_5_8_intremit_mode_sp=="in person" | C_5_8_intremit_mode_sp=="hand to hand")

gen I_1_16_disp_shpay_who__6 = 0
gen a = substr( I_1_16_disp_shpay_who_spec ,1,3)
replace I_1_16_disp_shpay_who__6=1 if (a=="LAN" | a=="Lan" | a=="The" | a=="hou" | a=="lan" | a=="own" | a=="pri")
drop a 
lab var I_1_16_disp_shpay_who__6  "I.1.16 Who did you give money or goods to? Select all that apply.:Landlord"

*Generate HH room density
gen hhdensity = C_1_2_rooms_n / hhsize
recode hhdensity (0/0.25 = 1 "More than 4 Individuals Per Room") (0.25/0.5 = 2 "2 - 4 Individuals Per Room") (0.5/1 = 3 "1 - 2 Individuals Per Room") (1/6 = 4 "Less than 1 Individual Per Room"), generate(memperroom)
label var hhdensity "Household Members Per Room"
label var memperroom "Household Members Per Room (Categorized)"

*Generate HH room density before displacement
gen hhdensity_pre = C_2_2_rooms_n_disp / hhsize_pre
recode hhdensity_pre (0/0.25 = 1 "More than 4 Individuals Per Room") (0.25/0.5 = 2 "2 - 4 Individuals Per Room") (0.5/1 = 3 "1 - 2 Individuals Per Room") (1/6 = 4 "Less than 1 Individual Per Room"), generate(memperroom_pre)
label var hhdensity_pre "Household Members Per Room Before Displacement"
label var memperroom_pre "Household Members Per Room (Categorized) Before Displacement"

*Generate HH sleeping room density
replace C_1_3_slrooms_n=1 if C_1_2_rooms_n==1
gen hhdensity_sl = C_1_3_slrooms_n / hhsize
recode hhdensity_sl (0/0.25 = 1 "More than 4 Individuals Per Bedroom") (0.25/0.5 = 2 "2 - 4 Individuals Per Bedroom") (0.5/1 = 3 "1 - 2 Individuals Per Bedroom") (1/6 = 4 "Less than 1 Individual Per Bedroom"), generate(memperroom_sl)
label var hhdensity_sl "Household Members Per Sleeping Room"
label var memperroom_sl "Household Members Per Sleeping Room (Categorized)"

*Generate HH sleeping room density before displacement:
replace C_2_3_slrooms_n_disp =1 if C_2_2_rooms_n_disp==1
gen hhdensity_sl_disp = C_2_3_slrooms_n_disp / hhsize_pre
recode hhdensity_sl_disp (0/0.25 = 1 "More than 4 Individuals Per Bedroom") (0.25/0.5 = 2 "2 - 4 Individuals Per Bedroom") (0.5/1 = 3 "1 - 2 Individuals Per Bedroom") (1/6 = 4 "Less than 1 Individual Per Bedroom"), generate(memperroom_sl_disp)
label var hhdensity_sl_disp "Household Members Per Sleeping Room"
label var memperroom_sl_disp "Household Members Per Sleeping Room (Categorized)"

*Recode tenure variable
recode C_1_7_tenure (5 = 1 "Temporary shelter provided by UN/INGOs") (6 7 8=2 "Squatting") (4=3 "Relatives/friends") (3=4 "Work-provided") (2=5 "Rented")  (1=6 "Owned"), gen(tenure)
label var tenure "What is the main tenure status of this dwelling?"


*Recode pre-disp tenure variable
recode C_2_4_tenure_disp (6 = 1 "Temporary shelter provided by UN/INGOs") ( 7 8 9 =2 "Squatting") (5=3 "Relatives/friends") (3=4 "Work-provided") (2=5 "Rented")  (1=6 "Owned"), gen(tenure_disp)
label var tenure_disp "What was the main tenure status of the dwelling before displacement?"

*Generate water access variables
tab C_1_11_water_home_ot
/*
*Handpump comes under tubewell/borehole according to the UNICEF/WHO guidelines
replace C_8_water_home=4 if strpos(C_8_water_home_ot,"pump")   | strpos(C_8_water_home_ot,"Pump")
replace C_8_water_home=11 if strpos(C_8_water_home_ot,"retailers") 
*/
recode C_1_11_water_home (1/5 7 9/10 = 1 "Improved Sources of Water") (6 8 11 12 13  = 2 "Unimproved sources of water") (1000 = .), generate(watersource)
recode C_1_12_water_home2 (1/5 7 9/10 = 1 "Improved Sources of Water") (6 8 11 12 13  = 2 "Unimproved sources of water") (1000 = .), generate(watersource2)

*Generate water access variables for before displacement
recode C_2_13_water_home_disp (1/5 7 9/10 = 1 "Improved Sources of Water") (6 8 11 12 13  = 2 "Unimproved sources of water") (1000 = .), generate(watersource_disp)
recode C_2_14_water_home2_disp (1/5 7 9/10 = 1 "Improved Sources of Water") (6 8 11 12 13  = 2 "Unimproved sources of water") (1000 = .), generate(watersource_disp2)

*Number of days to get water do not seem right, so ignore number of days or replace with minutes:
ren (C_1_13_* C_1_25_* C_1_26_* C_1_27_* C_1_28_*) (* * * * *)
*replace thealth_m = thealth_d if thealth_d == 30
local services = "market edu health water police"
foreach s of local services {
	gen time_`s'_min = t`s'_m + (60*t`s'_h) 
	label var time_`s'_min "Time taken (bth ways)"
	recode time_`s'_min (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), generate(`s'time)
}
replace time_water_min=0 if inlist(C_1_11_water_home,1,2)
label var watersource  "C.1.11 Drinking water source"
label var time_water_min "C.1.13 Time Spent on Getting Drinking Water, in minutes"

*Generate time taken variables for before displacement
ren (C_2_15_* C_2_16_* C_2_17_* C_2_18_* C_2_22_*) (* * * * *)
local services = "market edu health water police"
foreach s of local services {
	gen time_`s'_min_disp = t`s'_m_disp + (60*t`s'_h_disp) 
	label var time_`s'_min_disp "Time taken (bth ways) before displacement"
	recode time_`s'_min_disp (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), generate(`s'time_disp)
}

replace time_water_min_disp=0 if inlist(C_2_13_water_home_disp,1,2)
label var watersource_disp  "Drinking water source before displacement"
label var time_water_min_disp "Time Spent on Getting Drinking Water, in minutes before displacement"

*Generate cooking variable
recode C_1_20_cook (0 = 1 "No cooking") (6 1 = 2 "Firewood/grass") (2 = 3 "Charcoal") (3/5 9 10 7 10 14/17 = 5 "Electricity/gas/kerosene/other") (1000 = .), generate(cooking)
label define cooking .a "Don't know" .b "Refused to respond" , modify
label val cooking cooking
label var cooking "C.19 Source of energy for cooking"

*Generate sanitation access variable
*replace C_16_toilet=12 if strpos(C_16_toilet_ot,"bush") | strpos(C_16_toilet_ot,"field") | strpos(C_16_toilet_ot,"They have no pit latrin") | strpos(C_16_toilet_ot,"we share toilet with other")
recode C_1_21_toilet (1/3 5/7 9 = 1 "Improved sanitation facilities") (4 8 11/12 = 2 "Unimproved sanitation facilities") (1000 = .), generate(sanitation)
label var sanitation "Toilet Type"

*Creating before displacement sanitation variable:
recode C_2_20_toilet_disp (1/3 6/7 9 = 1 "Improved sanitation facilities") (4/5 8 10/13 = 2 "Unimproved sanitation facilities"), generate(sanitation_disp)
label var sanitation_disp "Toilet Type before displacement"

*Recode number of hhs sharing toilets  for better graph
*Generate lighting access variable
recode C_1_17_light (16 = 1 "No Lighting") (12 13  = 2 "Grass / Firewood") (14 7 10 11  = 3 "Lamp / Candle / Torch") (1/3 6 8 9 = 5 "Electricity") (15 5 4  = 6 "Solar Power / Biogas")  , generate(lighting)
label var lighting "Source of Lighting"
recode C_1_15_who_fetch (3=1 "Female child") (4=2 "Male child") (1=3 "Adult woman") (2=4 "Adult man"), gen(who_fetch)

*Generate lighting access variable before displacement:
recode C_2_19_light_disp (16 = 1 "No Lighting") (12 13  = 2 "Grass / Firewood") (14 7 10 11  = 3 "Lamp / Candle / Torch") (1/3 6 8 9 = 5 "Electricity") (15 5 4  = 6 "Solar Power / Biogas")  , generate(lighting_disp)
label var lighting_disp "Source of Lighting"

*Developing CSI:
*Converting missings to zeros:
foreach var of varlist C_4_3_cop_borrow_food C_4_4_cop_limitportion C_4_5_cop_limitadult C_4_6_cop_reducemeals C_4_2_cop_lessprefrerred {
	replace `var' = 0 if missing(`var')
}
gen csi = C_4_2_cop_lessprefrerred*1 + C_4_3_cop_borrow_food*2 + C_4_4_cop_limitportion*1 + C_4_5_cop_limitadult*3 + C_4_6_cop_reducemeals*1 
gen csi_cat = 3 if csi <3
replace csi_cat = 2 if csi<9 & csi>=3
replace csi_cat = 1 if csi >= 10
label define lcsi_cat 1 "High food insecurity" 2 " Medium food insecurity" 3 "Low food insecurity"
label values csi_cat lcsi_cat
*Label aid variables
foreach v of varlist C_5_2_assist_source__* {
	lab val `v' lyn
}

*Recode remittance change variables
label define lchange 0 "No change" 1 "Increased" 2 "Decreased"
foreach v of varlist C_5_11_intremit_moreless C_5_14_supp_moreless {
	lab values `v' lchange
}

*Recode number of hhs sharing toilets  for better graph
recode C_22_share_num (2 3 = 3 "3 or less households") (4 5 6 7 8 9 = 2 "4 to 9 households") (10 = 1 "10 or more households"), gen(share_num_new)

*Clean date of displacement
*Date in stata format
g year = substr(I_1_3_disp_date,1,4)
replace year = "" if year == "N/A"
g month_disp = substr(I_1_3_disp_date,6,2)
g day = substr(I_1_3_disp_date,9,2)
egen displacementdate = concat (year month_disp), p(-)
label var displacementdate "Date of displacement (month wise)"
replace displacementdate = "" if displacementdate == "-"

*Clean Number of times household changed residence:
*Cleaning incorrect entry:
*replace I_3_disp_site = . if I_3_disp_site == 2002
recode I_1_5_disp_site (0 = 0 "Did not change") ( 1= 1 "Once" ) (2 = 2 "Twice") ( 3/8 = 3 "Thrice or more"), gen (disp_times)
label var disp_times "Number of times household changed residence since displacement"

*Clean date of arrival:
g year_arrival = substr(I_1_7_disp_arrive_date,1,4)
replace year_arrival = "" if year_arrival == "N/A"

*Add consumption data for food, non-food and assets
*Merge consumption data
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_food.dta", nogen keep(match master) assert(master match using)
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_nonfood.dta", assert(match) nogen
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_assets.dta", assert(match) nogen
drop mod_item

*Consistency check for data completion and data cleanliness
capture: drop nofood 
tabstat nonfood_opt?_hh_wk food_opt?_hh_wk assets_hh_wk , stat(n min max median mean)
*Add remaining labels
forval i=0/4 {
	label var food_opt`i'_hh_wk "HH Food Cons of Opt Mod `i' Weekly"
	label var nonfood_opt`i'_hh_wk "HH Non-Food Cons of Opt Mod `i' Weekly"
}
*Save as temporary file to be used for consistency checks
save "${gsdTemp}/hhq_cons_aggregates_1.dta", replace

*add deflators
rename month tm
replace tm = "8" if tm == "Aug"
replace tm = "9" if tm == "Sep"
replace tm = "10" if tm == "Oct"
replace tm = "11" if tm == "Nov"
destring tm, replace
*create StrataID variable for deflator merging
merge m:1 region using "${gsdData}/1-CleanOutput/food-deflator.dta", nogen keep(master match) assert(master match) keepusing(food_cons_defl)
*merge m:1 region using "${gsdTemp}/nonfood-deflator.dta", nogen keep(master match) assert(master match) keepusing(nonfood_cons_defl)
rename tm month
sort region ea migr_idp hh

save "${gsdData}/1-CleanTemp/hhq.dta", replace
