*This do-file imputes consumption for those modules not asked to households, 
*computes the poverty measures, and adds imputed consumption values to the 
*food and nonfood datasets.
*For more info on the imputation method, refer to Pape and Mistian (2014)
set more off
set sortseed 10051990

*number of imputations
local m = 100

*prepare household member
use "${gsdData}/1-CleanOutput/hhm.dta", clear
gen nchild = B_1_1_hhm_age<15 if B_1_1_hhm_age<.
gen nsenior = B_1_1_hhm_age>64 if B_1_1_hhm_age<.
gen hhsex = B_2_1_hhm_gender if ishead
recode u_rate (0 = 1 "Employed")  (1 = 0  "Unemployed/Inactive") (. = 0 "Unemployed/Inactive"), gen(u_rate_cleaned) 	
gen hhempl = u_rate_cleaned if ishead
*Generate hhh highest level of education
gen hhh_edu_level_g= edu_level_g if ishead == 1
label var hhh_edu_level_g "Level of Education of Household Head"
label value hhh_edu_level_g edu_level_g
*generate household head literacy
gen hhh_literacy=literacy==1 if ishead == 1
label var hhh_literacy "Literacy of household head"
label val hhh_literacy lyn
collapse (sum) nchild nsenior (min) hhsex hhempl hhh_edu_level hhh_literacy (count) hhsize = hhmid, by(region ea migr_idp hh)
label var hhsex "Gender of household head"
label define lhhsex 1 "Male" 2 "Female"
label val hhsex lhhsex
label var hhempl "Is the household head employed"
label define lyesno 0 "No" 1 "Yes"
label values hhempl lyesno
gen pchild = nchild / hhsize
label var pchild "Share of children in household"
gen psenior = nsenior / hhsize
label var psenior "Share of elderly in household"
drop nchild nsenior
save "${gsdData}/1-CleanTemp/hhm-hh.dta", replace
*prepare household
use "${gsdData}/1-CleanTemp/hhq.dta", clear
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hhm-hh.dta", keepusing(pchild psenior hhsex hhempl hhh_edu_level_g hhh_literacy) assert(match) 
*harmonize variable names
ren (food_opt0_hh_wk food_opt1_hh_wk food_opt2_hh_wk food_opt3_hh_wk food_opt4_hh_wk) (cons_f0 cons_f1 cons_f2 cons_f3 cons_f4)
ren (nonfood_opt0_hh_wk nonfood_opt1_hh_wk nonfood_opt2_hh_wk nonfood_opt3_hh_wk nonfood_opt4_hh_wk) (cons_nf0 cons_nf1 cons_nf2 cons_nf3 cons_nf4)
ren assets_hh_wk cons_d
*ensure core consumption
assert cons_f0 > 0 | !missing(cons_f0) 
*Imputing missing food consumption data:
*do "${gsdDo}/1-7-1-impute_cons_f0.do"
*require positive food consumption (otherwise, we assume data is missing)
drop if missing(cons_f0)
*prepare model variables
*sleeping rooms
ren C_1_3_slrooms_n hhsleep
recode hhsleep (3/90=3) (-9=0)
label define lsleep 0 "None" 1 "1 Room" 2 "2 Rooms" 3 ">2 Rooms", replace
label values hhsleep lsleep
replace hhsleep = 2 if hhsleep>=.
*water
recode C_1_11_water_home (4=1 "Borehole" ) (1 2 3  =2 "Hand pump") (5/9 13=3 "Open Water" ) (nonmissing=4 "Other") , gen(hhwater)
replace hhwater = 4 if hhwater>=.
tab hhwater, m
*light
recode lighting (1=0 "None") (2=1 "Grass / Firewood") (3/4=2 "Lamp/Candle/Torch") (5/6=3 "Electricity"), gen(hhlight)
replace hhlight = 2 if hhlight>=.
tab hhlight, m 
*toilet
gen hhtoilet = sanitation 
replace hhtoilet = 0 if missing(hhtoilet)
label var hhtoilet "Does the household have an improved toilet?"
label define twoyesno 1 "Yes" 2 "No"
label val hhtoilet twoyesno
*prepare consumption variables
*make sure missing modules have missing consumption
forvalues i = 1/4 {
	assert missing(cons_f`i') if mod_hh!=`i'
	assert missing(cons_nf`i') if mod_hh!=`i'
}
*adjust to per capita per day 
forvalues i = 0/4 {
	replace cons_f`i' = cons_f`i' / hhsize / 7 
	replace cons_nf`i' = cons_nf`i' / hhsize / 7 
	label var cons_f`i' "Collected food consumption mod `i' pc pd curr naira"
	label var cons_nf`i' "Collected non-food consumption mod `i' pc pd curr naira"
	gen mi_cons_f`i' = cons_f`i'
	gen mi_cons_nf`i' = cons_nf`i'
	label var mi_cons_f`i' "Imputed food consumption mod `i' pc pd curr naira"
	label var mi_cons_nf`i' "Imputed non-food consumption mod `i' pc pd curr naira"
}
replace cons_d = cons_d / hhsize / 7
gen mi_cons_d = cons_d
label var cons_d "Consumption flow of durables pc pd curr naira"
label var mi_cons_d "Consumption flow of durables pc pd curr naira"
*create some aggregates
xtile pmi_cons_f0 = mi_cons_f0 [pweight=weight], nquantiles(4)
xtile pmi_cons_nf0 = mi_cons_nf0 [pweight=weight], nquantiles(4)
xtile pmi_cons_d = mi_cons_d [pweight=weight], nquantiles(4)
*prepare smaller dataset
keep region ea migr_idp hh *_defl* mi_cons_* pmi_cons_* cons_* hhsize pchild psenior hhsex hhempl hhwater hhlight hhsleep hhtoilet weight mod_hh
*build model
local model = "pchild psenior hhtoilet hhsleep hhsize i.hhsex i.hhempl hhlight i.migr_idp i.region" 
local model = "i.pmi_cons_f0 i.pmi_cons_nf0 `model'"
*create core consumption for comparison
save "${gsdData}/1-CleanTemp/mi-pre.dta", replace

use "${gsdData}/1-CleanTemp/mi-pre.dta", clear
encode region, gen(region1)
drop region
rename region1 region
*CHECK ALL THIS PROPERLY
*MI
mi set wide
mi register imputed mi_cons_f1 mi_cons_f2 mi_cons_f3 mi_cons_f4 mi_cons_nf1 mi_cons_nf2 mi_cons_nf3 mi_cons_nf4 
mi register regular hh* ea mi_cons_f0 mi_cons_nf0 mi_cons_d region migr_idp
*Multi-variate normal imputation using MCMC 

set seed 89124387
mi impute mvn mi_cons_f1 mi_cons_f2 mi_cons_f3 mi_cons_f4 mi_cons_nf1 mi_cons_nf2 mi_cons_nf3 mi_cons_nf4 = `model', add(`m') burnin(1000)
save "${gsdTemp}/mi.dta", replace

use "${gsdTemp}/mi.dta", clear
gen hhweight = weight*hhsize
*deflate consumption aggregates and label them as such
forvalues i = 0/4 {
	mi xeq: replace mi_cons_f`i' = mi_cons_f`i' / food_cons_defl
	replace cons_f`i' = cons_f`i' / food_cons_defl
}
*nonfood
forvalues i = 0/4 {
	mi xeq: replace mi_cons_nf`i' = mi_cons_nf`i' / food_cons_defl
	replace cons_nf`i' = cons_nf`i' / food_cons_defl
}

forvalues i = 0/4 {
	label var mi_cons_f`i' "Imputed food consumption module `i' pc pd in mid 2018 prices"
	label var cons_f`i' "Collected food consumption module `i' pc pd in mid 2018 prices"
}
forvalues i = 0/4 {
	label var mi_cons_nf`i' "Imputed non-food consumption module `i' pc pd in mid 2018 prices"
	label var cons_f`i' "Collected non-food consumption module `i' pc pd in mid 2018 prices"
}
*durables consumption was calculated 
replace cons_d = cons_d / food_cons_defl
label var mi_cons_d "Consumption flow from durables pc pd"
*create sub-aggregates making sure they are non-zero
*iterate over modules
local lis = "f nf"
foreach cat of local lis {
	forvalues i=1/4 {
		*need to take floor to make sure rounding does not result in negative averages
		egen double xtag`cat'`i' = rowtotal(_*_mi_cons_`cat'`i')
		forvalues j=1/`m' {
			*scale up to get average being zero (without losing the variance)
			replace _`j'_mi_cons_`cat'`i' = _`j'_mi_cons_`cat'`i' - floor(xtag`cat'`i'/`m'*10^5)/10^5 if xtag`cat'`i'<0
		}
	}
}
drop xtag*
*create aggregates
mi passive: egen  mi_cons_f = rowtotal(mi_cons_f?)
mi passive: egen mi_cons_nf = rowtotal(mi_cons_nf?)
label var mi_cons_f "Imputed food consumption pc pd"
label var mi_cons_nf "Imputed non-food consumption pc pd"
*recalculate collected aggregates with deflator
egen cons_f =  rowtotal(cons_f?)
egen cons_nf =  rowtotal(cons_nf?)
label var cons_f "Collected food consumption pc pd"
label var cons_nf "Collected non-food consumption pc pd"
*calculate total consumption
gen tc_core = cons_d + cons_f0 + cons_nf0 
label var tc_core "Total core consumption based pc pd"
gen tc_summ = cons_d + cons_f + cons_nf
label var tc_summ "Total collected consumption pc pd"
mi passive: gen tc_imp = mi_cons_d + mi_cons_f + mi_cons_nf
label var tc_imp "Total imputed consumption pc pd"
su tc_*
*check that the consumption aggregates add up to total consumption
assert round( mi_cons_d + mi_cons_f + mi_cons_nf - tc_imp , 0.01) == 0
*check that core consumption is always lower than imputed and summed consumption
*assert(round(tc_imp-tc_core, 0.001)>=0)
assert(round(tc_summ-tc_core, 0.001)>=0)

*Poverty line 1.90 USD in 2011 prices
*https://data.worldbank.org/indicator/PA.NUS.PPP?end=2016&start=2011
*According to World Bank PPP conversion factors, The 2011 PPP for Naira is 79.53
* Thus, the 2011 (PPP) poverty line of $1.9/d translates into $1.9/d/ 79.53 = = 151.107 (in 2011 USD)
* CPI 2018: 250; Dec 2011: 125.00 
* In 2018 terms, this is 151.107*(250/125) = 302.2 Naira/d
gen plinePPP = (1.9*79.53)*(250/125)
label var plinePPP "2011 PPP 1.90 USD Poverty Line"
gen pline125PPP = (1.25*79.53)*(250/125)
label var pline125PPP "2011 PPP 1.25 USD Poverty Line"
gen pline31PPP = (3.1*79.53)*(250/125)
label var pline31PPP "2011 PPP 3.1 USD Poverty Line"
*calculate poverty
mi passive: gen poorPPP_prob = tc_imp < plinePPP if !missing(tc_imp)
label var poorPPP_prob "Below 2011 1.9 USD PPP poverty line"
mi estimate: mean poorPPP_prob [pweight=hhweight], over(migr_idp)
mi passive: gen poor125PPP_prob = tc_imp < pline125PPP if !missing(tc_imp)
label var poor125PPP_prob "Below 2011 1.25 USD PPP poverty line"
mi estimate: mean poor125PPP_prob [pweight=hhweight], over(migr_idp)
mi passive: gen poor31PPP_prob = tc_imp < pline31PPP if !missing(tc_imp)
label var poor31PPP_prob "Below 2011 3.1 USD PPP poverty line"
mi estimate: mean poor31PPP_prob [pweight=hhweight], over(migr_idp)
label define poorPPP_prob 0 "Non-poor" 1 "Poor"
label values poorPPP_prob poor125PPP_prob poor31PPP_prob lpoorPPP_prob
save "${gsdTemp}/mi-analysis.dta", replace

*extract data
use "${gsdTemp}/mi-analysis.dta", clear
forvalues i = 1/`m' {
	use "${gsdTemp}/mi-analysis.dta", clear
	mi extract `i', clear	
	gen mi = `i'
	save "${gsdTemp}/mi_`i'.dta", replace
}
*append
clear
forvalues i = 1/`m' {
	append using "${gsdTemp}/mi_`i'.dta"
}
*adjust weights
replace weight=weight/`m'
drop hhweight
label var mi "Imputation number"
save "${gsdData}/1-CleanOutput/mi-extract.dta", replace

*analysis on extract
use "${gsdData}/1-CleanOutput/mi-extract.dta", clear
collapse (mean) tc_* poor* mi_cons_f? mi_cons_nf? mi_cons_d mi_cons_f mi_cons_nf food_cons_defl* cons_f cons_f? cons_nf cons_nf?, by(region migr_idp ea hh hhsize *weight* mod_hh pline*)
forvalues i = 1/4 {
	assert(round(mi_cons_f`i', 0.001)>=0)
	assert(round(mi_cons_nf`i', 0.001)>=0)
}
*check that poverty figures match 
mean poorPPP_prob [pweight=weight*hhsize], over(migr_idp)
*check that total consumption figures are appropriate
assert (round(tc_imp-tc_summ, 0.001)>=0)
assert (round(tc_summ-tc_core, 0.001)>=0)
*label consumption aggregates
label var tc_core "Total consumption based on core pc pd in Naira"
label var tc_summ "Total consumption based on summing pc pd in Naira"
label var tc_imp "Total consumption based on imputation pc pd in Naira"
label var poorPPP_prob "Probability being below 1.9 2011 PPP poverty line"
label var poor125PPP_prob "Probability being below 1.25 2011 PPP poverty line"
label var poor31PPP_prob "Probability being below 3.1 2011 PPP poverty line"
label var mi_cons_d "Durables consumption flow pc pd in real Naira"
label var mi_cons_f "Mean imputed food consumption pc pd in real Naira"
label var mi_cons_nf "Mean imputed non-food consumption pc pd in real Naira"
local lis = "f nf"
foreach cat of local lis {
	forvalues i = 0/4{
		label var mi_cons_`cat'`i' "Mean imputed consumption for food module `i' in July 2015 Naira"
		label var mi_cons_`cat'`i' "Mean imputed consumption for nonfood module `i' in July 2015 Naira"
	}
}

decode region, gen(region1)
drop region
rename region1 region
order region ea migr_idp hh hhsize
save "${gsdData}/1-CleanTemp/hhq-poverty.dta", replace

*Reshape module aggregates so that a single column identifies all aggregates
local lis = "f nf"
foreach cat of local lis {
	use "${gsdData}/1-CleanTemp/hhq-poverty.dta", clear
	keep region ea migr_idp weight hh hhsize mod_hh mi_cons_`cat'0 mi_cons_`cat'1 mi_cons_`cat'2 mi_cons_`cat'3 mi_cons_`cat'4
	ren (mi_cons_`cat'*) (x*)
	reshape long x, i(region ea migr_idp hh) j(mod_item)
	ren x mi_cons_`cat'
	save "${gsdData}/1-CleanTemp/mi_`cat'_collapsed.dta", replace
}

* Integrate total imputed consumption into hhq after imputation
*find optimal thresholds for poverty
do "${gsdDo}/1-8-1-optimize_threshold.do"
*Load hhq data
use "${gsdData}/1-CleanTemp/hhq.dta", clear
*Add imputed total consumption aggregates as well as poverty line
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", keep(match master) assert(match master) keepusing(mod_hh pline* poor* tc_core tc_summ tc_imp mi_cons_f mi_cons_nf mi_cons_d cons_f cons_nf) nogenerate
*Generate poor/nonpoor indicator
*1.9 PPP
mean poorPPP_prob [pweight=weight*hhsize], over(migr_idp)
gen poor = poorPPP_prob>.${threshold19} if !missing(tc_imp)
mean poor [pweight=weight*hhsize], over(migr_idp)
* 1.25 PPP
mean poor125PPP_prob [pweight=weight*hhsize], over(migr_idp)
gen poor125 = poor125PPP_prob>.${threshold125} if !missing(tc_imp)
mean poor125 [pweight=weight*hhsize], over(migr_idp)
* 3.1 PPP
mean poor31PPP_prob [pweight=weight*hhsize], over(migr_idp)
gen poor31 = poor31PPP_prob>.${threshold31} if !missing(tc_imp)
mean poor31 [pweight=weight*hhsize], over(migr_idp)
*Calculate quintiles based on imputed total consumption
xtile quintiles_tc = tc_imp [pweight=weight*hhsize], nquantiles(5)
*Label new variables and order
label var poor "Below 1.9 USD PPP 2011 poverty line"
label var poor125 "Below 1.25 USD PPP 2011 poverty line"
label var poor31 "Below 3.1 USD PPP 2011 poverty line"
label define lpoor 0 "NonPoor" 1 "Poor"
label val poor poor125 poor31 lpoor
label var quintiles_tc "Quintiles for imputed consumption"
label define lquintiles_tc 1 "Poorest Quintile" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Richest Quintile"
label values quintiles_tc lquintiles_tc
order plinePPP poorPPP poor pline125PPP poor125PPP poor125 pline31PPP poor31PPP poor31 , after(month)
*Merge hhm aggregates 
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", nogen keepusing(depend_share) keep(match master) assert(match master using)
*drop weekly consumption data from final
drop food_opt?_hh_wk nonfood_opt?_hh_wk assets_hh_wk
*Save
sort region ea migr_idp hh
save "${gsdData}/1-CleanOutput/hhq.dta", replace
*create graphs of food and nonfood shares
use "${gsdData}/1-CleanOutput/hhq.dta", clear
set graphics off
gen share_f_imp=mi_cons_f/tc_imp
hist share_f_imp
graph export "${gsdOutput}/food_share_imp.pdf" , as(pdf) replace
gen share_nf_imp=mi_cons_nf/tc_imp
hist share_nf_imp
graph export "${gsdOutput}/nonfood_share_imp.pdf" , as(pdf) replace
gen share_d=mi_cons_d/tc_imp
hist share_d
graph export "${gsdOutput}/assets_share_imp.pdf" , as(pdf) replace
set graphics on

* Prepare dataset that has rows with all items for each household
*Create local macro for food nonfood identifiers
local lis = "food"  /*nonfood"*/
foreach cat of local lis {
	*Create local macro for abbreviated food nonfood identifiers
	local short = cond("`cat'"=="food","f","nf")
	*Load data
	use "${gsdData}/1-CleanTemp/`cat'.dta", clear
	*assert !missing(mod_item)
	merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanOutput/hhq.dta" , assert(match master using) keep(match master) keepusing(mod_hh weight) nogen
	*Merge module consumption aggregates on household level
	merge m:1 region ea migr_idp hh mod_item using  "${gsdData}/1-CleanTemp/mi_`short'_collapsed.dta", assert(master match using) keepusing(mi_cons_`short') nogen
	*merge items' share of module consumption 
	merge m:1 itemid using "${gsdTemp}/`cat'-weights.dta" , assert(match master using) keepusing(cons_mshare) nogen
	*assert !missing(cons_mshare) if !missing(cons_value) & cons_value>0
	*Calculate imputed consumption values based on item shares and module level aggregates
	gen mi_cons_value = . 
	replace mi_cons_value  = cons_mshare * mi_cons_`short' 
	*Check that imputed cons_values sum up to module aggregates
	preserve
	rename mi_cons_value sumcheck
	collapse (sum) sumcheck, by(region ea migr_idp hh mod_item mi_cons_`short')
	assert round(mi_cons_`short' - sumcheck ,.01)==0 if !missing(mi_cons_`short')
	restore	
	*Differentiate between imputed and original data
	gen imputed = ( (mod_hh != mod_item & mod_item >0) | missing(cons_value) )
	*Create single cons var consisting of imputed values only where no real data available
	gen x = mi_cons_value  
	replace x = cons_value if (imputed == 0)
	*Tidy up 
	ren (cons_value x) (cons_value_org cons_value_fin)
	drop  *imputed* mi_cons_value *mi_cons*  cons_mshare 
	order region ea migr_idp hh weight itemid mod_item mod_hh cons_value_org cons_value_fin 
	label var cons_value_fin "`cat' consumption (per week based on quantity consumed and price reported) in Naira, imputed and original" 
	label var cons_value_org "`cat' consumption (per week based on quantity consumed and price reported) in Naira, original only"  
	label var mod_item "To which module does the item belong?"
	*Temp save data
	save "${gsdData}/1-CleanTemp/`cat'_incl_imp.dta", replace

	*Integrate into food and non-food dataset
	*Load data
	use "${gsdData}/1-CleanTemp/`cat'_incl_imp.dta", clear
	*Add details on consumption and prices, currency, constraints, etc.
	merge m:1 region ea migr_idp hh itemid using "${gsdData}/1-CleanTemp/`cat'.dta" , keep(match master) assert(master match using) nogen
	*Tidy up 
	sort region ea migr_idp hh itemid 
	drop cons_value
	order region ea migr_idp hh weight itemid mod_hh mod_item cons_value_org cons_value_fin 

	*Drop items that have zero or very small consumption values; rescale others	
	*Tag all cons_values that are insignificantly small, i.e. below 0.1 Naira pd pc
	gen small = 1 if (cons_value_fin < 0.1) & cons!=0
	replace small = 0 if (cons_value_fin >= 0.1)
	*Scale up other items in hh in order to keep hh aggregates same as before
	*Sum all cons_values for each household
	bys region ea migr_idp hh: egen sum = sum(cons_value_fin) 
	*Sum small values for each household
	bys region ea migr_idp hh: egen small_sum = sum(cons_value_fin) if small == 1
	*Distribute small_sum
	bys region ea migr_idp hh: egen x = max(small_sum)
	drop small_sum 
	ren x small_sum 
	*Sum non-small values of non-small cons_values per hh
	bys region ea migr_idp hh: egen nonsmall_sum = sum(cons_value_fin) if small == 0 
	*Calculate proportion of each cons_value of nonsmall_sum
	gen prop = cons_value_fin / nonsmall_sum 
	*Now rescale each item according to its proportion
	gen rescaled = cons_value_fin + (prop * small_sum)
	*Check that rescaling has worked
	bys region ea migr_idp hh: egen sum_rescaled = sum(rescaled)
	*assert round(sum_rescaled  - sum,0.1)==0 if sum_rescaled!=0
	*Tidy up
	drop cons_value_fin
	ren  rescaled cons_value_fin
	label var cons_value_fin "`cat' consumption (per week based on quantity consumed and price reported) in Naira, imputed and original" 
	drop if small == 1
	drop small sum small_sum nonsmall_sum prop sum_rescaled 
	order cons_value_fin, after(cons_value_org)
	*Save
	save "${gsdData}/1-CleanOutput/`cat'.dta", replace
}
