*This do file analyses conflict dates and displacement
*Conflict
*Prepare ACLED data
insheet using "${gsdDataRaw}/ACLED-Nigeria.csv", clear 
*Convert event type to numeric and simplify categories
encode event_type, gen(x)
recode x (1 2 3=1 "Battle") (4 5 8=2 "Strategic development") ( 6=3 "Remote violence") (7=4 "Riots/Protests" ) (9=5 "Violence against civilians"), gen(events_recode)
tab events_recode 
keep if year>2012
*Get dates by month
gen date = date(event_date, "DM20Y")
format date %td
gen m=mofd(date)
format m %tm
*Reshape to get number of each event per month
collapse (count) x (sum) fatalities, by(events_recode m)
reshape wide x fatalities, j(events_recode ) i(m)
*Label the events
label var x1 "Battle" 
label var x2 "Strategic development"
label var x3 "Remote violence"
label var x4 "Riots/protests"
*label var year "Year"
*Keep only total fatalities from all events
egen fatalities=rowtotal(fatalities*)
drop fatalities?
label var fatalities "Fatalities"

*Reformat date for graphs
generate event_date=dofm(m)
generate d = string(event_date, "%td")
gen my = substr(d,3,.)
gen m1=strupper(substr(my,1,1))
gen m2=substr(my,2,2)
gen month=m1+m2
drop m1 m2
gen year=substr(my,4,4)
gen ym=month+"-"+year
label var ym "Month"

*Tabout the conflict data
sort year ym
order ym x1 x2 x3 x4 fatalities
keep ym x1 x2 x3 x4 fatalities
export excel using "${gsdOutput}/Figures_NIG.xlsx", sheetmodify sheet("ACLED") first(varlabels) 
*DTM data
import excel using "${gsdDataRaw}/DTM_statewise.xlsx", clear first
drop in 1/1
keep StateofDisplacement EstimatedNumberofIDP YearofDisplacement IDPcategory
order YearofDisplacement StateofDisplacement EstimatedNumberofIDP IDPcategory
encode IDPcategory, gen(disp_reason)
drop IDPcategory
encode StateofDisplacement, gen(state)
drop StateofDisplacement
destring EstimatedNumberofIDP, replace 
collapse (sum) EstimatedNumberofIDP, by(YearofDisplacement state disp_reason)
reshape wide EstimatedNumberofIDP, j(state) i(YearofDisplacement disp_reason)
label var YearofDisplacement "Year"
label var EstimatedNumberofIDP1 "Adamawa"
label var EstimatedNumberofIDP2 "Bauchi"
label var EstimatedNumberofIDP3 "Borno"
label var EstimatedNumberofIDP4 "Gombe"
label var EstimatedNumberofIDP5 "Taraba"
label var EstimatedNumberofIDP6 "Yobe"
export excel using "${gsdOutput}/Figures_NIG.xlsx", sheetmodify sheet("DTM_statewise") first(varlabels)
*Displacement flows
import excel using "${gsdDataRaw}/Displacement_Nigeria.xlsx", first clear 
keep year- disaster_new_displacements
label var year "Year"
label var conflict_new_displacements "Conflict displacements"
label var disaster_new_displacements "Disaster displacements"
export excel using "${gsdOutput}/Figures_NIG.xlsx", sheetmodify sheet("Disp_flows") first(varlabels) 

