*This do file performs migr_idp poverty analysis and consumption distribution

*HHQ level analysis
use "${gsdData}/1-CleanOutput/hhq.dta", clear
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(master match using) keep(match) keepusing(hhh_gender) nogen
*Poverty analysis will be done using population weights as we are using household leve data to infer population headcounts in poverty
gen pweight = weight*hhsize
svyset ea [pw=pweight], strata(region)

*Generate analysis variables
gen gap = (plinePPP - tc_imp)/plinePPP if (!missing(tc_imp)) 
replace gap = 0 if (tc_imp>plinePPP & !missing(tc_imp))
gen severity = (gap)^2 

*Poverty headcount ratio: % of Population living on $1.90 PPP per person per day
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) replace h2("Poverty") f(4)
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty") f(4)
qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty") f(4)
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty") f(4)
qui tabout camp using "${gsdOutput}/Raw_Fig14.xls" if hhh_gender == 0, svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty - Male headed households - country of nationality") f(4)
qui tabout camp using "${gsdOutput}/Raw_Fig14.xls" if hhh_gender == 1, svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty - Female headed households - country of nationality") f(4)
qui tabout hhh_gender if migr_idp==0 using "${gsdOutput}/Raw_Fig14.xls" , svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty host community") f(4)

*Poverty headcount ratio: % of Population living on $1.90 PPP per person per day with behavioral module variable for comparison
qui tabout hhh_gender Behavioural_beh_treat_opt if migr_idp == 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty") f(4)
qui tabout region Behavioural_beh_treat_opt using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty") f(4)
qui tabout migr_idp Behavioural_beh_treat_opt using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty") f(4)
qui tabout camp Behavioural_beh_treat_opt if migr_idp==1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty") f(4)
qui tabout camp Behavioural_beh_treat_opt using "${gsdOutput}/Raw_Fig14.xls" if hhh_gender == 0, svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty - Male headed households - country of nationality") f(4)
qui tabout camp Behavioural_beh_treat_opt using "${gsdOutput}/Raw_Fig14.xls" if hhh_gender == 1, svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty - Female headed households - country of nationality") f(4)
qui tabout hhh_gender Behavioural_beh_treat_opt if migr_idp==0 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poorPPP_prob lb ub se) npos(col) append h2("Poverty - Female headed households - country of nationality") f(4)

*Testing for significance of difference in poverty over household head within the same country of nationality

svy: mean poorPPP_prob, over(migr_idp)
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //idp host
*IDP>HC 

svy: mean poorPPP_prob, over(hhh_gender)
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //male vs female
*Woman>Man

svy: mean poorPPP_prob, over(migr_idp hhh_gender)
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //host comm male female
*Host woman>man
lincom [poorPPP_prob]_subpop_3 - [poorPPP_prob]_subpop_4 //idp male female
*Statistically insignificant

svy: mean poorPPP_prob if migr_idp==1, over(camp)
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //camp host
*Camp>Host
svy: mean poorPPP_prob if migr_idp==1, over(camp hhh_gender)
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //host male female
*Host Woman>Man
lincom [poorPPP_prob]_subpop_3 - [poorPPP_prob]_subpop_4 //camp male female
*Insignificant

svy: mean poorPPP_prob, over(Behavioural_beh_treat_opt )
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //no nudge vs nudge
*Insignificant

svy: mean poorPPP_prob, over(migr_idp Behavioural_beh_treat_opt )
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //host nudge no nudge
*Nudge> no Nudge
lincom [poorPPP_prob]_subpop_3 - [poorPPP_prob]_subpop_4 //idp nudge no nudge
*No Nudge>nudge

svy: mean poorPPP_prob if migr_idp==1, over(camp Behavioural_beh_treat_opt )
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2 //host nudge no nudge
*Statistically insignificant
lincom [poorPPP_prob]_subpop_3 - [poorPPP_prob]_subpop_4 //camp nudge no nudge
*Insignificant


/*
svy: mean poorPPP_prob, over(origin_country)
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_2
*Statistically significant: Poverty amongst South Sudanese migr_idps is higher than poverty among Somali migr_idps
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_3
*Statistically significant: Poverty amongst South Sudanese migr_idps is higher than poverty among Eritrean migr_idps
lincom [poorPPP_prob]_subpop_1 - [poorPPP_prob]_subpop_4
*Statistically significant at 10%
lincom [poorPPP_prob]_subpop_4 - [poorPPP_prob]_subpop_2
*Statistically significant: Poverty amongst Sudanese migr_idps is higher than poverty among Somali migr_idps
lincom [poorPPP_prob]_subpop_4 - [poorPPP_prob]_subpop_3
*Statistically significant: Poverty amongst Sudanese migr_idps is higher than poverty among Eritrean migr_idps
lincom [poorPPP_prob]_subpop_3 - [poorPPP_prob]_subpop_4
*Statistically significant: Poverty amongst Somali migr_idps is higher than poverty among Eritrean migr_idps
*/
*Poverty headcount ratio $1.25 USD PPP
qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poor125PPP_prob lb ub se) npos(col) append h2("ExtremePoverty") f(4)
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poor125PPP_prob lb ub se) npos(col) append h2("ExtremePoverty") f(4)
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poor125PPP_prob lb ub se) npos(col) append h2("ExtremePoverty") f(4)
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poor125PPP_prob lb ub se) npos(col) append h2("ExtremePoverty") f(4)

*Poverty gap/depth: mean aggregate income relative to poverty line
qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean gap lb ub se) npos(col) append h2("Poverty Gap") f(4)
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean gap lb ub se) npos(col) append h2("Poverty Gap") f(4)
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean gap lb ub se) npos(col) append h2("Poverty Gap (migr_idps) - by Household Gender") f(4)
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean gap lb ub se) npos(col) append h2("Poverty Gap by country of nationality") f(4)
qui tabout camp using "${gsdOutput}/Raw_Fig14.xls" if migr_idp==1 & hhh_gender == 0, svy sum c(mean gap lb ub se) npos(col) append h2("Poverty Gap - Male headed households - country of nationality") f(4)
qui tabout camp using "${gsdOutput}/Raw_Fig14.xls" if migr_idp==1 & hhh_gender == 1, svy sum c(mean gap lb ub se) npos(col) append h2("Poverty Gap - Female headed households - country of nationality") f(4)
qui tabout hhh_gender if migr_idp == 0 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean gap lb ub se) npos(col) append h2("Poverty Gap (HC) - by Household Gender") f(4)

*Extreme poverty for camp and non camp
qui tabout hhh_gender if migr_idp==0 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poor125PPP_prob lb ub se) npos(col) append h2("ExtremePoverty") f(4)
qui tabout camp if migr_idp==1 & hhh_gender==1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poor125PPP_prob lb ub se) npos(col) append h2("ExtremePoverty") f(4)
qui tabout camp if migr_idp==1 & hhh_gender==0 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean poor125PPP_prob lb ub se) npos(col) append h2("ExtremePoverty") f(4)

*Tests of significance: 
svy: mean gap, over(migr_idp hhh_gender)
lincom [gap]_subpop_1 - [gap]_subpop_2
lincom [gap]_subpop_3 - [gap]_subpop_4
*IDP diff is significant
svy: mean gap, over(migr_idp)
lincom [gap]_subpop_1 - [gap]_subpop_2
*Statistically significant: IDP population have a higher gap from poverty line as compared to host community population

use "${gsdData}/1-CleanOutput/hhq.dta", clear
keep migr_idp region ea hh weight tc_imp quintiles_tc weight hhsize camp
gen pweight = weight *hhsize
svyset ea [pw=pweight], strata(region)
drop if missing(tc_imp)

*Gini Index
*The more unequal the distribution, the higher the Gini coefficient
*Among overall migr_idps
fastgini tc_imp [pw=pweight] if migr_idp == 1, jk
gen gini_mean=`r(gini)' if migr_idp == 1
gen gini_sd=`r(se)' if migr_idp == 1

*Among overall host community:
fastgini tc_imp [pw=pweight] if migr_idp == 0, jk
replace gini_mean=`r(gini)' if migr_idp == 0
replace gini_sd=`r(se)' if migr_idp == 0

*Among migr_idps of different countries of nationality:
fastgini tc_imp [pw=pweight] if region == "Adamawa", jk
gen gini_mean_n=`r(gini)' if region == "Adamawa"
gen gini_sd_n=`r(se)' if region== "Adamawa"


*Among migr_idps of different countries of nationality:
fastgini tc_imp [pw=pweight] if region == "Bauchi", jk
replace gini_mean_n=`r(gini)' if region == "Bauchi"
replace gini_sd_n=`r(se)' if region== "Bauchi"

*Among migr_idps of different countries of nationality:
fastgini tc_imp [pw=pweight] if region == "Borno", jk
replace gini_mean_n=`r(gini)' if region == "Borno"
replace gini_sd_n=`r(se)' if region== "Borno"

*Among migr_idps of different countries of nationality:
fastgini tc_imp [pw=pweight] if region == "Gombe", jk
replace gini_mean_n=`r(gini)' if region == "Gombe"
replace gini_sd_n=`r(se)' if region== "Gombe"

*Among migr_idps of different countries of nationality:
fastgini tc_imp [pw=pweight] if region == "Taraba", jk
replace gini_mean_n=`r(gini)' if region == "Taraba"
replace gini_sd_n=`r(se)' if region== "Taraba"

*Among migr_idps of different countries of nationality:
fastgini tc_imp [pw=pweight] if region == "Yobe", jk
replace gini_mean_n=`r(gini)' if region == "Yobe"
replace gini_sd_n=`r(se)' if region== "Yobe"

qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls" , svy sum c(mean gini_mean) npos(col) f(4) append sebnone h2("Gini - Overall")
qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls" , svy sum c(mean gini_sd) npos(col) f(4) append sebnone h2("Gini standard error - Overall")
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig14.xls" , svy sum c(mean gini_mean) npos(col) f(4) append sebnone h2("Gini - Overall")
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig14.xls" , svy sum c(mean gini_sd) npos(col) f(4) append sebnone h2("Gini standard error - Overall")
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean gini_mean_n) npos(col) f(4) append sebnone h2("Gini by Country of nationality")
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean gini_sd_n) npos(col) f(4) append sebnone h2("Gini standard error by Country of nationality")

*Inequality is not that high. We can talk about it further
/*
*Poverty severity: squared poverty gap
qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean severity lb ub se) npos(col) append h2("Severity") f(4)
qui tabout hhh_gender if migr_idp== 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean severity lb ub se) npos(col) append h2("Severity") f(4)
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean severity lb ub se) npos(col) append h2("Severity") f(4)



*Create dataset with consumption expenditure distribution curves by migr_idp status and by country of nationality
*create overall percentiles
use  "${gsdData}/1-CleanOutput/hhq.dta", clear
gen pweight = weight *hhsize
svyset ea [pw=pweight], strata(region)
drop if missing(tc_imp)
keep migr_idp region ea hh weight tc_imp pweight
gen pctile=.
forvalues i=0/1 {
	xtile pctile_`i'=tc_imp [aw=pweight]  if migr_idp==`i', nq(20)
	replace pctile=pctile_`i' if migr_idp==`i'
	gen tc_imp_`i'=tc_imp if migr_idp==`i'
}
drop if missing(pctile)
collapse tc_imp_* , by(pctile)
save "${gsdTemp}/pctiles_overall.dta", replace
*create percentiles by country of nationality
use  "${gsdData}/1-CleanOutput/hhq.dta", clear
gen pweight = weight * hhsize
svyset ea [pw=pweight], strata(region)
drop if missing(tc_imp)
keep migr_idp region ea hh weight tc_imp pweight
gen pctile=.
levelsof region, local(levels)
foreach i of local levels {
	xtile pctile_c`i'=tc_imp [aw=pweight]  if region == "`i'" , nq(20)
	replace pctile=pctile_c`i' if region =="`i'" 
	gen tc_imp_c`i'=tc_imp if region =="`i'" 
}
drop if missing(pctile)
collapse tc_imp_c* , by(pctile)
save "${gsdTemp}/pctiles_origin.dta", replace

*merge the data
use "${gsdTemp}/pctiles_overall.dta", clear
merge 1:1 pctile using "${gsdTemp}/pctiles_origin.dta", nogen assert(match)
save "${gsdData}/1-CleanTemp/distributions.dta", replace
export excel using "${gsdOutput}/Figures_NIG.xlsx", sheetreplace sheet("Raw-Data 24") first(variables)
*/

use "${gsdData}/1-CleanOutput/hhq.dta", clear
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(master match using) keep(match) keepusing(hhh_gender) nogen
keep migr_idp region ea hh weight tc_imp quintiles_tc weight hhsize hhh_gender Behavioural_beh_treat_opt camp
gen pweight = weight *hhsize
svyset ea [pw=pweight], strata(region)
drop if missing(tc_imp)
merge 1:m region ea migr_idp hh using "${gsdData}/1-CleanOutput/food.dta", nogen assert(match master using) keep(match) force

*71.89 percent of the people received all of the food item for free if they reported yes to receiving free food items
*create own production and aid consumption aggregates
gen share_free = 0.125 if D_1_21_free_quant == 1
replace share_free = 0.375 if D_1_21_free_quant == 2
replace share_free = 0.5 if D_1_21_free_quant == 3
replace share_free = 0.75 if D_1_21_free_quant == 4
replace share_free = 1 if D_1_21_free_quant == 5
gen cons_own=cons_value_fin*share_free if D_1_20_free_yn==1 & inlist(D_1_22_free_main,1)
replace cons_own = 0 if D_1_20_free_yn == 0
replace cons_own = 0 if D_1_20_free_yn==1 & inlist(D_1_22_free_main,2,3,4)
gen cons_aid=cons_value_fin*share_free if D_1_20_free_yn==1 & inlist(D_1_22_free_main,2,3,4)
replace cons_aid = 0 if D_1_20_free_yn == 0
replace cons_aid = 0 if D_1_20_free_yn==1 & inlist(D_1_22_free_main,1)
*collapse into hh data
collapse (sum) cons_own cons_aid cons_food_summ=cons_value_fin , by(region ea migr_idp hh quintiles_tc pweight tc_imp camp) 
replace cons_own=cons_own/cons_food_summ
label var cons_own "Share of core consumption obtained through own production"
replace cons_aid=cons_aid/cons_food_summ
label var cons_aid "Share of core consumption obtained through aid"

*Tests of significance:
svy: mean cons_aid, over(migr_idp)
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_2
*Statistically significant: migr_idps are more likely to received food through aid than non-idps

qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls" , svy sum c(mean cons_aid lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")
qui tabout camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean cons_aid lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")
tabout quintiles_tc using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean cons_aid lb ub se) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean cons_aid lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")

qui tabout migr_idp using "${gsdOutput}/Raw_Fig14.xls" , svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
qui tabout camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
tabout quintiles_tc if migr_idp == 1 using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
qui tabout region using "${gsdOutput}/Raw_Fig14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through  own production")

*Place raw data into the excel figures file
foreach i of num 14{
	insheet using "${gsdOutput}/Raw_Fig`i'.xls", clear nonames
	export excel using "${gsdOutput}/Figures_NIG.xlsx", sheetreplace sheet("Raw_Fig`i'") 
	rm "${gsdOutput}/Raw_Fig`i'.xls"
}
/*
*Tests of significance:
svy: mean cons_aid, over(origin_country)
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_2
*Statistically significant: South Sudanese migr_idps receive more aid than Somali migr_idps
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_3
*Statistically significant (p = 0.067) South Sudanese migr_idps recieve more aid than Eritrean migr_idps
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_4
*Statistically insignificant
lincom [cons_aid]_subpop_2 - [cons_aid]_subpop_3
*Statistically insignificant
lincom [cons_aid]_subpop_2 - [cons_aid]_subpop_4
*Statistically significant: Sudanese receive significantly more food aid than Somali migr_idps
lincom [cons_aid]_subpop_3 - [cons_aid]_subpop_4
*Statistically significant: Sudanese receive significantly more aid than Eritrean migr_idps

gen pctile=.
forvalues i=0/1 {
	xtile pctile_`i'=tc_imp [aw=pweight]  if migr_idp==`i', nq(20)
	replace pctile=pctile_`i' if migr_idp==`i'
	gen tc_imp_`i'=tc_imp if migr_idp==`i'
}
drop if missing(pctile)
collapse tc_imp_* cons_aid , by(pctile)

gen pctile=.
levelsof region, local(levels)
foreach i of local levels {
	xtile pctile_c`i'=tc_imp [aw=pweight]  if region == "`i'" , nq(20)
	replace pctile=pctile_c`i' if region=="`i'"
	gen cons_aid_`i' = cons_aid if region == "`i'"
	gen tc_imp_c`i'=tc_imp if region =="`i'" 
}
drop if missing(pctile)
collapse tc_imp_c* cons_aid*, by(pctile)
twoway (scatter cons_aid_1 tc_imp_c1, sort)
twoway (scatter cons_aid_2 tc_imp_c2, sort)
twoway (scatter cons_aid_4 tc_imp_c4, sort)
twoway (scatter cons_aid_5 tc_imp_c5, sort)

qui tabout migr_idp using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean cons_aid lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_aid lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")
tabout quintiles_tc using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_aid lb ub se) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")
qui tabout region using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_aid lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through aid")

qui tabout migr_idp using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
tabout quintiles_tc if migr_idp == 1 using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
qui tabout region using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through  own production")

use "${gsdData}/1-CleanOutput/hhq.dta", clear
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(master match using) keep(match) keepusing(hhh_gender) nogen
keep migr_idp region ea hh weight tc_imp quintiles_tc weight hhsize hhh_gender
gen pweight = weight *hhsize
svyset ea [pw=pweight], strata(region)
drop if missing(tc_imp)
merge 1:m region ea migr_idp hh using "${gsdData}/1-CleanOutput/nonfood.dta", nogen assert(match master using) keep(match)
gen cons_aid_nf =cons_value_fin if E_1_6_free_yn==1 
*collapse into hh data
collapse (sum) cons_aid_nf cons_nonfood_summ=cons_value_fin , by(region ea migr_idp hh quintiles_tc pweight tc_imp hhh_gender) 
replace cons_aid_nf=cons_aid_nf/cons_nonfood_summ
label var cons_aid_nf "Share of nonfood consumption obtained through aid"
