use  "${gsdData}/1-CleanOutput/hhq.dta", clear
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(match using) keep(match) nogen
*Set survey data
svyset ea [pw=weight], strata(region)

*For preliminary results without sampling weights for host communities:
*Create an extreme poor, poor, nonpoor indicator
*gen p=3
*replace p=2 if poor==1
*replace p=1 if poor125==1
*label define lp 1 "Extreme Poor" 2 "Poor" 3 "Non-Poor"
*label val p lp
*Calculating quintiles based on asset index:
*sort asset_index_current 
*gen n = _n if migr_idp == 1
*egen N = max(n)
*gen pct = n/N 
*Form quintiles manually:
*gen quintiles = 1 if pct<=0.2
*replace quintiles = 2 if pct> 0.2 & pct <= 0.4
*replace quintiles = 3 if pct > 0.4 & pct <= 0.6
*replace quintiles = 4 if pct >0.6 & pct <= 0.8
*replace quintiles = 5 if pct > 0.8 & pct <= 1.0 & !missing(pct)
*Calculate income quintiles based on total imputed consumption
*xtile quintiles = tc_imp [pweight=weight*hhsize], nquantiles(5)
*label var quintiles "Quintiles for Asset Index - migr_idps"
*label define lquintiles 1 "Poorest Quintile" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Richest Quintile"
*label values quintiles lquintiles
numlabel, remove force

*HHQ level variables
tabout region migr_idp using "${gsdOutput}/Raw_Fig0.xls",  cells(freq)  replace h1("Stratas and IDPs") f(4)
*Count the number of members in each comparison group
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig1.xls", cells(freq) replace h1("Household head gender") f(4)
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig1.xls", cells(freq) append h1("Quintiles based on asset index") f(4)
qui tabout region using "${gsdOutput}/Raw_Fig1.xls", cells(freq) append h1("Country of Origin") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig1.xls", cells(freq) append h1("Country of Origin") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig1.xls", cells(freq) append h1("Country of Origin") f(4) 

*qui tabout p using "${gsdOutput}/Raw_Fig1.xls", cells(freq) append h1("Poor and non-poor") f(4)

*Food Security Status
qui tabout csi_cat hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) replace h1("Food security") f(4) 
qui tabout csi_cat quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
qui tabout csi_cat region using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
*qui tabout csi_cat p using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
qui tabout csi_cat migr_idp using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
qui tabout csi_cat camp if migr_idp==1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 

*Hunger Coping Strategies
*qui tabout hunger_coping hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Hunger coping") f(4) 
*qui tabout hunger_coping quintiles using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Hunger coping") f(4) 
*qui tabout hunger_coping p using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Hunger coping") f(4) 
*qui tabout hunger_coping migr_idp using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Hunger coping") f(4) 
*qui tabout hunger_coping comparisonw3 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Hunger coping") f(4) 

*Water Source - I only have improved and non-improved water sources: Define in a box in the presentation what this means
qui tabout watersource hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) replace h1("Water source") f(4) 
qui tabout watersource quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source") f(4) 
qui tabout watersource region using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source") f(4) 
*qui tabout watersource p using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source") f(4) 
qui tabout watersource migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source") f(4) 
qui tabout watersource camp if migr_idp==1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source") f(4) 

*qui tabout watersource comparisonw3 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source") f(4) 

*Water Improved
*qui tabout waterimproved hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water improved") f(4) 
*qui tabout waterimproved region using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water improved") f(4)
*qui tabout waterimproved p using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water improved") f(4) 
*qui tabout waterimproved migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water improved") f(4) 
*qui tabout waterimproved comparisonw3 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water improved") f(4) 

*Water Time
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 


svy: mean time_water_min, over(migr_idp)
lincom [time_water_min]_subpop_1 - [time_water_min]IDP //host water vs idp water
svy: mean time_water_min if migr_idp==1, over(camp)
lincom [time_water_min]Host - [time_water_min]Camp //host water vs idp water


*qui tabout comparisonw3 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 

*Who fetches water
qui tabout who_fetch hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Who fetches water") f(4) 
qui tabout who_fetch quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Who fetches water") f(4)
qui tabout who_fetch region using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Who fetches water") f(4)  
*qui tabout who_fetch p using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Who fetches water") f(4) 
qui tabout who_fetch migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Who fetches water") f(4) 
qui tabout who_fetch camp if migr_idp==1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Who fetches water") f(4) 

svy: prop who_fetch, over(migr_idp)
lincom [_prop_3]_subpop_1 - [_prop_3]IDP //adult woman
lincom [_prop_1]_subpop_1 - [_prop_3]IDP //female child

svy: prop who_fetch if migr_idp==1, over(camp)
lincom [_prop_3]Host - [_prop_3]Camp //adult woman
lincom [_prop_1]Host - [_prop_3]Camp //female child

*Water variables before displacement:
*Water Source - I only have improved and non-improved water sources: Define in a box in the presentation what this means
qui tabout watersource_disp hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout watersource_disp quintiles if migr_idp == 1  using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout watersource_disp region using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout watersource_disp camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 

*Water Time before displacement
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min_disp lb ub se) npos(col) append h1("Water fetch time before displacement") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min_disp lb ub se) npos(col) append h1("Water fetch time before displacement") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min_disp lb ub se) npos(col) append h1("Water fetch time before displacement") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min_disp lb ub se) npos(col) append h1("Water fetch time before displacement") f(4) 

*Water obstacle
qui tabout C_1_14_water_obstacle hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_14_water_obstacle quintiles if migr_idp == 1  using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_14_water_obstacle region using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_14_water_obstacle migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_14_water_obstacle camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 

*Treat water
qui tabout C_1_16_treat_water hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_16_treat_water quintiles if migr_idp == 1  using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_16_treat_water region using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_16_treat_water migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 
qui tabout C_1_16_treat_water camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy c(col lb ub) npos(col) append h1("Water source before displacement") f(4) 

*Market time 
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_market_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_market_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_market_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_market_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_market_min lb ub se) npos(col) append h1("Water fetch time") f(4) 

*Education time
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_edu_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_edu_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_edu_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_edu_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_edu_min lb ub se) npos(col) append h1("Water fetch time") f(4) 

*Police time
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_police_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_police_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_police_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_water_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_police_min lb ub se) npos(col) append h1("Water fetch time") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig3.xls", svy sum c(mean time_police_min lb ub se) npos(col) append h1("Water fetch time") f(4) 

svy: mean time_market_min, over(migr_idp)
lincom [time_market_min]_subpop_1 - [time_market_min]IDP //host market vs idp
svy: mean time_market_min if migr_idp==1, over(camp)
lincom [time_market_min]Host - [time_market_min]Camp //host market vs camp
svy: mean time_edu_min, over(migr_idp)
lincom [time_edu_min]_subpop_1 - [time_edu_min]IDP //host edu vs idp
svy: mean time_edu_min if migr_idp==1, over(camp)
lincom [time_edu_min]Host - [time_edu_min]Camp //host edu vs camp
svy: mean time_police_min, over(migr_idp)
lincom [time_police_min]_subpop_1 - [time_police_min]IDP //host police vs idp
svy: mean time_police_min if migr_idp==1, over(camp)
lincom [time_police_min]Host - [time_police_min]Camp //host police vs camp

*Sanitation Facility
qui tabout sanitation hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) replace h1("Sanitation") f(4) 
qui tabout sanitation quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
qui tabout sanitation region using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
*qui tabout sanitation p using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
qui tabout sanitation migr_idp using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
qui tabout sanitation camp if migr_idp==1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
*qui tabout sanitation comparisonw3 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 

svy: prop sanitation, over(migr_idp)


*Toilet shared
qui tabout C_1_22_share_facility hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared") f(4) 
qui tabout C_1_22_share_facility quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared") f(4) 
qui tabout C_1_22_share_facility region using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared") f(4) 
*qui tabout share_facility p using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared") f(4) 
qui tabout C_1_22_share_facility migr_idp using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared") f(4) 
qui tabout C_1_22_share_facility camp if migr_idp==1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared") f(4) 

*Number of households sharing the toilet facility
qui tabout share_num_new hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_num") f(4) 
qui tabout share_num_new quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_num") f(4) 
qui tabout share_num_new region using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_num") f(4) 
*qui tabout share_num p using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_num") f(4) 
qui tabout share_num migr_idp using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_num") f(4) 
qui tabout share_num camp if migr_idp==1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_num") f(4) 

*Number of households sharing the toilet facility -- new categories for easier graphing
*qui tabout share_num_new hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_numnew") f(4) 
*qui tabout share_num_new region using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_numnew") f(4) 
*qui tabout share_num_new p using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_numnew") f(4) 
*qui tabout share_num_new migr_idp using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Toilet_shared_numnew") f(4) 

*Sanitation Facility
qui tabout sanitation_disp hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
qui tabout sanitation_disp quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
qui tabout sanitation_disp region using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
*qui tabout sanitation p using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
qui tabout sanitation_disp migr_idp using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 
qui tabout sanitation_disp camp if migr_idp==1 using "${gsdOutput}/Raw_Fig4.xls", svy c(col lb ub) npos(col) append h1("Sanitation") f(4) 

*Type of housing
qui tabout house hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) replace h1("house") f(4) 
qui tabout house quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house") f(4) 
qui tabout house region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house") f(4) 
*qui tabout house p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house") f(4) 
qui tabout house migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house") f(4) 
qui tabout house camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house") f(4) 
*qui tabout house comparisonw3 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house") f(4)

*Household size
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy sum c(mean hhsize lb ub se) npos(col) append h2("Household_size") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy sum c(mean hhsize lb ub se) npos(col) append h2("Household_size") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig5.xls", svy sum c(mean hhsize lb ub se) npos(col) append h2("Household_size") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig5.xls", svy sum c(mean hhsize lb ub se) npos(col) append h2("Household_size") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy sum c(mean hhsize lb ub se) npos(col) append h2("Household_size") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy sum c(mean hhsize lb ub se) npos(col) append h2("Household_size") f(4) 

*Members per room
qui tabout memperroom hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_room") f(4) 
qui tabout memperroom quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_room") f(4) 
qui tabout memperroom region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_room") f(4) 
*qui tabout memperroom p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_room") f(4) 
qui tabout memperroom migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_room") f(4) 
qui tabout memperroom camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_room") f(4) 

*Member per sleeping room
qui tabout memperroom_sl hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
*qui tabout memperroom_sl p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 

*Tenure
qui tabout tenure hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
qui tabout tenure quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
qui tabout tenure region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
*qui tabout tenure p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
qui tabout tenure migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
*qui tabout tenure comparisonw3 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 

*Legal ownership
qui tabout C_1_9_land_legal_main hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
qui tabout C_1_9_land_legal_main quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
qui tabout C_1_9_land_legal_main region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
*qui tabout land_legal_main p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
qui tabout C_1_9_land_legal_main migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
*No variation in the below-- all are owners
*qui tabout land_legal_main comparisonw3 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 

*Legal ownership type
qui tabout C_1_10_land_legal_main_d hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_1_10_land_legal_main_d quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_1_10_land_legal_main_d region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
*qui tabout land_legal_main_d p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_1_10_land_legal_main_d migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 

*Type of housing before displacement
qui tabout house_disp hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house before displacement") f(4) 
qui tabout house_disp quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house before displacement") f(4) 
qui tabout house_disp region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house before displacement") f(4) 
qui tabout house_disp migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house before displacement") f(4) 
qui tabout house_disp camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("house before displacement") f(4) 

*Member per sleeping room before displacement
qui tabout memperroom_sl_disp hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl_disp quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl_disp region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
*qui tabout memperroom_sl p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl_disp migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 
qui tabout memperroom_sl_disp camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Members_per_sleepingroom") f(4) 

*Tenure before displacement
qui tabout tenure_disp hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
qui tabout tenure_disp quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
qui tabout tenure_disp region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
*qui tabout tenure p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
qui tabout tenure_disp migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 
*qui tabout tenure comparisonw3 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Tenure") f(4) 

*Legal ownership before displacement
qui tabout C_2_6_land_legal_main_disp hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
qui tabout C_2_6_land_legal_main_disp quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
qui tabout C_2_6_land_legal_main_disp region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
*qui tabout land_legal_main p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4) 
qui tabout C_2_6_land_legal_main_disp migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership") f(4)

*Legal ownership type before displacement
qui tabout C_2_7_land_legal_main_disp_d hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_2_7_land_legal_main_disp_d quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_2_7_land_legal_main_disp_d region using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
*qui tabout land_legal_main_d p using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_2_7_land_legal_main_disp_d migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 

*Land owned:
qui tabout C_1_8_land_own_dur_n_main migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_1_8_land_own_dur_n_main camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_1_8_land_own_dur_n_main quintiles_tc if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
*qui tabout C_2_5_land_own_n_main_disp migr_idp using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_2_5_land_own_n_main_disp camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_2_5_land_own_n_main_disp quintiles_tc if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_2_8_land_use_disp camp if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 
qui tabout C_2_8_land_use_disp quintiles_tc if migr_idp==1 using "${gsdOutput}/Raw_Fig5.xls", svy c(col lb ub) npos(col) append h1("Land_ownership_type") f(4) 

*Lighting
qui tabout lighting hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) replace h1("Lighting") f(4) 
qui tabout lighting quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
qui tabout lighting region using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
*qui tabout lighting p using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
qui tabout lighting migr_idp using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
qui tabout lighting camp if migr_idp==1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 

*Cooking
qui tabout cooking hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Cooking") f(4) 
qui tabout cooking quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Cooking") f(4) 
qui tabout cooking region using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Cooking") f(4) 
*qui tabout cooking p using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Cooking") f(4) 
qui tabout cooking migr_idp using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Cooking") f(4) 
qui tabout cooking camp if migr_idp==1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Cooking") f(4) 

*Charge phone
qui tabout C_1_18_electricity_phone hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Charge_phone") f(4) 
qui tabout C_1_18_electricity_phone quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Charge_phone") f(4) 
qui tabout C_1_18_electricity_phone region using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Charge_phone") f(4) 
*qui tabout electricity_phone p using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Charge_phone") f(4) 
qui tabout C_1_18_electricity_phone migr_idp using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Charge_phone") f(4) 

*Electricity hours
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy sum c(mean C_1_19_electricity_hours lb ub se) npos(col) append h2("Electricity_hours") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy sum c(mean C_1_19_electricity_hours lb ub se) npos(col) append h2("Electricity_hours") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig6.xls", svy sum c(mean C_1_19_electricity_hours lb ub se) npos(col) append h2("Electricity_hours") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig6.xls", svy sum c(mean electricity_hours lb ub se) npos(col) append h1("Electricity_hours") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig6.xls", svy sum c(mean C_1_19_electricity_hours lb ub se) npos(col) append h2("Electricity_hours") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig6.xls", svy sum c(mean C_1_19_electricity_hours lb ub se) npos(col) append h2("Electricity_hours") f(4) 

*Lighting before displacement
qui tabout lighting_disp hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
qui tabout lighting_disp quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
qui tabout lighting_disp region using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
*qui tabout lighting p using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
qui tabout lighting_disp migr_idp using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 
qui tabout lighting_disp camp if migr_idp==1 using "${gsdOutput}/Raw_Fig6.xls", svy c(col lb ub) npos(col) append h1("Lighting") f(4) 

*Distance to health facility
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min lb ub se) npos(col) replace h1("Distance_health") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min lb ub se) npos(col) append h1("Distance_health") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min lb ub se) npos(col) append h1("Distance_health") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean dist_health_new lb ub se) npos(col) append h1("Distance_health") f(4) 
qui tabout migr_idp using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min lb ub se) npos(col) append h1("Distance_health") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min lb ub se) npos(col) append h1("Distance_health") f(4) 

*Distance to health facility before displacement
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min_disp lb ub se) npos(col) append h1("Distance_health") f(4) 
qui tabout quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min_disp lb ub se) npos(col) append h1("Distance_health") f(4) 
qui tabout region using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min_disp lb ub se) npos(col) append h1("Distance_health") f(4) 
*qui tabout p using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean dist_health_new lb ub se) npos(col) append h1("Distance_health") f(4) 
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min_disp lb ub se) npos(col) append h1("Distance_health") f(4) 
*qui tabout comparisonw3 using "${gsdOutput}/Raw_Fig7.xls", svy sum c(mean time_health_min lb ub se) npos(col) append h1("Distance_health") f(4) 

*Literacy of HH Head
*qui tabout hhh_literacy hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) replace h1("HHH_literacy") f(4) 
*qui tabout hhh_literacy quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_literacy") f(4) 
*qui tabout hhh_literacy region using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_literacy") f(4) 
*qui tabout hhh_literacy p using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_literacy") f(4) 
*qui tabout hhh_literacy migr_idp using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_literacy") f(4) 
*qui tabout hhh_literacy camp if migr_idp==1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_literacy") f(4) 

*Highest education level of HH head
*qui tabout hhh_edu_level_g hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_education") f(4) 
*qui tabout hhh_edu_level_g quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_education") f(4) 
*qui tabout hhh_edu_level_g region using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_education") f(4) 
*qui tabout hhh_edu_level_g p using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_education") f(4) 
*qui tabout hhh_edu_level_g migr_idp using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_education") f(4) 
*qui tabout hhh_edu_level_g camp if migr_idp==1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("HHH_education") f(4) 

*Assistance from UN
qui tabout C_5_2_assist_source__1 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) replace h1("UN_assistance") f(4) 
qui tabout C_5_2_assist_source__1 quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("UN_assistance") f(4) 
qui tabout C_5_2_assist_source__1 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("UN_assistance") f(4) 
*qui tabout C_76_assist_source__1 p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("UN_assistance") f(4) 
qui tabout C_5_2_assist_source__1 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("UN_assistance") f(4) 
qui tabout C_5_2_assist_source__1 camp if migr_idp==1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("UN_assistance") f(4) 

*Assistance from NGO/Development Org
qui tabout C_5_2_assist_source__2 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("NGO_assistance") f(4) 
qui tabout C_5_2_assist_source__2 quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("NGO_assistance") f(4) 
qui tabout C_5_2_assist_source__2 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("NGO_assistance") f(4) 
*qui tabout C_76_assist_source__2 p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("NGO_assistance") f(4) 
qui tabout C_5_2_assist_source__2 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("NGO_assistance") f(4) 
qui tabout C_5_2_assist_source__2 camp if migr_idp==1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("NGO_assistance") f(4) 

*Assistance from Government
qui tabout C_5_2_assist_source__3 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
qui tabout C_5_2_assist_source__3 quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
qui tabout C_5_2_assist_source__3 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
*qui tabout C_76_assist_source__3 p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
qui tabout C_5_2_assist_source__3 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
qui tabout C_5_2_assist_source__3 camp if migr_idp==1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 

*Assistance from Government
*qui tabout C_76_assist_source__3 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
*qui tabout C_76_assist_source__3 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
*qui tabout C_76_assist_source__3 p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 
*qui tabout C_76_assist_source__3 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Government_assistance") f(4) 

*Assistance from in-country remittance
*qui tabout C_76_assist_source__4 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("In_country_remittance") f(4) 
*qui tabout C_76_assist_source__4 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("In_country_remittance") f(4) 
*qui tabout C_76_assist_source__4 p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("In_country_remittance") f(4) 
*qui tabout C_76_assist_source__4 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("In_country_remittance") f(4) 

*Assistance from abroad remittance
*qui tabout C_76_assist_source__5 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Abroad_remittance") f(4) 
*qui tabout C_76_assist_source__5 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Abroad_remittance") f(4) 
*qui tabout C_76_assist_source__5 p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Abroad_remittance") f(4) 
*qui tabout C_76_assist_source__5 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Abroad_remittance") f(4) 


*Receive remittance currently:
qui tabout C_5_2_assist_source__6 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 
qui tabout C_5_2_assist_source__6 quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 
qui tabout C_5_2_assist_source__6 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 
*qui tabout intremit_prev_yn p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_beforeDec13") f(4) 
qui tabout C_5_2_assist_source__6 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 
qui tabout C_5_2_assist_source__6 camp if migr_idp==1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 

*qui tabout C_5_2_assist_source__7 hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 
*qui tabout C_5_2_assist_source__7 quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 
*qui tabout C_5_2_assist_source__7 region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 
*qui tabout intremit_prev_yn p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_beforeDec13") f(4) 
*qui tabout C_5_2_assist_source__7 migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance - Current") f(4) 


*Received remittance before displacement
qui tabout C_5_10_intremit_prev_yn hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance before displacement") f(4) 
qui tabout C_5_10_intremit_prev_yn quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance before displacement") f(4) 
qui tabout C_5_10_intremit_prev_yn region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance before displacement") f(4) 
*qui tabout intremit_prev_yn p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_beforeDec13") f(4) 
qui tabout C_5_10_intremit_prev_yn migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_beforeDec13") f(4) 

*Change in remittance received since Dec conflict
qui tabout C_5_11_intremit_moreless hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_change") f(4) 
qui tabout C_5_11_intremit_moreless quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_change") f(4)
qui tabout C_5_11_intremit_moreless region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_change") f(4)  
*qui tabout intremit_moreless p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_change") f(4) 
qui tabout C_5_11_intremit_moreless migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_change") f(4) 

*Sent remittance before Dec conflict
qui tabout C_5_12_supp_nig_yn hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_beforeDec13") f(4) 
qui tabout C_5_12_supp_nig_yn quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_beforeDec13") f(4) 
qui tabout C_5_12_supp_nig_yn region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_beforeDec13") f(4) 
*qui tabout supp_ssd_yn p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_beforeDec13") f(4)
qui tabout C_5_12_supp_nig_yn migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_beforeDec13") f(4)

*Change in remittance sent since Dec conflict
qui tabout C_5_14_supp_moreless hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_change") f(4) 
qui tabout C_5_14_supp_moreless quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_change") f(4)
qui tabout C_5_14_supp_moreless region using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_change") f(4) 
 
*qui tabout supp_moreless p using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_change") f(4) 
qui tabout C_5_14_supp_moreless migr_idp using "${gsdOutput}/Raw_Fig9.xls", svy c(col lb ub) npos(col) append h1("Remittance_sent_change") f(4) 

*HHM level variables
use "${gsdData}/1-CleanOutput/hhm.dta" , clear
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(match using) keep(match) keepusing(hhh_gender) nogen
merge m:1 region ea migr_idp hh using "${gsdData}/1-CleanOutput/hhq.dta",  nogen keepusing(tc_imp quintiles_tc *lhood camp)
/*
*For preliminary results without sampling weights for host communities:
replace weight = 1 if migr_idp == 0
*Code that needs to go early into pipeline:
replace A_6_orig_c = 2 if A_6_orig_c == 3
rename A_6_orig_c region
*/
*Cleaning birth attendant data:
*set survey data
svyset ea [pw=weight], strata(region)
ren B_1_1_hhm_age age
*create age ranges for different educational stats
gen adult=inrange(age,26,120)
gen age18up=inrange(age,18,120)
gen age15up=inrange(age,15,120)
gen age25up=inrange(age,25,120)

*label
foreach v of varlist youth adult age*up {
	label val `v' lyn
}

*Delivery place of women who gave birth
qui tabout B_3_11_delivery hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_place") f(4) 
qui tabout B_3_11_delivery quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_place") f(4) 
qui tabout B_3_11_delivery region using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_place") f(4) 
qui tabout B_3_11_delivery migr_idp using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_place") f(4) 
qui tabout B_3_11_delivery camp if migr_idp==1 using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_place") f(4) 

*Who helped deliver
qui tabout B_3_12_deliveryassist hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_assist") f(4) 
qui tabout B_3_12_deliveryassist quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_assist") f(4) 
qui tabout B_3_12_deliveryassist region using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_assist") f(4) 
qui tabout B_3_12_deliveryassist migr_idp using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_assist") f(4) 
qui tabout B_3_12_deliveryassist camp if migr_idp==1 using "${gsdOutput}/Raw_Fig7.xls", svy c(col lb ub) npos(col) append h1("Delivery_assist") f(4) 

/*
*Reason for not attending school for those aged 6-18 years
qui tabout B_4_5_hhm_edu_reason B_2_1_hhm_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Noeducation_reason") f(4) 
qui tabout B_4_5_hhm_edu_reason quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Noeducation_reason") f(4) 
qui tabout B_4_5_hhm_edu_reason region using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Noeducation_reason") f(4) 
qui tabout B_4_5_hhm_edu_reason migr_idp using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Noeducation_reason") f(4) 
qui tabout B_4_5_hhm_edu_reason camp if migr_idp==1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Noeducation_reason") f(4) 

*Primary school attendance among primary school age
qui tabout B_4_3_hhm_edu_current B_2_1_hhm_gender if migr_idp == 1 & school_age_primary == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Primary_attendance") f(4) 
qui tabout B_4_3_hhm_edu_current quintiles if migr_idp == 1 & school_age_primary == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Primary_attendance") f(4) 
qui tabout B_4_3_hhm_edu_current region if school_age_primary == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Primary_attendance") f(4) 
qui tabout B_4_3_hhm_edu_current region if school_age_primary == 1 & B_2_1_hhm_gender == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Primary_attendance - Boys") f(4) 
qui tabout B_4_3_hhm_edu_current region if school_age_primary == 1 & B_2_1_hhm_gender == 2 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Primary_attendance - Girls") f(4) 
qui tabout B_4_3_hhm_edu_current migr_idp if school_age_primary == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Primary_attendance") f(4) 

*Secondary school attendance among Secondary school age
qui tabout B_4_3_hhm_edu_current B_2_1_hhm_gender if migr_idp == 1 & school_age_secondary == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Secondary_attendance") f(4) 
qui tabout B_4_3_hhm_edu_current quintiles if migr_idp == 1 & school_age_secondary == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Secondary_attendance") f(4) 
qui tabout B_4_3_hhm_edu_current region if school_age_secondary == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Secondary_attendance") f(4) 
qui tabout B_4_3_hhm_edu_current region if school_age_secondary == 1 & B_2_1_hhm_gender == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Secondary_attendance - Boys") f(4) 
qui tabout B_4_3_hhm_edu_current region if school_age_secondary == 1 & B_2_1_hhm_gender == 2 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Secondary_attendance - Girls") f(4) 
qui tabout B_4_3_hhm_edu_current migr_idp if school_age_secondary == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Secondary_attendance") f(4) 

*Overall school attendance rates:
qui tabout B_4_3_hhm_edu_current B_2_1_hhm_gender if migr_idp == 1 & school_age_prim_sec == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall") f(4) 
qui tabout B_4_3_hhm_edu_current quintiles if migr_idp == 1  & school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall") f(4) 
qui tabout B_4_3_hhm_edu_current region if school_age_prim_sec == 1   using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall") f(4) 
qui tabout B_4_3_hhm_edu_current region  if B_2_1_hhm_gender == 1 & school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Boys") f(4) 
qui tabout B_4_3_hhm_edu_current region  if B_2_1_hhm_gender == 2 & school_age_prim_sec == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Girls") f(4) 
qui tabout B_4_3_hhm_edu_current migr_idp  if school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall") f(4) 
qui tabout B_4_3_hhm_edu_current camp if migr_idp==1  & school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall") f(4) 

*Overall school attendance rates before displacement:
qui tabout B_4_6_hhm_edu_pre B_2_1_hhm_gender if migr_idp == 1 & school_age_prim_sec == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall - Before displacement") f(4) 
qui tabout B_4_6_hhm_edu_pre quintiles if migr_idp == 1  & school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall - Before displacement") f(4) 
qui tabout B_4_6_hhm_edu_pre region if school_age_prim_sec == 1   using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall - Before displacement") f(4) 
qui tabout B_4_6_hhm_edu_pre region  if B_2_1_hhm_gender == 1 & school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Boys - Before displacement") f(4) 
qui tabout B_4_6_hhm_edu_pre region  if B_2_1_hhm_gender == 2 & school_age_prim_sec == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Girls - Before displacement") f(4) 
qui tabout B_4_6_hhm_edu_pre migr_idp  if school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall - Before displacement") f(4) 
qui tabout B_4_6_hhm_edu_pre camp if migr_idp==1  & school_age_prim_sec == 1  using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("School attendance - Overall - Before displacement") f(4) 

*Literacy rate:
qui tabout literacy B_2_1_hhm_gender if migr_idp == 1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Literacy Rate") f(4) 
qui tabout literacy quintiles if migr_idp == 1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Literacy Rate") f(4) 
qui tabout literacy region if working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Literacy Rate") f(4) 
qui tabout literacy region if B_2_1_hhm_gender == 1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Literacy Rate - Men") f(4) 
qui tabout literacy region if B_2_1_hhm_gender == 2 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Literacy Rate - Women") f(4) 
qui tabout literacy migr_idp if working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Literacy Rate") f(4) 
qui tabout literacy camp if migr_idp==1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("Literacy Rate") f(4) 

*Highest educational attainment of those aged 18 years and up
qui tabout edu_level_g_c B_2_1_hhm_gender if migr_idp == 1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
qui tabout edu_level_g_c quintiles if migr_idp == 1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
qui tabout edu_level_g_c region if working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
qui tabout edu_level_g_c region if working_age ==1 & B_2_1_hhm_gender == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up - Men") f(4) 
qui tabout edu_level_g_c region if working_age ==1 & B_2_1_hhm_gender == 2 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up - Women") f(4) 
qui tabout edu_level_g_c migr_idp if working_age ==1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
qui tabout edu_level_g_c camp if migr_idp==1 & working_age ==1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 

*Gap in education
qui tabout B_4_8_hhm_edu_gap B_2_1_hhm_gender if migr_idp == 1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
qui tabout B_4_8_hhm_edu_gap quintiles if migr_idp == 1 & working_age == 1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
qui tabout B_4_8_hhm_edu_gap migr_idp if working_age ==1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
qui tabout B_4_8_hhm_edu_gap camp if migr_idp==1 & working_age ==1 using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("EdLevel_18up") f(4) 
*/

/*
*Primary school attendance by gender
forvalues i=1/2 {
	if `i'==1 {
		local g="Male"
	}
	if `i'==2 {
		local g="Female"
	}
	qui tabout primary_attend hhh_gender if migr_idp == 1 if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' primary_attend hhh gender") f(4)
	qui tabout primary_attend quintiles if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' primary_attend idp quintiles") f(4)
	qui tabout primary_attend p if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' primary_attend poor nonpoor") f(4)
	qui tabout primary_attend migr_idp if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' primary_attend poor nonpoor") f(4)
	qui tabout primary_attend comparisonw3 if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' primary_attend poor nonpoor") f(4)
	
}

*Secondary school attendance by gender
forvalues i=1/2 {
	if `i'==1 {
		local g="Male"
	}
	if `i'==2 {
		local g="Female"
	}
	qui tabout secondary_attend hhh_gender if migr_idp == 1 if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' secondary_attend hhh gender") f(4)
	qui tabout secondary_attend quintiles if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' secondary_attend idp quintiles") f(4)
	qui tabout secondary_attend p if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' secondary_attend poor nonpoor") f(4)
	qui tabout secondary_attend migr_idp if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' secondary_attend poor nonpoor") f(4)
	qui tabout secondary_attend comparisonw3 if gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' secondary_attend poor nonpoor") f(4)
}

*Edu levels by gender
forvalues i=1/2 {
	if `i'==1 {
		local g="Male"
	}
	if `i'==2 {
		local g="Female"
	}
	qui tabout edu_levels hhh_gender if migr_idp == 1 if age18up==1 & gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' edlevels hhh gender") f(4)
	qui tabout edu_levels quintiles if age18up==1 & gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' edlevels idp quintiles") f(4)
	qui tabout edu_levels p if age18up==1 & gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' edlevels poor nonpoor") f(4)
	qui tabout edu_levels migr_idp if age18up==1 & gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' edlevels poor nonpoor") f(4)
	qui tabout edu_levels comparisonw3 if age18up==1 & gender==`i' using "${gsdOutput}/Raw_Fig8.xls", svy c(col lb ub) npos(col) append h1("`g' edlevels poor nonpoor") f(4)
}
*/
*Place raw data into the excel figures file
foreach i of num 1 2 3 4 5 6 7 9{
	insheet using "${gsdOutput}/Raw_Fig`i'.xls", clear nonames
	export excel using "${gsdOutput}/Figures_NIG.xlsx", sheetreplace sheet("Raw_Fig`i'") 
	rm "${gsdOutput}/Raw_Fig`i'.xls"
}
