*This do file performs analysis of food security for IDP and HC HHs
use  "${gsdData}/1-CleanOutput/hhq.dta", clear
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(master match using) keep(match) nogen

*Generate population weight:
gen pweight = weight * hhsize
*Set survey data
svyset ea [pw=pweight], strata(region)

*Food Security Status
qui tabout csi_cat hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) replace h1("Food security") f(4) 
qui tabout csi_cat quintiles if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
qui tabout csi_cat region using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
*qui tabout csi_cat p using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
qui tabout csi_cat migr_idp using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 
qui tabout csi_cat camp if migr_idp==1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Food security") f(4) 

*Tests of significance:
svy: mean csi_cat, over(migr_idp)
lincom [csi_cat]_subpop_1 - [csi_cat]_subpop_2
*Statistically significant: IDP are more food insecure than host community households. (p<0.05)
svy: mean csi_cat if migr_idp == 1, over(hhh_gender)
lincom [csi_cat]_subpop_1 - [csi_cat]_subpop_2
*Statistically significant: Female headed households amongst refugees are more food insecure than male headed households. (p<0.01)
svy: mean csi_cat if migr_idp==1 , over(camp)
lincom [csi_cat]_subpop_1 - [csi_cat]_subpop_2

svy: mean csi_cat, over(quintiles_tc)
lincom [csi_cat]_subpop_1 - [csi_cat]Q2
*Statistically insignificant
lincom [csi_cat]Q2 - [csi_cat]Q3
*Statistically insignificant
lincom [csi_cat]Q3 - [csi_cat]Q4
*Statistically insignificant
lincom [csi_cat]Q4 - [csi_cat]_subpop_5
*Statistically significant: People in Richest quintile have the least food insecurity (p<0.01)

merge 1:m region ea migr_idp hh using "${gsdData}/1-CleanOutput/food.dta", nogen assert(match master using) keep(match) force
tab D_1_20_free_yn
svy: prop D_1_20_free_yn, over(migr_idp)
svy: prop D_1_20_free_yn, over(hhh_gender)
*svy: prop D_1_20_free_yn, over(region)
*71.89 percent of the people received all of the food item for free if they reported yes to receiving free food items
*create own production and aid consumption aggregates
gen share_free = 0.125 if D_1_21_free_quant == 1
replace share_free = 0.375 if D_1_21_free_quant == 2
replace share_free = 0.5 if D_1_21_free_quant == 3
replace share_free = 0.75 if D_1_21_free_quant == 4
replace share_free = 1 if D_1_21_free_quant == 5
gen cons_own=cons_value_org*share_free if D_1_20_free_yn==1 & inlist(D_1_22_free_main,1)
replace cons_own = 0 if D_1_20_free_yn == 0
replace cons_own = 0 if D_1_20_free_yn==1 & inlist(D_1_22_free_main,2,3,4)
gen cons_aid=cons_value_org*share_free if D_1_20_free_yn==1 & inlist(D_1_22_free_main,2,3,4)
replace cons_aid = 0 if D_1_20_free_yn == 0
replace cons_aid = 0 if D_1_20_free_yn==1 & inlist(D_1_22_free_main,1)
*collapse into hh data
collapse (sum) cons_own cons_aid cons_food_summ=cons_value_org , by(region ea migr_idp hh quintiles_tc pweight tc_imp hhh_gender food_cons_defl tc_imp mi_cons_f cons_f hhsize camp) 
gen cons_own_share=cons_own/cons_food_summ
label var cons_own_share "Share of core consumption obtained through own production"
gen cons_aid_share=cons_aid/cons_food_summ
label var cons_aid_share "Share of core consumption obtained through aid"
*Obtaining deflated values of per capita per day food consumption:
gen cons_food_pc_pd = cons_food_summ/food_cons_defl/7/hhsize
gen cons_food_pc_pd_aid = cons_aid/food_cons_defl/7/hhsize


/*
svy: mean cons_aid, over(region)
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_2
*Statistically significant: South Sudanese refugees receive more aid than Somali refugees
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_3
*Statistically significant (p = 0.067) South Sudanese refugees recieve more aid than Eritrean refugees
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_4
*Statistically insignificant
lincom [cons_aid]_subpop_2 - [cons_aid]_subpop_3
*Statistically insignificant
lincom [cons_aid]_subpop_2 - [cons_aid]_subpop_4
*Statistically significant: Sudanese receive significantly more food aid than Somali refugees
lincom [cons_aid]_subpop_3 - [cons_aid]_subpop_4
*Statistically significant: Sudanese receive significantly more aid than Eritrean refugees
svy: mean cons_aid, over(quintiles_tc)

*/

/*
gen pctile=.
forvalues i=0/1 {
	xtile pctile_`i'=tc_imp [aw=pweight]  if Refugee==`i', nq(20)
	replace pctile=pctile_`i' if Refugee==`i'
	gen tc_imp_`i'=tc_imp if Refugee==`i'
}
drop if missing(pctile)
collapse tc_imp_* cons_aid , by(pctile)

gen pctile=.
drop if origin_country == 1000
levelsof origin_country, local(levels)
foreach i of local levels {
	xtile pctile_c`i'=tc_imp [aw=pweight]  if origin_country == `i' , nq(20)
	replace pctile=pctile_c`i' if origin_country==`i' 
	gen cons_aid_`i' = cons_aid if origin_country == `i'
	gen tc_imp_c`i'=tc_imp if origin_country ==`i' 
}
drop if missing(pctile)
collapse tc_imp_c* cons_aid*, by(pctile)
twoway (scatter cons_aid_1 tc_imp_c1, sort)
twoway (scatter cons_aid_2 tc_imp_c2, sort)
twoway (scatter cons_aid_4 tc_imp_c4, sort)
twoway (scatter cons_aid_5 tc_imp_c5, sort)
*/


qui tabout migr_idp using "${gsdOutput}/Raw_Fig2.xls" , svy sum c(mean cons_aid_share lb ub) npos(col) f(4) append sebnone h2("Mean share of food obtained through aid - By Refugee status")
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_aid_share lb ub) npos(col) f(4) append sebnone h2("Mean share of food obtained through aid (Refugees) - by Gender of Household Head")
qui tabout quintiles_tc using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_aid_share lb ub se) npos(col) f(4) append sebnone h2("Mean share of food obtained through aid (Refugees) - by Consumption Quintiles")
qui tabout region using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_aid_share lb ub) npos(col) f(4) append sebnone h2("Mean share of food obtained through aid (Refugees) - by Country of Nationality")
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_aid_share lb ub) npos(col) f(4) append sebnone h2("Mean share of food obtained through aid (Refugees) - by Country of Nationality")

qui tabout migr_idp using "${gsdOutput}/Raw_Fig2.xls" , svy sum c(mean cons_food_pc_pd_aid lb ub) npos(col) f(4) append sebnone h2("Mean value of food obtained through aid per capita per day- By Refugee status")
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd_aid lb ub) npos(col) f(4) append sebnone h2("Mean value of food obtained through aid (Refugees) per capita per day- by Gender of Household Head")
qui tabout quintiles_tc using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd_aid lb ub se) npos(col) f(4) append sebnone h2("Mean value of food obtained through aid (Refugees) per capita per day- by Consumption Quintiles")
qui tabout region using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd_aid lb ub) npos(col) f(4) append sebnone h2("Mean value of food obtained through aid (Refugees) per capita per day - by Country of Nationality")
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd_aid lb ub) npos(col) f(4) append sebnone h2("Mean value of aid - by Country of Nationality")

qui tabout migr_idp using "${gsdOutput}/Raw_Fig2.xls" , svy sum c(mean cons_food_pc_pd lb ub) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day from collected data - By Refugee status")
qui tabout hhh_gender if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd lb ub) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day from collected data (Refugees) - by Gender of Household Head")
qui tabout quintiles_tc using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd lb ub se) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day from collected data (Refugees) - by Consumption Quintiles")
qui tabout region using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd lb ub) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day from collected data (Refugees) - by Country of Nationality")
qui tabout camp if migr_idp==1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean cons_food_pc_pd lb ub) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day  - by Country of Nationality")

*Tests of significance:
svy: mean cons_aid, over(migr_idp)
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_2
*Statistically significant: Refugees are more likely to received food through aid than non-refugees
*Tests of significance:
svy: mean cons_aid, over(hhh_gender)
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_2
*Woman headed households are more likely to receive food throug aid than households headed by men
svy: mean cons_aid if migr_idp==1, over(camp)
lincom [cons_aid]_subpop_1 - [cons_aid]_subpop_2


*Livestock
merge 1:m region ea migr_idp hh using "${gsdData}/1-CleanOutput/livestock.dta", nogen assert(match master using) keep(match) force

qui tabout migr_idp using "${gsdOutput}/Raw_Fig2.xls" , svy sum c(mean F_1_2_own_n lb ub) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day from collected data - By Refugee status")
qui tabout camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean F_1_2_own_n lb ub) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day from collected data (Refugees) - by Gender of Household Head")
qui tabout camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy sum c(mean F_2_2_own_pre_n lb ub) npos(col) f(4) append sebnone h2("Mean value of food consumption per capita per day from collected data (Refugees) - by Gender of Household Head")

*Tests of significance:
svy: mean F_1_2_own_n, over(migr_idp)
lincom [F_1_2_own_n]_subpop_1 - [F_1_2_own_n]_subpop_2
*Statistically significant: Refugees are more likely to received food through aid than non-refugees
*Tests of significance:
svy: mean F_2_2_own_pre_n if migr_idp==1, over(camp)
lincom [F_2_2_own_pre_n]_subpop_1 - [F_2_2_own_pre_n]_subpop_2

/*
qui tabout Refugee using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
qui tabout hhh_gender if Refugee == 1 using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
tabout quintiles_tc if Refugee == 1 using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
qui tabout origin_country using "${gsdOutput}/Raw-Data 14.xls", svy sum c(mean cons_own lb ub) npos(col) f(4) append sebnone h1("Mean share of food obtained through own production")
*/

*Assistance
use  "${gsdData}/1-CleanOutput/hhq.dta", clear
merge 1:1 region ea migr_idp hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(master match using) keep(match) nogen

gen pweight = weight * hhsize
*Set survey data
svyset ea [pw=pweight], strata(region)

forval i=1/7 {
	qui tabout C_5_2_assist_source__`i' camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Assistance") f(4) 
}

qui tabout C_5_4_obs_access_aid camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Assistance") f(4) 
qui tabout C_5_4_obs_access_aid_g camp if migr_idp == 1 using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Assistance") f(4) 

forval i=1/7 {
	qui tabout C_5_2_assist_source__`i' migr_idp using "${gsdOutput}/Raw_Fig2.xls", svy c(col lb ub) npos(col) append h1("Assistance") f(4) 
}


foreach i of num 2{
	insheet using "${gsdOutput}/Raw_Fig`i'.xls", clear nonames
	export excel using "${gsdOutput}/Figures_NIG.xlsx", sheetreplace sheet("Raw_Fig`i'") 
	rm "${gsdOutput}/Raw_Fig`i'.xls"
}
